@@ -1,6 +1,8 @@
 #!/usr/bin/env python3
 
 # this script takes all the PR created by dependabot and gather them into one
+
+import argparse
 import os
 
 import requests
@@ -8,6 +10,12 @@ import yaml
 
 
 def main():
+    parser = argparse.ArgumentParser()
+    parser.add_argument('--remote', type=str, default=None,
+                        help='The name of the remote to use for pull request. ' +
+                             'Uses hub default if not specified')
+    args = parser.parse_args()
+
     with open(os.path.expanduser("~/.config/hub")) as f:
         conf = yaml.safe_load(f)
         token = conf['github.com'][0]['oauth_token']
@@ -26,9 +34,12 @@ def main():
                 print(pr['number'], pr['title'])
                 f.write(f"#{pr['number']}: {pr['title']}\n")
                 os.system(
-                    "git fetch https://github.com/buildbot/buildbot"
+                    "git fetch https://github.com/buildbot/buildbot "
                     f"refs/pull/{pr['number']}/head")
                 os.system("git cherry-pick FETCH_HEAD")
+
+    if args.remote is not None:
+        os.system(f'git push {args.remote} gather_dependabot')
     os.system("hub pull-request -b buildbot:master -p -F /tmp/hub_pr_message -l dependencies")
 
 
