@@ -19,13 +19,13 @@ import stat
 from urllib.parse import quote as urlquote
 
 from twisted.internet import defer
-from twisted.internet import utils
 from twisted.python import log
 
 from buildbot import config
 from buildbot.changes import base
 from buildbot.util import bytes2unicode
 from buildbot.util import private_tempdir
+from buildbot.util import runprocess
 from buildbot.util.git import GitMixin
 from buildbot.util.git import getSshKnownHostsContents
 from buildbot.util.misc import writeLocalFile
@@ -37,26 +37,64 @@ class GitError(Exception):
     """Raised when git exits with code 128."""
 
 
-class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
+class GitPoller(base.ReconfigurablePollingChangeSource, StateMixin, GitMixin):
 
     """This source will poll a remote git repo for changes and submit
     them to the change master."""
 
-    compare_attrs = ("repourl", "branches", "workdir",
-                     "pollInterval", "gitbin", "usetimestamps",
-                     "category", "project", "pollAtLaunch",
-                     "buildPushesWithNoCommits", "sshPrivateKey", "sshHostKey")
+    compare_attrs = ("repourl", "branches", "workdir", "pollInterval", "gitbin", "usetimestamps",
+                     "category", "project", "pollAtLaunch", "buildPushesWithNoCommits",
+                     "sshPrivateKey", "sshHostKey", "sshKnownHosts", "pollRandomDelayMin",
+                     "pollRandomDelayMax")
 
-    secrets = ("sshPrivateKey", "sshHostKey")
+    secrets = ("sshPrivateKey", "sshHostKey", "sshKnownHosts")
 
-    def __init__(self, repourl, branches=None, branch=None,
-                 workdir=None, pollInterval=10 * 60,
-                 gitbin='git', usetimestamps=True,
-                 category=None, project=None,
-                 pollinterval=-2, fetch_refspec=None,
-                 encoding='utf-8', name=None, pollAtLaunch=False,
-                 buildPushesWithNoCommits=False, only_tags=False,
-                 sshPrivateKey=None, sshHostKey=None):
+    def __init__(self, repourl, **kwargs):
+        name = kwargs.get("name", None)
+        if name is None:
+            kwargs["name"] = repourl
+        super().__init__(repourl, **kwargs)
+
+    def checkConfig(self, repourl, branches=None, branch=None, workdir=None,
+                    pollInterval=10 * 60, gitbin="git", usetimestamps=True, category=None,
+                    project=None, pollinterval=-2, fetch_refspec=None, encoding="utf-8",
+                    name=None, pollAtLaunch=False, buildPushesWithNoCommits=False,
+                    only_tags=False, sshPrivateKey=None, sshHostKey=None, sshKnownHosts=None,
+                    pollRandomDelayMin=0, pollRandomDelayMax=0):
+
+        # for backward compatibility; the parameter used to be spelled with 'i'
+        if pollinterval != -2:
+            pollInterval = pollinterval
+
+        if only_tags and (branch or branches):
+            config.error("GitPoller: can't specify only_tags and branch/branches")
+        if branch and branches:
+            config.error("GitPoller: can't specify both branch and branches")
+
+        self.sshPrivateKey = sshPrivateKey
+        self.sshHostKey = sshHostKey
+        self.sshKnownHosts = sshKnownHosts
+        self.setupGit(logname='GitPoller')  # check the configuration
+
+        if fetch_refspec is not None:
+            config.error("GitPoller: fetch_refspec is no longer supported. "
+                         "Instead, only the given branches are downloaded.")
+
+        if name is None:
+            name = repourl
+
+        super().checkConfig(name=name,
+                            pollInterval=pollInterval, pollAtLaunch=pollAtLaunch,
+                            pollRandomDelayMin=pollRandomDelayMin,
+                            pollRandomDelayMax=pollRandomDelayMax)
+
+    @defer.inlineCallbacks
+    def reconfigService(self, repourl, branches=None, branch=None, workdir=None,
+                        pollInterval=10 * 60, gitbin="git", usetimestamps=True, category=None,
+                        project=None, pollinterval=-2, fetch_refspec=None, encoding="utf-8",
+                        name=None, pollAtLaunch=False, buildPushesWithNoCommits=False,
+                        only_tags=False, sshPrivateKey=None, sshHostKey=None, sshKnownHosts=None,
+                        pollRandomDelayMin=0, pollRandomDelayMax=0):
 
         # for backward compatibility; the parameter used to be spelled with 'i'
         if pollinterval != -2:
@@ -65,25 +103,10 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
         if name is None:
             name = repourl
 
-        if sshHostKey is not None and sshPrivateKey is None:
-            config.error('GitPoller: sshPrivateKey must be provided in order '
-                         'use sshHostKey')
-            sshPrivateKey = None
-
-        base.PollingChangeSource.__init__(self, name=name,
-                                          pollInterval=pollInterval,
-                                          pollAtLaunch=pollAtLaunch,
-                                          sshPrivateKey=sshPrivateKey,
-                                          sshHostKey=sshHostKey)
-
         if project is None:
             project = ''
 
-        if only_tags and (branch or branches):
-            config.error("GitPoller: can't specify only_tags and branch/branches")
-        if branch and branches:
-            config.error("GitPoller: can't specify both branch and branches")
-        elif branch:
+        if branch:
             branches = [branch]
         elif not branches:
             if only_tags:
@@ -105,15 +128,23 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
         self.lastRev = {}
         self.sshPrivateKey = sshPrivateKey
         self.sshHostKey = sshHostKey
-        self.setupGit()
-
-        if fetch_refspec is not None:
-            config.error("GitPoller: fetch_refspec is no longer supported. "
-                         "Instead, only the given branches are downloaded.")
+        self.sshKnownHosts = sshKnownHosts
+        self.setupGit(logname='GitPoller')
 
         if self.workdir is None:
             self.workdir = 'gitpoller-work'
 
+        # make our workdir absolute, relative to the master's basedir
+
+        if not os.path.isabs(self.workdir):
+            self.workdir = os.path.join(self.master.basedir, self.workdir)
+            log.msg("gitpoller: using workdir '{}'".format(self.workdir))
+
+        yield super().reconfigService(name=name,
+                                      pollInterval=pollInterval, pollAtLaunch=pollAtLaunch,
+                                      pollRandomDelayMin=pollRandomDelayMin,
+                                      pollRandomDelayMax=pollRandomDelayMax)
+
     @defer.inlineCallbacks
     def _checkGitFeatures(self):
         stdout = yield self._dovccmd('--version', [])
@@ -128,15 +159,10 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
 
     @defer.inlineCallbacks
     def activate(self):
-        # make our workdir absolute, relative to the master's basedir
-        if not os.path.isabs(self.workdir):
-            self.workdir = os.path.join(self.master.basedir, self.workdir)
-            log.msg("gitpoller: using workdir '{}'".format(self.workdir))
-
         try:
             self.lastRev = yield self.getState('lastRev', {})
 
-            base.PollingChangeSource.activate(self)
+            super().activate()
         except Exception as e:
             log.err(e, 'while initializing GitPoller repository')
 
@@ -181,8 +207,14 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
         return branch
 
     def _trackerBranch(self, branch):
-        return "refs/buildbot/{}/{}".format(urlquote(self.repourl, ''),
-                                        self._removeHeads(branch))
+        # manually quote tilde for Python 3.7
+        url = urlquote(self.repourl, '').replace('~', '%7E')
+        return "refs/buildbot/{}/{}".format(url, self._removeHeads(branch))
+
+    def poll_should_exit(self):
+        # A single gitpoller loop may take a while on a loaded master, which would block
+        # reconfiguration, so we try to exit early.
+        return not self.doPoll.running
 
     @defer.inlineCallbacks
     def poll(self):
@@ -196,6 +228,10 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
 
         branches = self.branches if self.branches else []
         remote_refs = yield self._getBranches()
+
+        if self.poll_should_exit():
+            return
+
         if branches is True or callable(branches):
             if callable(self.branches):
                 branches = [b for b in remote_refs if self.branches(b)]
@@ -211,7 +247,7 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
         ]
 
         try:
-            yield self._dovccmd('fetch', [self.repourl] + refspecs,
+            yield self._dovccmd('fetch', ['--progress', self.repourl] + refspecs,
                                 path=self.workdir)
         except GitError as e:
             log.msg(e.args[0])
@@ -221,6 +257,11 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
         log.msg('gitpoller: processing changes from "{}"'.format(self.repourl))
         for branch in branches:
             try:
+                if self.poll_should_exit():  # pragma: no cover
+                    # Note that we still want to update the last known revisions for the branches
+                    # we did process
+                    break
+
                 rev = yield self._dovccmd(
                     'rev-parse', [self._trackerBranch(branch)], path=self.workdir)
                 revs[branch] = bytes2unicode(rev, self.encoding)
@@ -229,7 +270,7 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
                 log.err(_why="trying to poll branch {} of {}".format(
                         branch, self.repourl))
 
-        self.lastRev.update(revs)
+        self.lastRev = revs
         yield self.setState('lastRev', self.lastRev)
 
     def _get_commit_comments(self, rev):
@@ -248,8 +289,8 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
                 try:
                     stamp = int(git_output)
                 except Exception as e:
-                    log.msg(
-                        'gitpoller: caught exception converting output \'{}\' to timestamp'.format(git_output))
+                    log.msg(('gitpoller: caught exception converting output \'{}\' to timestamp'
+                             ).format(git_output))
                     raise e
                 return stamp
             return None
@@ -286,6 +327,14 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
             return git_output
         return d
 
+    @defer.inlineCallbacks
+    def _get_commit_committer(self, rev):
+        args = ['--no-walk', r'--format=%cN <%cE>', rev, '--']
+        res = yield self._dovccmd('log', args, path=self.workdir)
+        if not res:
+            raise EnvironmentError('could not get commit committer for rev')
+        return res
+
     @defer.inlineCallbacks
     def _process_changes(self, newRev, branch):
         """
@@ -299,24 +348,10 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
         # initial run, don't parse all history
         if not self.lastRev:
             return
-        rebuild = False
-        if newRev in self.lastRev.values():
-            if self.buildPushesWithNoCommits:
-                existingRev = self.lastRev.get(branch)
-                if existingRev is None:
-                    # This branch was completely unknown, rebuild
-                    log.msg('gitpoller: rebuilding {} for new branch "{}"'.format(
-                            newRev, branch))
-                    rebuild = True
-                elif existingRev != newRev:
-                    # This branch is known, but it now points to a different
-                    # commit than last time we saw it, rebuild.
-                    log.msg('gitpoller: rebuilding {} for updated branch "{}"'.format(
-                            newRev, branch))
-                    rebuild = True
 
         # get the change list
-        revListArgs = (['--format=%H', '{}'.format(newRev)] +
+        revListArgs = (['--ignore-missing'] +
+                       ['--format=%H', '{}'.format(newRev)] +
                        ['^' + rev
                         for rev in sorted(self.lastRev.values())] +
                        ['--'])
@@ -327,8 +362,19 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
         revList = results.split()
         revList.reverse()
 
-        if rebuild and not revList:
-            revList = [newRev]
+        if self.buildPushesWithNoCommits and not revList:
+            existingRev = self.lastRev.get(branch)
+            if existingRev != newRev:
+                revList = [newRev]
+                if existingRev is None:
+                    # This branch was completely unknown, rebuild
+                    log.msg('gitpoller: rebuilding {} for new branch "{}"'.format(
+                        newRev, branch))
+                else:
+                    # This branch is known, but it now points to a different
+                    # commit than last time we saw it, rebuild.
+                    log.msg('gitpoller: rebuilding {} for updated branch "{}"'.format(
+                        newRev, branch))
 
         self.changeCount = len(revList)
         self.lastRev[branch] = newRev
@@ -341,6 +387,7 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
             dl = defer.DeferredList([
                 self._get_commit_timestamp(rev),
                 self._get_commit_author(rev),
+                self._get_commit_committer(rev),
                 self._get_commit_files(rev),
                 self._get_commit_comments(rev),
             ], consumeErrors=True)
@@ -356,10 +403,11 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
                 # just fail on the first error; they're probably all related!
                 failures[0].raiseException()
 
-            timestamp, author, files, comments = [r[1] for r in results]
+            timestamp, author, committer, files, comments = [r[1] for r in results]
 
             yield self.master.data.updates.addChange(
                 author=author,
+                committer=committer,
                 revision=bytes2unicode(rev, encoding=self.encoding),
                 files=files, comments=comments, when_timestamp=timestamp,
                 branch=bytes2unicode(self._removeHeads(branch)),
@@ -383,7 +431,11 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
         writeLocalFile(keyPath, self.sshPrivateKey, mode=stat.S_IRUSR)
 
     def _downloadSshKnownHosts(self, path):
-        writeLocalFile(path, getSshKnownHostsContents(self.sshHostKey))
+        if self.sshKnownHosts is not None:
+            contents = self.sshKnownHosts
+        else:
+            contents = getSshKnownHostsContents(self.sshHostKey)
+        writeLocalFile(path, contents)
 
     def _getSshPrivateKeyPath(self, ssh_data_path):
         return os.path.join(ssh_data_path, 'ssh-key')
@@ -411,7 +463,7 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
             self._downloadSshPrivateKey(key_path)
 
             known_hosts_path = None
-            if self.sshHostKey is not None:
+            if self.sshHostKey is not None or self.sshKnownHosts is not None:
                 known_hosts_path = self._getSshKnownHostsPath(ssh_workdir)
                 self._downloadSshKnownHosts(known_hosts_path)
 
@@ -421,15 +473,15 @@ class GitPoller(base.PollingChangeSource, StateMixin, GitMixin):
 
         full_args += [command] + args
 
-        res = yield utils.getProcessOutputAndValue(self.gitbin,
-            full_args, path=path, env=full_env)
-        (stdout, stderr, code) = res
+        res = yield runprocess.run_process(self.master.reactor, [self.gitbin] + full_args, path,
+                                           env=full_env)
+        (code, stdout, stderr) = res
         stdout = bytes2unicode(stdout, self.encoding)
         stderr = bytes2unicode(stderr, self.encoding)
         if code != 0:
             if code == 128:
                 raise GitError('command {} in {} on repourl {} failed with exit code {}: {}'.format(
                                full_args, path, self.repourl, code, stderr))
-            raise EnvironmentError('command {} in {} on repourl {} failed with exit code {}: {}'.format(
-                                   full_args, path, self.repourl, code, stderr))
+            raise EnvironmentError(('command {} in {} on repourl {} failed with exit code {}: {}'
+                                    ).format(full_args, path, self.repourl, code, stderr))
         return stdout.strip()
