@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 from buildbot.process.measured_service import MeasuredBuildbotServiceManager
 
