@@ -13,6 +13,7 @@
 #
 # Copyright Buildbot Team Members
 
+import base64
 import json
 import os
 import random
@@ -33,13 +34,15 @@ from twisted.python import runtime
 from twisted.python.procutils import which
 from twisted.spread import pb
 
-from buildbot.status import builder
+from buildbot.process.results import SUCCESS
+from buildbot.process.results import Results
+from buildbot.util import bytes2unicode
 from buildbot.util import now
 from buildbot.util import unicode2bytes
 from buildbot.util.eventual import fireEventually
 
 
-class SourceStamp(object):
+class SourceStamp:
 
     def __init__(self, branch, revision, patch, repository=''):
         self.branch = branch
@@ -96,7 +99,7 @@ class SourceStampExtractor:
         if not self.repository:
             self.repository = self.treetop
         # TODO: figure out the branch and project too
-        ss = SourceStamp(self.branch, self.baserev, self.patch,
+        ss = SourceStamp(bytes2unicode(self.branch), self.baserev, self.patch,
                          repository=self.repository)
         return ss
 
@@ -212,11 +215,11 @@ class MercurialExtractor(SourceStampExtractor):
     def getBaseRevision(self):
         upstream = ""
         if self.repository:
-            upstream = "r'%s'" % self.repository
+            upstream = "r'{}'".format(self.repository)
         output = ''
         try:
             output = yield self.dovc(["log", "--template", "{node}\\n", "-r",
-                                      "max(::. - outgoing(%s))" % upstream])
+                                      "max(::. - outgoing({}))".format(upstream)])
         except RuntimeError:
             # outgoing() will abort if no default-push/default path is
             # configured
@@ -270,8 +273,8 @@ class PerforceExtractor(SourceStampExtractor):
             m = re.search('==== //depot/' + self.branch
                           + r'/([\w/\.\d\-_]+)#(\d+) -', line)
             if m:
-                mpatch += "--- %s#%s\n" % (m.group(1), m.group(2))
-                mpatch += "+++ %s\n" % (m.group(1))
+                mpatch += "--- {}#{}\n".format(m.group(1), m.group(2))
+                mpatch += "+++ {}\n".format(m.group(1))
                 found = True
             else:
                 mpatch += line
@@ -279,7 +282,7 @@ class PerforceExtractor(SourceStampExtractor):
         if not found:
             output(b"could not parse patch file")
             sys.exit(1)
-        self.patch = (patchlevel, mpatch)
+        self.patch = (patchlevel, unicode2bytes(mpatch))
 
     def getPatch(self, res):
         d = self.dovc(["diff"])
@@ -329,12 +332,13 @@ class GitExtractor(SourceStampExtractor):
             d = self.dovc(["remote"])
             d.addCallback(self.fixBranch)
             return d
+        return None
 
     # strip remote prefix from self.branch
     def fixBranch(self, remotes):
-        for l in remotes.split("\n"):
+        for l in bytes2unicode(remotes).split("\n"):
             r = l.strip()
-            if r and self.branch.startswith(r):
+            if r and self.branch.startswith(r + "/"):
                 self.branch = self.branch[len(r) + 1:]
                 break
 
@@ -370,7 +374,7 @@ class GitExtractor(SourceStampExtractor):
         return d
 
     def override_baserev(self, res):
-        self.baserev = res.strip()
+        self.baserev = bytes2unicode(res).strip()
 
     def parseStatus(self, res):
         # The current branch is marked by '*' at the start of the
@@ -447,39 +451,32 @@ def ns(s):
 def createJobfile(jobid, branch, baserev, patch_level, patch_body, repository,
                   project, who, comment, builderNames, properties):
     # Determine job file version from provided arguments
-    if properties:
+    try:
+        bytes2unicode(patch_body)
         version = 5
-    elif comment:
-        version = 4
-    elif who:
-        version = 3
-    else:
-        version = 2
+    except UnicodeDecodeError:
+        version = 6
+
     job = ""
     job += ns(str(version))
-    if version < 5:
-        job += ns(jobid)
-        job += ns(branch)
-        job += ns(str(baserev))
-        job += ns("{}".format(patch_level))
-        job += ns(patch_body or "")
-        job += ns(repository)
-        job += ns(project)
-        if (version >= 3):
-            job += ns(who)
-        if (version >= 4):
-            job += ns(comment)
-        for bn in builderNames:
-            job += ns(bn)
+    job_dict = {
+        'jobid': jobid,
+        'branch': branch,
+        'baserev': str(baserev),
+        'patch_level': patch_level,
+        'repository': repository,
+        'project': project,
+        'who': who,
+        'comment': comment,
+        'builderNames': builderNames,
+        'properties': properties,
+    }
+    if version > 5:
+        job_dict['patch_body_base64'] = bytes2unicode(base64.b64encode(patch_body))
     else:
-        job += ns(
-            json.dumps({
-                'jobid': jobid, 'branch': branch, 'baserev': str(baserev),
-                'patch_level': patch_level, 'patch_body': patch_body,
-                'repository': repository, 'project': project, 'who': who,
-                'comment': comment, 'builderNames': builderNames,
-                'properties': properties,
-            }))
+        job_dict['patch_body'] = bytes2unicode(patch_body)
+
+    job += ns(json.dumps(job_dict))
     return job
 
 
@@ -509,14 +506,14 @@ class RemoteTryPP(protocol.ProcessProtocol):
         self.d = defer.Deferred()
 
     def connectionMade(self):
-        self.transport.write(self.job)
+        self.transport.write(unicode2bytes(self.job))
         self.transport.closeStdin()
 
     def outReceived(self, data):
-        sys.stdout.write(data)
+        sys.stdout.write(bytes2unicode(data))
 
     def errReceived(self, data):
-        sys.stderr.write(data)
+        sys.stderr.write(bytes2unicode(data))
 
     def processEnded(self, status_object):
         sig = status_object.value.signal
@@ -528,6 +525,13 @@ class RemoteTryPP(protocol.ProcessProtocol):
         self.d.callback((sig, rc))
 
 
+class FakeBuildSetStatus:
+    def callRemote(self, name):
+        if name == "getBuildRequests":
+            return defer.succeed([])
+        raise NotImplementedError()
+
+
 class Try(pb.Referenceable):
     buildsetStatus = None
     quiet = False
@@ -568,7 +572,7 @@ class Try(pb.Referenceable):
             if difffile == "-":
                 diff = sys.stdin.read()
             else:
-                with open(difffile, "r") as f:
+                with open(difffile, "rb") as f:
                     diff = f.read()
             if not diff:
                 diff = None
@@ -620,89 +624,83 @@ class Try(pb.Referenceable):
                ss.revision,
                self.builderNames,
                ss.patch[1]))
+        self.buildsetStatus = FakeBuildSetStatus()
         d = defer.Deferred()
         d.callback(True)
         return d
 
-    def deliverJob(self):
-        # returns a Deferred that fires when the job has been delivered
-        if self.connect == "ssh":
-            tryhost = self.getopt("host")
-            tryport = self.getopt("port")
-            tryuser = self.getopt("username")
-            trydir = self.getopt("jobdir")
-            buildbotbin = self.getopt("buildbotbin")
-            ssh_command = self.getopt("ssh")
-            if not ssh_command:
-                ssh_commands = which("ssh")
-                if not ssh_commands:
-                    raise RuntimeError("couldn't find ssh executable, make sure "
-                                       "it is available in the PATH")
+    def deliver_job_ssh(self):
+        tryhost = self.getopt("host")
+        tryport = self.getopt("port")
+        tryuser = self.getopt("username")
+        trydir = self.getopt("jobdir")
+        buildbotbin = self.getopt("buildbotbin")
+        ssh_command = self.getopt("ssh")
+        if not ssh_command:
+            ssh_commands = which("ssh")
+            if not ssh_commands:
+                raise RuntimeError("couldn't find ssh executable, make sure "
+                                   "it is available in the PATH")
 
-                argv = [ssh_commands[0]]
+            argv = [ssh_commands[0]]
+        else:
+            # Split the string on whitespace to allow passing options in
+            # ssh command too, but preserving whitespace inside quotes to
+            # allow using paths with spaces in them which is common under
+            # Windows. And because Windows uses backslashes in paths, we
+            # can't just use shlex.split there as it would interpret them
+            # specially, so do it by hand.
+            if runtime.platformType == 'win32':
+                # Note that regex here matches the arguments, not the
+                # separators, as it's simpler to do it like this. And then we
+                # just need to get all of them together using the slice and
+                # also remove the quotes from those that were quoted.
+                argv = [string.strip(a, '"') for a in
+                        re.split(r'''([^" ]+|"[^"]+")''', ssh_command)[1::2]]
             else:
-                # Split the string on whitespace to allow passing options in
-                # ssh command too, but preserving whitespace inside quotes to
-                # allow using paths with spaces in them which is common under
-                # Windows. And because Windows uses backslashes in paths, we
-                # can't just use shlex.split there as it would interpret them
-                # specially, so do it by hand.
-                if runtime.platformType == 'win32':
-                    # Note that regex here matches the arguments, not the
-                    # separators, as it's simpler to do it like this. And then we
-                    # just need to get all of them together using the slice and
-                    # also remove the quotes from those that were quoted.
-                    argv = [string.strip(a, '"') for a in
-                            re.split(r'''([^" ]+|"[^"]+")''', ssh_command)[1::2]]
-                else:
-                    # Do use standard tokenization logic under POSIX.
-                    argv = shlex.split(ssh_command)
+                # Do use standard tokenization logic under POSIX.
+                argv = shlex.split(ssh_command)
 
-            if tryuser:
-                argv += ["-l", tryuser]
+        if tryuser:
+            argv += ["-l", tryuser]
 
-            if tryport:
-                argv += ["-p", tryport]
+        if tryport:
+            argv += ["-p", tryport]
 
-            argv += [tryhost, buildbotbin, "tryserver", "--jobdir", trydir]
-            pp = RemoteTryPP(self.jobfile)
-            reactor.spawnProcess(pp, argv[0], argv, os.environ)
-            d = pp.d
-            return d
-        if self.connect == "pb":
-            user = self.getopt("username")
-            passwd = self.getopt("passwd")
-            master = self.getopt("master")
-            tryhost, tryport = master.split(":")
-            tryport = int(tryport)
-            f = pb.PBClientFactory()
-            d = f.login(credentials.UsernamePassword(unicode2bytes(user), unicode2bytes(passwd)))
-            reactor.connectTCP(tryhost, tryport, f)
-            d.addCallback(self._deliverJob_pb)
-            return d
-        raise RuntimeError("unknown connecttype '{}', "
-                           "should be 'ssh' or 'pb'".format(self.connect))
+        argv += [tryhost, buildbotbin, "tryserver", "--jobdir", trydir]
+        pp = RemoteTryPP(self.jobfile)
+        reactor.spawnProcess(pp, argv[0], argv, os.environ)
+        d = pp.d
+        return d
+
+    @defer.inlineCallbacks
+    def deliver_job_pb(self):
+        user = self.getopt("username")
+        passwd = self.getopt("passwd")
+        master = self.getopt("master")
+        tryhost, tryport = master.split(":")
+        tryport = int(tryport)
+        f = pb.PBClientFactory()
+        d = f.login(credentials.UsernamePassword(unicode2bytes(user), unicode2bytes(passwd)))
+        reactor.connectTCP(tryhost, tryport, f)
+        remote = yield d
 
-    def _deliverJob_pb(self, remote):
         ss = self.sourcestamp
         output("Delivering job; comment=", self.comment)
 
-        d = remote.callRemote("try",
-                              ss.branch,
-                              ss.revision,
-                              ss.patch,
-                              ss.repository,
-                              self.project,
-                              self.builderNames,
-                              self.who,
-                              self.comment,
-                              self.config.get('properties', {}))
-        d.addCallback(self._deliverJob_pb2)
-        return d
+        self.buildsetStatus = \
+            yield remote.callRemote("try", ss.branch, ss.revision, ss.patch, ss.repository,
+                                    self.project, self.builderNames, self.who, self.comment,
+                                    self.config.get('properties', {}))
 
-    def _deliverJob_pb2(self, status):
-        self.buildsetStatus = status
-        return status
+    def deliverJob(self):
+        # returns a Deferred that fires when the job has been delivered
+        if self.connect == "ssh":
+            return self.deliver_job_ssh()
+        if self.connect == "pb":
+            return self.deliver_job_pb()
+        raise RuntimeError("unknown connecttype '{}', "
+                           "should be 'ssh' or 'pb'".format(self.connect))
 
     def getStatus(self):
         # returns a Deferred that fires when the builds have finished, and
@@ -714,18 +712,21 @@ class Try(pb.Referenceable):
             output("waiting for builds with ssh is not supported")
         else:
             self.running = defer.Deferred()
-            assert self.buildsetStatus
-            self._getStatus_1()
+            if not self.buildsetStatus:
+                output("try scheduler on the master does not have the builder configured")
+                return None
+
+            self._getStatus_1()  # note that we don't wait for the returned Deferred
+            if bool(self.config.get("dryrun")):
+                self.statusDone()
             return self.running
+        return None
 
-    def _getStatus_1(self, res=None):
-        if res:
-            self.buildsetStatus = res
+    @defer.inlineCallbacks
+    def _getStatus_1(self):
         # gather the set of BuildRequests
-        d = self.buildsetStatus.callRemote("getBuildRequests")
-        d.addCallback(self._getStatus_2)
+        brs = yield self.buildsetStatus.callRemote("getBuildRequests")
 
-    def _getStatus_2(self, brs):
         self.builderNames = []
         self.buildRequests = {}
 
@@ -785,6 +786,7 @@ class Try(pb.Referenceable):
     def remote_buildETAUpdate(self, buildername, build, eta):
         self.ETA[buildername] = now() + eta
 
+    @defer.inlineCallbacks
     def _build_finished(self, bs, builderName):
         # we need to collect status from the newly-finished build. We don't
         # remove the build from self.outstanding until we've collected
@@ -792,23 +794,13 @@ class Try(pb.Referenceable):
         self.builds[builderName] = None
         self.ETA[builderName] = None
         self.currentStep[builderName] = "finished"
-        d = bs.callRemote("getResults")
-        d.addCallback(self._build_finished_2, bs, builderName)
-        return d
 
-    def _build_finished_2(self, results, bs, builderName):
-        self.results[builderName][0] = results
-        d = bs.callRemote("getText")
-        d.addCallback(self._build_finished_3, builderName)
-        return d
-
-    def _build_finished_3(self, text, builderName):
-        self.results[builderName][1] = text
+        self.results[builderName][0] = yield bs.callRemote("getResults")
+        self.results[builderName][1] = yield bs.callRemote("getText")
 
         self.outstanding.remove(builderName)
         if not self.outstanding:
-            # all done
-            return self.statusDone()
+            self.statusDone()
 
     def printStatus(self):
         try:
@@ -817,7 +809,7 @@ class Try(pb.Referenceable):
                 if n not in self.outstanding:
                     # the build is finished, and we have results
                     code, text = self.results[n]
-                    t = builder.Results[code]
+                    t = Results[code]
                     if text:
                         t += " ({})".format(" ".join(text))
                 elif self.builds[n]:
@@ -841,11 +833,11 @@ class Try(pb.Referenceable):
         happy = True
         for n in names:
             code, text = self.results[n]
-            t = "{}: {}".format(n, builder.Results[code])
+            t = "{}: {}".format(n, Results[code])
             if text:
                 t += " ({})".format(" ".join(text))
             output(t)
-            if code != builder.SUCCESS:
+            if code != SUCCESS:
                 happy = False
 
         if happy:
@@ -854,6 +846,7 @@ class Try(pb.Referenceable):
             self.exitcode = 1
         self.running.callback(self.exitcode)
 
+    @defer.inlineCallbacks
     def getAvailableBuilderNames(self):
         # This logs into the master using the PB protocol to
         # get the names of the configured builders that can
@@ -867,51 +860,56 @@ class Try(pb.Referenceable):
             f = pb.PBClientFactory()
             d = f.login(credentials.UsernamePassword(unicode2bytes(user), unicode2bytes(passwd)))
             reactor.connectTCP(tryhost, tryport, f)
-            d.addCallback(self._getBuilderNames)
-            return d
+            remote = yield d
+            buildernames = yield remote.callRemote("getAvailableBuilderNames")
+
+            output("The following builders are available for the try scheduler: ")
+            for buildername in buildernames:
+                output(buildername)
+
+            yield remote.broker.transport.loseConnection()
+            return
         if self.connect == "ssh":
             output("Cannot get available builders over ssh.")
             sys.exit(1)
         raise RuntimeError(
             "unknown connecttype '{}', should be 'pb'".format(self.connect))
 
-    def _getBuilderNames(self, remote):
-        d = remote.callRemote("getAvailableBuilderNames")
-        d.addCallback(self._getBuilderNames2)
-        d.addCallback(lambda _: remote.broker.transport.loseConnection())
-        return d
-
-    def _getBuilderNames2(self, buildernames):
-        output("The following builders are available for the try scheduler: ")
-        for buildername in buildernames:
-            output(buildername)
-
     def announce(self, message):
         if not self.quiet:
             output(message)
 
-    def run(self, _inTests=False):
-        # we can't do spawnProcess until we're inside reactor.run(), so get
-        # funky
+    @defer.inlineCallbacks
+    def run_impl(self):
         output("using '{}' connect method".format(self.connect))
         self.exitcode = 0
-        d = fireEventually(None)
-        if bool(self.config.get("get-builder-names")):
-            d.addCallback(lambda res: self.getAvailableBuilderNames())
-        else:
-            d.addCallback(lambda res: self.createJob())
-            d.addCallback(lambda res: self.announce("job created"))
-            deliver = self.deliverJob
-            if bool(self.config.get("dryrun")):
-                deliver = self.fakeDeliverJob
-            d.addCallback(lambda res: deliver())
-            d.addCallback(lambda res: self.announce("job has been delivered"))
-            d.addCallback(lambda res: self.getStatus())
-        d.addErrback(self.trapSystemExit)
-        d.addErrback(log.err)
-        d.addCallback(self.cleanup)
-        if _inTests:
-            return d
+
+        # we can't do spawnProcess until we're inside reactor.run(), so force asynchronous execution
+        yield fireEventually(None)
+
+        try:
+            if bool(self.config.get("get-builder-names")):
+                yield self.getAvailableBuilderNames()
+            else:
+                yield self.createJob()
+                yield self.announce("job created")
+                if bool(self.config.get("dryrun")):
+                    yield self.fakeDeliverJob()
+                else:
+                    yield self.deliverJob()
+                yield self.announce("job has been delivered")
+                yield self.getStatus()
+
+            if not bool(self.config.get("dryrun")):
+                yield self.cleanup()
+        except SystemExit as e:
+            self.exitcode = e.code
+        except Exception as e:
+            log.err(e)
+            raise
+
+    def run(self):
+        d = self.run_impl()
         d.addCallback(lambda res: reactor.stop())
 
         reactor.run()
