@@ -14,7 +14,6 @@
 # Copyright Buildbot Team Members
 
 from twisted.internet import defer
-from twisted.internet import reactor
 
 from buildbot.data import base
 from buildbot.data import types
@@ -24,7 +23,7 @@ from buildbot.process import results
 from buildbot.process.results import RETRY
 
 
-class Db2DataMixin(object):
+class Db2DataMixin:
 
     def _generate_filtered_properties(self, props, filters):
         """
@@ -38,15 +37,17 @@ class Db2DataMixin(object):
             return (props
                     if '*' in filters
                     else dict(((k, v) for k, v in props.items() if k in filters)))
+        return None
 
     @defer.inlineCallbacks
     def addPropertiesToBuildRequest(self, buildrequest, filters):
         if not filters:
-            return
+            return None
         props = yield self.master.db.buildsets.getBuildsetProperties(buildrequest['buildsetid'])
         filtered_properties = self._generate_filtered_properties(props, filters)
         if filtered_properties:
             buildrequest['properties'] = filtered_properties
+        return None
 
     def db2data(self, dbdict):
         data = {
@@ -121,10 +122,10 @@ class BuildRequestEndpoint(Db2DataMixin, base.Endpoint):
             # Don't call the data API here, as the buildrequests might have been
             # taken by another master. We just send the stop message and forget
             # about those.
-            mqKwargs = {'reason': kwargs.get('reason', 'no reason')}
+            mqArgs = {'reason': args.get('reason', 'no reason')}
             for b in builds:
                 self.master.mq.produce(("control", "builds", str(b['buildid']), "stop"),
-                                       mqKwargs)
+                                       mqArgs)
             return None
 
         # then complete it with 'CANCELLED'; this is the closest we can get to
@@ -132,6 +133,7 @@ class BuildRequestEndpoint(Db2DataMixin, base.Endpoint):
         # references.
         yield self.master.data.updates.completeBuildRequests([brid],
                                                              results.CANCELLED)
+        return None
 
 
 class BuildRequestsEndpoint(Db2DataMixin, base.Endpoint):
@@ -178,13 +180,15 @@ class BuildRequest(base.ResourceType):
     name = "buildrequest"
     plural = "buildrequests"
     endpoints = [BuildRequestEndpoint, BuildRequestsEndpoint]
-    keyFields = ['buildsetid', 'builderid', 'buildrequestid']
+    keyField = 'buildrequestid'
     eventPathPatterns = """
         /buildsets/:buildsetid/builders/:builderid/buildrequests/:buildrequestid
         /buildrequests/:buildrequestid
         /builders/:builderid/buildrequests/:buildrequestid
     """
 
+    subresources = ["Build"]
+
     class EntityType(types.Entity):
         buildrequestid = types.Integer()
         buildsetid = types.Integer()
@@ -199,7 +203,7 @@ class BuildRequest(base.ResourceType):
         complete_at = types.NoneOk(types.DateTime())
         waited_for = types.Boolean()
         properties = types.NoneOk(types.SourcedProperties())
-    entityType = EntityType(name)
+    entityType = EntityType(name, 'Buildrequest')
 
     @defer.inlineCallbacks
     def generateEvent(self, brids, event):
@@ -224,12 +228,11 @@ class BuildRequest(base.ResourceType):
         return True
 
     @base.updateMethod
-    def claimBuildRequests(self, brids, claimed_at=None, _reactor=reactor):
+    def claimBuildRequests(self, brids, claimed_at=None):
         return self.callDbBuildRequests(brids,
                                         self.master.db.buildrequests.claimBuildRequests,
                                         event="claimed",
-                                        claimed_at=claimed_at,
-                                        _reactor=_reactor)
+                                        claimed_at=claimed_at)
 
     @base.updateMethod
     @defer.inlineCallbacks
@@ -240,8 +243,7 @@ class BuildRequest(base.ResourceType):
 
     @base.updateMethod
     @defer.inlineCallbacks
-    def completeBuildRequests(self, brids, results, complete_at=None,
-                              _reactor=reactor):
+    def completeBuildRequests(self, brids, results, complete_at=None):
         assert results != RETRY, "a buildrequest cannot be completed with a retry status!"
         if not brids:
             # empty buildrequest list. No need to call db API
@@ -250,8 +252,7 @@ class BuildRequest(base.ResourceType):
             yield self.master.db.buildrequests.completeBuildRequests(
                 brids,
                 results,
-                complete_at=complete_at,
-                _reactor=_reactor)
+                complete_at=complete_at)
         except NotClaimedError:
             # the db layer returned a NotClaimedError exception, usually
             # because one of the buildrequests has been claimed by another
@@ -280,13 +281,14 @@ class BuildRequest(base.ResourceType):
 
         # goal is to make a copy of the original buildset
         buildset = yield self.master.data.get(('buildsets', buildrequest['buildsetid']))
-        properties = yield self.master.data.get(('buildsets', buildrequest['buildsetid'], 'properties'))
+        properties = yield self.master.data.get(('buildsets', buildrequest['buildsetid'],
+                                                 'properties'))
         ssids = [ss['ssid'] for ss in buildset['sourcestamps']]
-        res = yield self.master.data.updates.addBuildset(waited_for=False, scheduler='rebuild',
-                                                         sourcestamps=ssids, reason='rebuild',
-                                                         properties=properties, builderids=[
-                                                             buildrequest['builderid']], external_idstring=buildset['external_idstring'],
-                                                         parent_buildid=buildset['parent_buildid'], parent_relationship=buildset[
-                                                             'parent_relationship'],
-                                                         )
+        res = yield self.master.data.updates.addBuildset(
+                waited_for=False, scheduler='rebuild', sourcestamps=ssids, reason='rebuild',
+                properties=properties,
+                builderids=[buildrequest['builderid']],
+                external_idstring=buildset['external_idstring'],
+                parent_buildid=buildset['parent_buildid'],
+                parent_relationship=buildset['parent_relationship'])
         return res
