@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 from buildbot.data import base
 from buildbot.data import types
@@ -27,7 +25,7 @@ class Patch(base.ResourceType):
     name = "patch"
     plural = "patches"
     endpoints = []
-    keyFields = ['patchid']
+    keyField = 'patchid'
 
     class EntityType(types.Entity):
         patchid = types.Integer()
@@ -36,4 +34,4 @@ class Patch(base.ResourceType):
         subdir = types.String()
         author = types.String()
         comment = types.String()
-    entityType = EntityType(name)
+    entityType = EntityType(name, 'Patch')
