@@ -59,7 +59,7 @@ class StepEndpoint(Db2DataMixin, base.BuildNestingMixin, base.Endpoint):
             return (yield self.db2data(dbdict)) if dbdict else None
         buildid = yield self.getBuildid(kwargs)
         if buildid is None:
-            return
+            return None
         dbdict = yield self.master.db.steps.getStep(
             buildid=buildid,
             number=kwargs.get('step_number'),
@@ -83,7 +83,7 @@ class StepsEndpoint(Db2DataMixin, base.BuildNestingMixin, base.Endpoint):
         else:
             buildid = yield self.getBuildid(kwargs)
             if buildid is None:
-                return
+                return None
         steps = yield self.master.db.steps.getSteps(buildid=buildid)
         results = []
         for dbdict in steps:
@@ -91,16 +91,22 @@ class StepsEndpoint(Db2DataMixin, base.BuildNestingMixin, base.Endpoint):
         return results
 
 
+class UrlEntityType(types.Entity):
+    name = types.String()
+    url = types.String()
+
+
 class Step(base.ResourceType):
 
     name = "step"
     plural = "steps"
     endpoints = [StepEndpoint, StepsEndpoint]
-    keyFields = ['builderid', 'stepid']
+    keyField = 'stepid'
     eventPathPatterns = """
         /builds/:buildid/steps/:stepid
         /steps/:stepid
     """
+    subresources = ["Log"]
 
     class EntityType(types.Entity):
         stepid = types.Integer()
@@ -113,12 +119,9 @@ class Step(base.ResourceType):
         results = types.NoneOk(types.Integer())
         state_string = types.String()
         urls = types.List(
-            of=types.Dict(
-                name=types.String(),
-                url=types.String()
-            ))
+            of=UrlEntityType("Url", "Url"))
         hidden = types.Boolean()
-    entityType = EntityType(name)
+    entityType = EntityType(name, 'Step')
 
     @defer.inlineCallbacks
     def generateEvent(self, stepid, event):
