@@ -22,10 +22,15 @@ from buildbot import util
 from buildbot.util import bytes2unicode
 
 
+def capitalize(word):
+    return ''.join(x.capitalize() or '_' for x in word.split('_'))
+
+
 class Type:
 
     name = None
     doc = None
+    graphQLType = "unknown"
 
     @property
     def ramlname(self):
@@ -55,6 +60,18 @@ class Type:
             r["doc"] = self.doc
         return r
 
+    def toGraphQL(self):
+        return self.graphQLType
+
+    def toGraphQLTypeName(self):
+        return self.graphQLType
+
+    def graphQLDependentTypes(self):
+        return []
+
+    def getGraphQLInputType(self):
+        return self.toGraphQLTypeName()
+
 
 class NoneOk(Type):
 
@@ -87,11 +104,24 @@ class NoneOk(Type):
     def toRaml(self):
         return self.nestedType.toRaml()
 
+    def toGraphQL(self):
+        # remove trailing !
+        if isinstance(self.nestedType, Entity):
+            return self.nestedType.graphql_name
+        return self.nestedType.toGraphQL()[:-1]
+
+    def graphQLDependentTypes(self):
+        return [self.nestedType]
+
+    def getGraphQLInputType(self):
+        return self.nestedType.getGraphQLInputType()
+
 
 class Instance(Type):
 
     types = ()
     ramlType = "unknown"
+    graphQLType = "unknown"
 
     @property
     def ramlname(self):
@@ -104,12 +134,16 @@ class Instance(Type):
     def toRaml(self):
         return self.ramlType
 
+    def toGraphQL(self):
+        return self.graphQLType + "!"
+
 
 class Integer(Instance):
 
     name = "integer"
     types = (int,)
     ramlType = "integer"
+    graphQLType = "Int"
 
     def valueFromString(self, arg):
         return int(arg)
@@ -119,6 +153,8 @@ class DateTime(Instance):
 
     name = "datetime"
     types = (datetime.datetime,)
+    ramlType = "date"
+    graphQLType = "Date"  # custom
 
     def valueFromString(self, arg):
         return int(arg)
@@ -135,14 +171,13 @@ class DateTime(Instance):
                 return
         yield "{} ({}) is not a valid timestamp".format(name, object)
 
-    ramlType = "date"
-
 
 class String(Instance):
 
     name = "string"
     types = (str,)
     ramlType = "string"
+    graphQLType = "String"
 
     def valueFromString(self, arg):
         val = util.bytes2unicode(arg)
@@ -154,6 +189,7 @@ class Binary(Instance):
     name = "binary"
     types = (bytes,)
     ramlType = "string"
+    graphQLType = "Binary"  # custom
 
     def valueFromString(self, arg):
         return arg
@@ -164,6 +200,7 @@ class Boolean(Instance):
     name = "boolean"
     types = (bool,)
     ramlType = "boolean"
+    graphQLType = "Boolean"  # custom
 
     def valueFromString(self, arg):
         return util.string2boolean(arg)
@@ -174,6 +211,7 @@ class Identifier(Type):
     name = "identifier"
     identRe = re.compile('^[a-zA-Z_-][a-zA-Z0-9._-]*$')
     ramlType = "string"
+    graphQLType = "String"
 
     def __init__(self, len=None, **kwargs):
         super().__init__(**kwargs)
@@ -234,8 +272,20 @@ class List(Type):
     def toRaml(self):
         return {'type': 'array', 'items': self.of.name}
 
+    def toGraphQL(self):
+        return f"[{self.of.toGraphQLTypeName()}]!"
 
-def maybeNoneOrList(k, v):
+    def toGraphQLTypeName(self):
+        return f"[{self.of.toGraphQLTypeName()}]"
+
+    def graphQLDependentTypes(self):
+        return [self.of]
+
+    def getGraphQLInputType(self):
+        return self.of.getGraphQLInputType()
+
+
+def ramlMaybeNoneOrList(k, v):
     if isinstance(v, NoneOk):
         return k + "?"
     if isinstance(v, List):
@@ -275,55 +325,20 @@ class SourcedProperties(Type):
                         }
                         }}}
 
+    def toGraphQL(self):
+        return "[Property]!"
 
-class Dict(Type):
-    name = "dict"
+    def graphQLDependentTypes(self):
+        return [PropertyEntityType("property", 'Property')]
 
-    @property
-    def ramlname(self):
-        return self.toRaml()
-
-    def __init__(self, **contents):
-        self.contents = contents
-        self.keys = set(contents)
-
-    def validate(self, name, object):
-        if not isinstance(object, dict):
-            yield "{} ({}) is not a dictionary (got type {})".format(name, repr(object),
-                                                                     type(object))
-            return
-
-        gotNames = set(object.keys())
-
-        unexpected = gotNames - self.keys
-        if unexpected:
-            yield "{} has unexpected keys {}".format(name, ", ".join([repr(n) for n in unexpected]))
-
-        missing = self.keys - gotNames
-        if missing:
-            yield "{} is missing keys {}".format(name, ", ".join([repr(n) for n in missing]))
-
-        for k in gotNames & self.keys:
-            f = self.contents[k]
-            for msg in f.validate("{}[{}]".format(name, repr(k)), object[k]):
-                yield msg
-
-    def getSpec(self):
-        return dict(type=self.name,
-                    fields=[dict(name=k,
-                                 type=v.name,
-                                 type_spec=v.getSpec())
-                            for k, v in self.contents.items()
-                            ])
-
-    def toRaml(self):
-        return {'type': "object",
-                'properties': {maybeNoneOrList(k, v): v.ramlname for k, v in self.contents.items()}}
+    def getGraphQLInputType(self):
+        return None
 
 
 class JsonObject(Type):
     name = "jsonobject"
     ramlname = 'object'
+    graphQLType = "JSON"
 
     def validate(self, name, object):
         if not isinstance(object, dict):
@@ -350,10 +365,11 @@ class Entity(Type):
     #  * self.master.data.rtypes.buildsets.entityType
 
     name = None  # set in constructor
+    graphql_name = None  # set in constructor
     fields = {}
     fieldNames = set([])
 
-    def __init__(self, name):
+    def __init__(self, name, graphql_name):
         fields = {}
         for k, v in self.__class__.__dict__.items():
             if isinstance(v, Type):
@@ -361,6 +377,7 @@ class Entity(Type):
         self.fields = fields
         self.fieldNames = set(fields)
         self.name = name
+        self.graphql_name = graphql_name
 
     def validate(self, name, object):
         # this uses isinstance, allowing dict subclasses as used by the DB API
@@ -395,5 +412,32 @@ class Entity(Type):
     def toRaml(self):
         return {'type': "object",
                 'properties': {
-                    maybeNoneOrList(k, v): {'type': v.ramlname, 'description': ''}
+                    ramlMaybeNoneOrList(k, v): {'type': v.ramlname, 'description': ''}
                     for k, v in self.fields.items()}}
+
+    def toGraphQL(self):
+        return dict(type=self.graphql_name,
+                    fields=[dict(name=k,
+                                 type=v.toGraphQL())
+                            for k, v in self.fields.items()
+                            # in graphql, we handle properties as queriable sub resources
+                            # instead of hardcoded attributes like in rest api
+                            if k != "properties"
+                            ])
+
+    def toGraphQLTypeName(self):
+        return self.graphql_name
+
+    def graphQLDependentTypes(self):
+        return self.fields.values()
+
+    def getGraphQLInputType(self):
+        # for now, complex types are not query able
+        # in the future, we may want to declare (and implement) graphql input types
+        return None
+
+
+class PropertyEntityType(Entity):
+    name = String()
+    source = String()
+    value = JsonObject()
