@@ -132,7 +132,7 @@ class DBConnector(service.ReconfigurableServiceMixin,
                 # Using in-memory database. Since it is reset after each process
                 # restart, `buildbot upgrade-master` cannot be used (data is not
                 # persistent). Upgrade model here to allow startup to continue.
-                self.model.upgrade()
+                yield self.model.upgrade()
             current = yield self.model.is_current()
             if not current:
                 for l in upgrade_message.format(basedir=self.master.basedir).split('\n'):
