@@ -14,7 +14,6 @@
 # Copyright Buildbot Team Members
 
 from twisted.internet import defer
-from twisted.internet import reactor
 from twisted.python import log
 
 from buildbot import locks
@@ -28,7 +27,53 @@ from buildbot.process.workerforbuilder import States
 from buildbot.util import service
 
 
-class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
+class LockRetrieverMixin:
+
+    @defer.inlineCallbacks
+    def getLockByID(self, lockid, config_version):
+        ''' Convert a Lock identifier into an actual Lock instance.
+            @lockid: a locks.MasterLock or locks.WorkerLock instance
+            @config_version: The version of the config from which the list of locks has been
+                acquired by the downstream user.
+            @return: a locks.RealMasterLock or locks.RealWorkerLock instance
+
+            The real locks are tracked using lock ID and config_version. The latter is used as a
+            way to track most recent properties of real locks.
+
+            This approach is needed because there's no central registry of lock access instances
+            that are used within a Buildbot master.cfg (like there is for e.g c['builders']). All
+            lock accesses bring all lock information with themselves as the lockid member.
+            Therefore, the reconfig process is relatively complicated, because we don't know
+            whether a specific access instance encodes lock information before reconfig or after.
+            Taking into account config_version allows us to know when properties of a lock should
+            be updated.
+
+            Note that the user may create multiple lock ids with different maxCount values. It's
+            unspecified which maxCount value the real lock will have.
+        '''
+        assert isinstance(config_version, int)
+        lock = yield lockid.lockClass.getService(self, lockid.name)
+
+        if config_version > lock.config_version:
+            lock.updateFromLockId(lockid, config_version)
+        return lock
+
+    def getLockFromLockAccess(self, access, config_version):
+        # Convert a lock-access object into an actual Lock instance.
+        if not isinstance(access, locks.LockAccess):
+            # Buildbot 0.7.7 compatibility: user did not specify access
+            access = access.defaultAccess()
+        return self.getLockByID(access.lockid, config_version)
+
+    @defer.inlineCallbacks
+    def getLockFromLockAccesses(self, accesses, config_version):
+        # converts locks to their real forms
+        locks = yield defer.gatherResults([self.getLockFromLockAccess(access, config_version)
+                                           for access in accesses])
+        return zip(locks, accesses)
+
+
+class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService, LockRetrieverMixin):
 
     """This is the master-side service which manages remote buildbot workers.
     It provides them with Workers, and distributes build requests to
@@ -38,7 +83,7 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
     name = "botmaster"
 
     def __init__(self):
-        service.AsyncMultiService.__init__(self)
+        super().__init__()
 
         self.builders = {}
         self.builderNames = []
@@ -47,9 +92,6 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
 
         self.watchers = {}
 
-        # self.locks holds the real Lock instances
-        self.locks = {}
-
         self.shuttingDown = False
 
         # subscription to new build requests
@@ -60,7 +102,7 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
         self.brd.setServiceParent(self)
 
     @defer.inlineCallbacks
-    def cleanShutdown(self, quickMode=False, stopReactor=True, _reactor=reactor):
+    def cleanShutdown(self, quickMode=False, stopReactor=True):
         """Shut down the entire process, once all currently-running builds are
         complete.
         quickMode will mark all builds as retry (except the ones that were triggered)
@@ -125,7 +167,7 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
             else:
                 if stopReactor and self.shuttingDown:
                     log.msg("Stopping reactor")
-                    _reactor.stop()
+                    self.master.reactor.stop()
                 break
 
         if not self.shuttingDown:
@@ -156,19 +198,21 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
     def getBuilders(self):
         return list(self.builders.values())
 
+    @defer.inlineCallbacks
+    def getBuilderById(self, builderid):
+        for builder in self.getBuilders():
+            if builderid == (yield builder.getBuilderId()):
+                return builder
+        return None
+
     @defer.inlineCallbacks
     def startService(self):
         @defer.inlineCallbacks
         def buildRequestAdded(key, msg):
             builderid = msg['builderid']
-            buildername = None
-            # convert builderid to buildername
-            for builder in self.builders.values():
-                if builderid == (yield builder.getBuilderId()):
-                    buildername = builder.name
-                    break
-            if buildername:
-                self.maybeStartBuildsForBuilder(buildername)
+            builder = yield self.getBuilderById(builderid)
+            if builder is not None:
+                self.maybeStartBuildsForBuilder(builder.name)
 
         # consume both 'new' and 'unclaimed' build requests
         startConsuming = self.master.mq.startConsuming
@@ -178,7 +222,7 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
         self.buildrequest_consumer_unclaimed = yield startConsuming(
             buildRequestAdded,
             ('buildrequests', None, 'unclaimed'))
-        yield service.AsyncMultiService.startService(self)
+        yield super().startService()
 
     @defer.inlineCallbacks
     def reconfigServiceWithBuildbotConfig(self, new_config):
@@ -189,8 +233,7 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
         yield self.reconfigServiceBuilders(new_config)
 
         # call up
-        yield service.ReconfigurableServiceMixin.reconfigServiceWithBuildbotConfig(self,
-                                                                                   new_config)
+        yield super().reconfigServiceWithBuildbotConfig(new_config)
 
         # try to start a build for every builder; this is necessary at master
         # startup, and a good idea in any other case
@@ -227,7 +270,7 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
                 builder.master = None
                 builder.botmaster = None
 
-                yield defer.maybeDeferred(builder.disownServiceParent)
+                yield builder.disownServiceParent()
 
             for n in added_names:
                 builder = Builder(n)
@@ -255,29 +298,7 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
         if self.buildrequest_consumer_unclaimed:
             self.buildrequest_consumer_unclaimed.stopConsuming()
             self.buildrequest_consumer_unclaimed = None
-        return service.AsyncMultiService.stopService(self)
-
-    def getLockByID(self, lockid):
-        """Convert a Lock identifier into an actual Lock instance.
-        @param lockid: a locks.MasterLock or locks.WorkerLock instance
-        @return: a locks.RealMasterLock or locks.RealWorkerLock instance
-        """
-        assert isinstance(lockid, (locks.MasterLock, locks.WorkerLock))
-        if lockid not in self.locks:
-            self.locks[lockid] = lockid.lockClass(lockid)
-        # if the master.cfg file has changed maxCount= on the lock, the next
-        # time a build is started, they'll get a new RealLock instance. Note
-        # that this requires that MasterLock and WorkerLock (marker) instances
-        # be hashable and that they should compare properly.
-        return self.locks[lockid]
-
-    def getLockFromLockAccess(self, access):
-        # Convert a lock-access object into an actual Lock instance.
-        if not isinstance(access, locks.LockAccess):
-            # Buildbot 0.7.7 compatibility: user did not specify access
-            access = access.defaultAccess()
-        lock = self.getLockByID(access.lockid)
-        return lock
+        return super().stopService()
 
     def maybeStartBuildsForBuilder(self, buildername):
         """
