@@ -190,7 +190,7 @@ class GerritStatusPush(service.BuildbotService):
             options = ['-i', self.gerrit_identity_file]
         else:
             options = []
-        return ['ssh'] + options + [
+        return ['ssh', '-o', 'BatchMode=yes'] + options + [
             '@'.join((self.gerrit_username, self.gerrit_server)),
             '-p', str(self.gerrit_port),
             'gerrit'
@@ -322,8 +322,8 @@ class GerritStatusPush(service.BuildbotService):
         yield utils.getDetailsForBuilds(self.master,
                                         buildset,
                                         [build],
-                                        wantProperties=True,
-                                        wantSteps=self.wantSteps)
+                                        want_properties=True,
+                                        want_steps=self.wantSteps)
 
     def isBuildReported(self, build):
         return self.builders is None or build['builder']['name'] in self.builders
@@ -333,9 +333,9 @@ class GerritStatusPush(service.BuildbotService):
         if not self.summaryCB:
             return
         bsid = msg['bsid']
-        res = yield utils.getDetailsForBuildset(
-            self.master, bsid, wantProperties=True,
-            wantSteps=self.wantSteps, wantLogs=self.wantLogs)
+        res = yield utils.getDetailsForBuildset(self.master, bsid, want_properties=True,
+                                                want_steps=self.wantSteps, want_logs=self.wantLogs,
+                                                want_logs_content=self.wantLogs)
         builds = res['builds']
         buildset = res['buildset']
         self.sendBuildSetSummary(buildset, builds)
