@@ -40,8 +40,8 @@ def getPreviousBuild(master, build):
 
 
 @defer.inlineCallbacks
-def getDetailsForBuildset(master, bsid, wantProperties=False, wantSteps=False,
-                          wantPreviousBuild=False, wantLogs=False):
+def getDetailsForBuildset(master, bsid, want_properties=False, want_steps=False,
+                          want_previous_build=False, want_logs=False, want_logs_content=False):
     # Here we will do a bunch of data api calls on behalf of the reporters
     # We do try to make *some* calls in parallel with the help of gatherResults, but don't commit
     # to much in that. The idea is to do parallelism while keeping the code readable
@@ -59,16 +59,17 @@ def getDetailsForBuildset(master, bsid, wantProperties=False, wantSteps=False,
     builds = yield defer.gatherResults(dl)
     builds = flatten(builds, types=(list, UserList))
     if builds:
-        yield getDetailsForBuilds(master, buildset, builds, wantProperties=wantProperties,
-                                  wantSteps=wantSteps, wantPreviousBuild=wantPreviousBuild,
-                                  wantLogs=wantLogs)
+        yield getDetailsForBuilds(master, buildset, builds, want_properties=want_properties,
+                                  want_steps=want_steps, want_previous_build=want_previous_build,
+                                  want_logs=want_logs,
+                                  want_logs_content=want_logs_content)
 
     return dict(buildset=buildset, builds=builds)
 
 
 @defer.inlineCallbacks
-def getDetailsForBuild(master, build, wantProperties=False, wantSteps=False,
-                       wantPreviousBuild=False, wantLogs=False):
+def getDetailsForBuild(master, build, want_properties=False, want_steps=False,
+                       want_previous_build=False, want_logs=False, want_logs_content=False):
     buildrequest = yield master.data.get(("buildrequests", build['buildrequestid']))
     buildset = yield master.data.get(("buildsets", buildrequest['buildsetid']))
     build['buildrequest'], build['buildset'] = buildrequest, buildset
@@ -82,14 +83,30 @@ def getDetailsForBuild(master, build, wantProperties=False, wantSteps=False,
     build['parentbuilder'] = parentbuilder
 
     ret = yield getDetailsForBuilds(master, buildset, [build],
-                                    wantProperties=wantProperties, wantSteps=wantSteps,
-                                    wantPreviousBuild=wantPreviousBuild, wantLogs=wantLogs)
+                                    want_properties=want_properties, want_steps=want_steps,
+                                    want_previous_build=want_previous_build,
+                                    want_logs=want_logs,
+                                    want_logs_content=want_logs_content)
     return ret
 
 
 @defer.inlineCallbacks
-def getDetailsForBuilds(master, buildset, builds, wantProperties=False, wantSteps=False,
-                        wantPreviousBuild=False, wantLogs=False):
+def get_details_for_buildrequest(master, buildrequest, build):
+    buildset = yield master.data.get(("buildsets", buildrequest['buildsetid']))
+    builder = yield master.data.get(("builders", buildrequest['builderid']))
+
+    build['buildrequest'] = buildrequest
+    build['buildset'] = buildset
+    build['builderid'] = buildrequest['builderid']
+    build['builder'] = builder
+    build['url'] = getURLForBuildrequest(master, buildrequest['buildrequestid'])
+    build['results'] = None
+    build['complete'] = False
+
+
+@defer.inlineCallbacks
+def getDetailsForBuilds(master, buildset, builds, want_properties=False, want_steps=False,
+                        want_previous_build=False, want_logs=False, want_logs_content=False):
 
     builderids = {build['builderid'] for build in builds}
 
@@ -99,29 +116,38 @@ def getDetailsForBuilds(master, buildset, builds, wantProperties=False, wantStep
     buildersbyid = {builder['builderid']: builder
                     for builder in builders}
 
-    if wantProperties:
+    if want_properties:
         buildproperties = yield defer.gatherResults(
             [master.data.get(("builds", build['buildid'], 'properties'))
              for build in builds])
     else:  # we still need a list for the big zip
         buildproperties = list(range(len(builds)))
 
-    if wantPreviousBuild:
+    if want_previous_build:
         prev_builds = yield defer.gatherResults(
             [getPreviousBuild(master, build) for build in builds])
     else:  # we still need a list for the big zip
         prev_builds = list(range(len(builds)))
 
-    if wantSteps:
+    if want_logs_content:
+        want_logs = True
+    if want_logs:
+        want_steps = True
+
+    if want_steps:  # pylint: disable=too-many-nested-blocks
         buildsteps = yield defer.gatherResults(
             [master.data.get(("builds", build['buildid'], 'steps'))
              for build in builds])
-        if wantLogs:
-            for s in flatten(buildsteps, types=(list, UserList)):
-                logs = yield master.data.get(("steps", s['stepid'], 'logs'))
-                s['logs'] = list(logs)
-                for l in s['logs']:
-                    l['content'] = yield master.data.get(("logs", l['logid'], 'contents'))
+        if want_logs:
+            for build, build_steps in zip(builds, buildsteps):
+                for s in build_steps:
+                    logs = yield master.data.get(("steps", s['stepid'], 'logs'))
+                    s['logs'] = list(logs)
+                    for l in s['logs']:
+                        l['url'] = get_url_for_log(master, build['builderid'], build['number'],
+                                                   s['number'], l['slug'])
+                        if want_logs_content:
+                            l['content'] = yield master.data.get(("logs", l['logid'], 'contents'))
 
     else:  # we still need a list for the big zip
         buildsteps = list(range(len(builds)))
@@ -133,13 +159,13 @@ def getDetailsForBuilds(master, buildset, builds, wantProperties=False, wantStep
         build['url'] = getURLForBuild(
             master, build['builderid'], build['number'])
 
-        if wantProperties:
+        if want_properties:
             build['properties'] = properties
 
-        if wantSteps:
+        if want_steps:
             build['steps'] = list(steps)
 
-        if wantPreviousBuild:
+        if want_previous_build:
             build['prev_build'] = prev
 
 
@@ -203,6 +229,17 @@ def getURLForBuild(master, builderid, build_number):
         build_number)
 
 
+def getURLForBuildrequest(master, buildrequestid):
+    prefix = master.config.buildbotURL
+    return "{}#buildrequests/{}".format(prefix, buildrequestid)
+
+
+def get_url_for_log(master, builderid, build_number, step_number, log_slug):
+    prefix = master.config.buildbotURL
+    return f"{prefix}#builders/{builderid}/builds/{build_number}/" + \
+        f"steps/{step_number}/logs/{log_slug}"
+
+
 @renderer
 def URLForBuild(props):
     build = props.getBuild()
