@@ -141,7 +141,7 @@ class CreateMasterOptions(base.BasedirMixin, base.SubcommandOptions):
     To use a remote MySQL database instead, use something like:
 
       --db='mysql://bbuser:bbpasswd@dbhost/bbdb'
-    The --db string is stored verbatim in the buildbot.tac file, and
+    The --db string is stored verbatim in the master.cfg.sample file, and
     evaluated at 'buildbot start' time to pass a DBConnector instance into
     the newly-created BuildMaster object.
     """)
@@ -218,6 +218,11 @@ class ReconfigOptions(base.BasedirMixin, base.SubcommandOptions):
         ['quiet', 'q', "Don't display log messages about reconfiguration"],
     ]
 
+    optParameters = [
+        ['progress_timeout', None, None,
+         'The amount of time the script waits for messages in the logs that indicate progress.'],
+    ]
+
     def getSynopsis(self):
         return "Usage:    buildbot reconfig [<basedir>]"
 
@@ -651,6 +656,16 @@ class DataSpecOption(base.BasedirMixin, base.SubcommandOptions):
         return "Usage:   buildbot dataspec [options]"
 
 
+class GenGraphQLOption(base.BasedirMixin, base.SubcommandOptions):
+    subcommandFunction = "buildbot.scripts.gengraphql.gengraphql"
+    optParameters = [
+        ['out', 'o', "graphql.schema", "output to specified path"],
+    ]
+
+    def getSynopsis(self):
+        return "Usage:   buildbot graphql-schema [options]"
+
+
 class DevProxyOptions(base.BasedirMixin, base.SubcommandOptions):
 
     """Run a fake web server serving the local ui frontend and a distant rest and websocket api.
@@ -737,6 +752,8 @@ class Options(usage.Options):
         ['dev-proxy', None, DevProxyOptions,
          "Run a fake web server serving the local ui frontend and a distant rest and websocket api."
          ],
+        ['graphql-schema', None, GenGraphQLOption,
+         "Output graphql api schema"],
         ['cleanupdb', None, CleanupDBOptions,
          "cleanup the database"
          ]
