@@ -1,4 +1,5 @@
-# Runs the build-bot as a Windows service.
+# pylint: disable=import-outside-toplevel
+# # Runs the build-bot as a Windows service.
 # To use:
 # * Install and configure buildbot as per normal (ie, running
 #  'setup.py install' from the source directory).
@@ -109,7 +110,7 @@ class BBService(win32serviceutil.ServiceFramework):
                         'see http://buildbot.net'
 
     def __init__(self, args):
-        win32serviceutil.ServiceFramework.__init__(self, args)
+        super().__init__(args)
 
         # Create an event which we will use to wait on. The "service stop"
         # request will set this event.
@@ -134,7 +135,7 @@ class BBService(win32serviceutil.ServiceFramework):
             if os.path.isfile(msg_file):
                 servicemanager.Initialize("BuildBot", msg_file)
             else:
-                self.warning("Strange - '%s' does not exist" % (msg_file, ))
+                self.warning("Strange - '{}' does not exist".format(msg_file))
 
     def _checkConfig(self):
         # Locate our child process runner (but only when run from source)
@@ -155,7 +156,7 @@ class BBService(win32serviceutil.ServiceFramework):
             if me.endswith(".pyc") or me.endswith(".pyo"):
                 me = me[:-1]
 
-            self.runner_prefix = '"%s" "%s"' % (python_exe, me)
+            self.runner_prefix = '"{}" "{}"'.format(python_exe, me)
         else:
             # Running from a py2exe built executable - our child process is
             # us (but with the funky cmdline args!)
@@ -193,8 +194,7 @@ class BBService(win32serviceutil.ServiceFramework):
             if os.path.isfile(sentinal):
                 self.dirs.append(d)
             else:
-                msg = "Directory '%s' is not a buildbot dir - ignoring" \
-                      % (d, )
+                msg = "Directory '{}' is not a buildbot dir - ignoring".format(d)
                 self.warning(msg)
         if not self.dirs:
             self.error("No valid buildbot directories were specified.\n"
@@ -227,12 +227,12 @@ class BBService(win32serviceutil.ServiceFramework):
         child_infos = []
 
         for bbdir in self.dirs:
-            self.info("Starting BuildBot in directory '%s'" % (bbdir, ))
-            hstop = self.hWaitStop
+            self.info("Starting BuildBot in directory '{}'".format(bbdir))
+            # hWaitStop is a Handle but the command needs the int associated
+            # to that Handle
+            hstop = int(self.hWaitStop)
+            cmd = '{} --spawn {} start --nodaemon {}'.format(self.runner_prefix, hstop, bbdir)
 
-            cmd = '%s --spawn %d start --nodaemon %s' % (
-                self.runner_prefix, hstop, bbdir)
-            # print "cmd is", cmd
             h, t, output = self.createProcess(cmd)
             child_infos.append((bbdir, h, t, output))
 
@@ -245,27 +245,26 @@ class BBService(win32serviceutil.ServiceFramework):
             if rc == win32event.WAIT_OBJECT_0:
                 # user sent a stop service request
                 break
-            else:
-                # A child process died.  For now, just log the output
-                # and forget the process.
-                index = rc - win32event.WAIT_OBJECT_0 - 1
-                bbdir, dead_handle, dead_thread, output_blocks = \
-                    child_infos[index]
-                status = win32process.GetExitCodeProcess(dead_handle)
-                output = "".join(output_blocks)
-                if not output:
-                    output = "The child process generated no output. " \
-                             "Please check the twistd.log file in the " \
-                             "indicated directory."
+            # A child process died.  For now, just log the output
+            # and forget the process.
+            index = rc - win32event.WAIT_OBJECT_0 - 1
+            bbdir, dead_handle, _, output_blocks = \
+                child_infos[index]
+            status = win32process.GetExitCodeProcess(dead_handle)
+            output = "".join(output_blocks)
+            if not output:
+                output = ("The child process generated no output. "
+                          "Please check the twistd.log file in the "
+                          "indicated directory.")
 
-                self.warning("BuildBot for directory %r terminated with "
-                             "exit code %d.\n%s" % (bbdir, status, output))
+            self.warning(("BuildBot for directory {} terminated with "
+                          "exit code {}.\n{}").format(repr(bbdir), status, output))
 
-                del child_infos[index]
+            del child_infos[index]
 
-                if not child_infos:
-                    self.warning("All BuildBot child processes have "
-                                 "terminated.  Service stopping.")
+            if not child_infos:
+                self.warning("All BuildBot child processes have "
+                             "terminated.  Service stopping.")
 
         # Either no child processes left, or stop event set.
         self.ReportServiceStatus(win32service.SERVICE_STOP_PENDING)
@@ -297,7 +296,7 @@ class BBService(win32serviceutil.ServiceFramework):
             for i in range(5):
                 t.join(1)
                 self.ReportServiceStatus(win32service.SERVICE_STOP_PENDING)
-                if not t.isAlive():
+                if not t.is_alive():
                     break
             else:
                 self.warning("Redirect thread did not stop!")
@@ -315,7 +314,7 @@ class BBService(win32serviceutil.ServiceFramework):
             servicemanager.LogMsg(servicemanager.EVENTLOG_INFORMATION_TYPE,
                                   event,
                                   (self._svc_name_,
-                                   " (%s)" % self._svc_display_name_))
+                                   " ({})".format(self._svc_display_name_)))
         except win32api.error as details:
             # Failed to write a log entry - most likely problem is
             # that the event log is full.  We don't want this to kill us
@@ -406,7 +405,7 @@ class BBService(win32serviceutil.ServiceFramework):
                 # ERROR_BROKEN_PIPE means the child process closed the
                 # handle - ie, it terminated.
                 if err[0] != winerror.ERROR_BROKEN_PIPE:
-                    self.warning("Error reading output from process: %s" % err)
+                    self.warning("Error reading output from process: {}".format(err))
                 break
             captured_blocks.append(data)
             del captured_blocks[CHILDCAPTURE_MAX_BLOCKS:]
@@ -469,7 +468,7 @@ def RegisterWithFirewall(exe_name, description):
 
 
 def CustomInstall(opts):
-    # Register this process with the Windows Firewaall
+    # Register this process with the Windows Firewall
     import pythoncom
     try:
         RegisterWithFirewall(sys.executable, "BuildBot")
