@@ -46,24 +46,23 @@ class DownloadSecretsToWorker(BuildStep, CompositeStepMixin):
 
     @defer.inlineCallbacks
     def run(self):
-        self._start_deferred = None
         res = yield self.runPopulateSecrets()
         return res
 
 
 class RemoveWorkerFileSecret(BuildStep, CompositeStepMixin):
 
+    renderables = ['secret_to_be_populated']
+
     def __init__(self, populated_secret_list, logEnviron=False, **kwargs):
-        self.paths = []
-        for path, secret in populated_secret_list:
-            self.paths.append(path)
-        self.logEnviron = logEnviron
         super().__init__(**kwargs)
+        self.logEnviron = logEnviron
+        self.secret_to_be_populated = populated_secret_list
 
     @defer.inlineCallbacks
     def runRemoveWorkerFileSecret(self):
         all_results = []
-        for path in self.paths:
+        for path, _ in self.secret_to_be_populated:
             res = yield self.runRmFile(path, abandonOnFailure=False)
             all_results.append(res)
         if FAILURE in all_results:
@@ -74,6 +73,5 @@ class RemoveWorkerFileSecret(BuildStep, CompositeStepMixin):
 
     @defer.inlineCallbacks
     def run(self):
-        self._start_deferred = None
         res = yield self.runRemoveWorkerFileSecret()
         return res
