@@ -17,13 +17,14 @@
 
 import os
 
+from twisted.internet import defer
+
 from buildbot import config
 from buildbot.process import buildstep
 from buildbot.process import logobserver
-from buildbot.steps.shell import ShellCommand
 
 
-class RpmBuild(ShellCommand):
+class RpmBuild(buildstep.ShellMixin, buildstep.BuildStep):
 
     """
     RpmBuild build step.
@@ -49,42 +50,17 @@ class RpmBuild(ShellCommand):
                  autoRelease=False,
                  vcsRevision=False,
                  **kwargs):
-        """
-        Create the RpmBuild object.
-
-        @type specfile: str
-        @param specfile: location of the specfile to build
-        @type topdir: str
-        @param topdir: define the _topdir rpm parameter
-        @type builddir: str
-        @param builddir: define the _builddir rpm parameter
-        @type rpmdir: str
-        @param rpmdir: define the _rpmdir rpm parameter
-        @type sourcedir: str
-        @param sourcedir: define the _sourcedir rpm parameter
-        @type specdir: str
-        @param specdir: define the _specdir rpm parameter
-        @type srcrpmdir: str
-        @param srcrpmdir: define the _srcrpmdir rpm parameter
-        @type dist: str
-        @param dist: define the dist string.
-        @type define: dict
-        @param define: additional parameters to define
-        @type autoRelease: boolean
-        @param autoRelease: Use auto incrementing release numbers.
-        @type vcsRevision: boolean
-        @param vcsRevision: Use vcs version number as revision number.
-        """
+        kwargs = self.setupShellMixin(kwargs, prohibitArgs=['command'])
         super().__init__(**kwargs)
 
         self.dist = dist
 
         self.base_rpmbuild = (
-            'rpmbuild --define "_topdir %s" --define "_builddir %s"'
-            ' --define "_rpmdir %s" --define "_sourcedir %s"'
-            ' --define "_specdir %s" --define "_srcrpmdir %s"'
-            % (topdir, builddir, rpmdir, sourcedir, specdir,
-               srcrpmdir))
+            ('rpmbuild --define "_topdir {}" --define "_builddir {}"'
+             ' --define "_rpmdir {}" --define "_sourcedir {}"'
+             ' --define "_specdir {}" --define "_srcrpmdir {}"').format(topdir, builddir, rpmdir,
+                                                                        sourcedir, specdir,
+                                                                        srcrpmdir))
 
         if define is None:
             define = {}
@@ -101,14 +77,14 @@ class RpmBuild(ShellCommand):
         self.addLogObserver(
             'stdio', logobserver.LineConsumerLogObserver(self.logConsumer))
 
-    def start(self):
+    @defer.inlineCallbacks
+    def run(self):
 
         rpm_extras_dict = {}
         rpm_extras_dict['dist'] = self.dist
 
         if self.autoRelease:
-            relfile = '%s.release' % (
-                os.path.basename(self.specfile).split('.')[0])
+            relfile = '{}.release'.format(os.path.basename(self.specfile).split('.')[0])
             try:
                 with open(relfile, 'r') as rfile:
                     rel = int(rfile.readline().strip())
@@ -132,19 +108,20 @@ class RpmBuild(ShellCommand):
             self.rpmbuild = '{0} --define "{1} {2}"'.format(
                 self.rpmbuild, k, v)
 
-        self.rpmbuild = '{0} -ba {1}'.format(self.rpmbuild, self.specfile)
+        command = '{} -ba {}'.format(self.rpmbuild, self.specfile)
 
-        self.command = self.rpmbuild
+        cmd = yield self.makeRemoteShellCommand(command=command)
 
-        # create the actual RemoteShellCommand instance now
-        kwargs = self.remote_kwargs
-        kwargs['command'] = self.command
-        kwargs['workdir'] = self.workdir
-        cmd = buildstep.RemoteShellCommand(**kwargs)
-        self.setupEnvironment(cmd)
-        self.startCommand(cmd)
-        self.addLogObserver(
-            'stdio', logobserver.LineConsumerLogObserver(self.logConsumer))
+        yield self.runCommand(cmd)
+
+        stdio_log = yield self.getLog('stdio')
+        yield stdio_log.finish()
+
+        yield self.addCompleteLog('RPM Command Log', "\n".join(self.rpmcmdlog))
+        if self.rpmerrors:
+            yield self.addCompleteLog('RPM Errors', "\n".join(self.rpmerrors))
+
+        return cmd.results()
 
     def logConsumer(self):
         rpm_prefixes = ['Provides:', 'Requires(', 'Requires:',
@@ -164,8 +141,3 @@ class RpmBuild(ShellCommand):
                 if line.startswith(err):
                     self.rpmerrors.append(line)
                     break
-
-    def createSummary(self, log):
-        self.addCompleteLog('RPM Command Log', "\n".join(self.rpmcmdlog))
-        if self.rpmerrors:
-            self.addCompleteLog('RPM Errors', "\n".join(self.rpmerrors))
