@@ -19,6 +19,7 @@ from twisted.internet import defer
 from twisted.python import failure
 
 from buildbot.data import connector
+from buildbot.data import resultspec
 from buildbot.db.buildrequests import AlreadyClaimedError
 from buildbot.test.util import validation
 from buildbot.util import service
@@ -216,6 +217,7 @@ class FakeUpdates(service.AsyncService):
         self.builderNames = builderNames
         return defer.succeed(None)
 
+    @defer.inlineCallbacks
     def updateBuilderInfo(self, builderid, description, tags):
         yield self.master.db.builders.updateBuilderInfo(builderid, description, tags)
 
@@ -485,6 +487,7 @@ class FakeDataConnector(service.AsyncMultiService):
         self.realConnector = connector.DataConnector()
         self.realConnector.setServiceParent(self)
         self.rtypes = self.realConnector.rtypes
+        self.plural_rtypes = self.realConnector.plural_rtypes
 
     def _scanModule(self, mod):
         return self.realConnector._scanModule(mod)
@@ -504,7 +507,20 @@ class FakeDataConnector(service.AsyncMultiService):
         return self.realConnector.get(path, filters=filters, fields=fields,
                                       order=order, limit=limit, offset=offset)
 
+    def get_with_resultspec(self, path, rspec):
+        if not isinstance(path, tuple):
+            raise TypeError('path must be a tuple')
+        if not isinstance(rspec, resultspec.ResultSpec):
+            raise TypeError('rspec must be ResultSpec')
+        return self.realConnector.get_with_resultspec(path, rspec)
+
     def control(self, action, args, path):
         if not isinstance(path, tuple):
             raise TypeError('path must be a tuple')
         return self.realConnector.control(action, args, path)
+
+    def resultspec_from_jsonapi(self, args, entityType, is_collection):
+        return self.realConnector.resultspec_from_jsonapi(args, entityType, is_collection)
+
+    def getResourceTypeForGraphQlType(self, type):
+        return self.realConnector.getResourceTypeForGraphQlType(type)
