@@ -33,6 +33,7 @@ class CommandMixinMaster(RunMasterBase):
         change = dict(branch="master",
                       files=["foo.c"],
                       author="me@foo.com",
+                      committer="me@foo.com",
                       comments="good stuff",
                       revision="HEAD",
                       project="none"
@@ -49,9 +50,6 @@ class CommandMixinMasterPB(CommandMixinMaster):
 
 class TestCommandMixinStep(BuildStep, CommandMixin):
 
-    def __init__(self, *args, **kwargs):
-        BuildStep.__init__(self, *args, **kwargs)
-
     @defer.inlineCallbacks
     def run(self):
         contents = yield self.runGlob('*')
