@@ -16,13 +16,14 @@
 
 import locale
 import os
+import pprint
 import shutil
 import sqlite3
 import tarfile
 
-import migrate
-import migrate.versioning.api
-from sqlalchemy.engine import reflection
+import sqlalchemy as sa
+from alembic.autogenerate import compare_metadata
+from alembic.migration import MigrationContext
 from sqlalchemy.exc import DatabaseError
 
 from twisted.internet import defer
@@ -30,7 +31,8 @@ from twisted.python import util
 from twisted.trial import unittest
 
 from buildbot.db import connector
-from buildbot.db.model import EightUpgradeError
+from buildbot.db.model import UpgradeFromBefore0p9Error
+from buildbot.db.model import UpgradeFromBefore3p0Error
 from buildbot.test.fake import fakemaster
 from buildbot.test.util import db
 from buildbot.test.util import querylog
@@ -115,19 +117,22 @@ class UpgradeTestMixin(db.RealDatabaseMixin, TestReactorMixin):
     def tearDown(self):
         return self.tearDownUpgradeTest()
 
+    @defer.inlineCallbacks
     def assertModelMatches(self):
         def comp(engine):
-            # use compare_model_to_db, which gets everything but foreign
-            # keys and indexes
-            diff = migrate.versioning.api.compare_model_to_db(
-                engine,
-                self.db.model.repo_path,
-                self.db.model.metadata)
+            # use compare_model_to_db, which gets everything but indexes
+            with engine.connect() as conn:
+                diff = compare_metadata(MigrationContext.configure(conn), self.db.model.metadata)
+
+            if engine.dialect.name == 'mysql':
+                # MySQL/MyISAM does not support foreign keys, which is expected.
+                diff = [d for d in diff if d[0] != 'add_fk']
+
             if diff:
                 return diff
 
             # check indexes manually
-            insp = reflection.Inspector.from_engine(engine)
+            insp = sa.inspect(engine)
             # unique, name, column_names
             diff = []
             for tbl in self.db.model.metadata.sorted_tables:
@@ -168,49 +173,47 @@ class UpgradeTestMixin(db.RealDatabaseMixin, TestReactorMixin):
                 return "\n".join(diff)
             return None
 
-        d = self.db.pool.do_with_engine(comp)
-
-        # older sqlites cause failures in reflection, which manifest as a
-        # TypeError.  Reflection is only used for tests, so we can just skip
-        # this test on such platforms.  We still get the advantage of trying
-        # the upgrade, at any rate.
-        @d.addErrback
-        def catch_TypeError(f):
-            f.trap(TypeError)
+        try:
+            diff = yield self.db.pool.do_with_engine(comp)
+        except TypeError:
+            # older sqlites cause failures in reflection, which manifest as a
+            # TypeError.  Reflection is only used for tests, so we can just skip
+            # this test on such platforms.  We still get the advantage of trying
+            # the upgrade, at any rate.
             raise unittest.SkipTest("model comparison skipped: bugs in schema "
                                     "reflection on this sqlite version")
 
-        @d.addCallback
-        def check(diff):
-            if diff:
-                self.fail("\n" + str(diff))
-        return d
+        if diff:
+            self.fail("\n" + pprint.pformat(diff))
 
     def gotError(self, e):
-        e.trap(sqlite3.DatabaseError, DatabaseError)
-        if "file is encrypted or is not a database" in str(e):
-            self.flushLoggedErrors(sqlite3.DatabaseError)
-            self.flushLoggedErrors(DatabaseError)
-            raise unittest.SkipTest("sqlite dump not readable on this machine {}".format(str(e)))
-        return e
+        if isinstance(e, (sqlite3.DatabaseError, DatabaseError)):
+            if "file is encrypted or is not a database" in str(e):
+                self.flushLoggedErrors(sqlite3.DatabaseError)
+                self.flushLoggedErrors(DatabaseError)
+                raise unittest.SkipTest(f"sqlite dump not readable on this machine {str(e)}")
 
+    @defer.inlineCallbacks
     def do_test_upgrade(self, pre_callbacks=None):
         if pre_callbacks is None:
             pre_callbacks = []
-        d = defer.succeed(None)
+
         for cb in pre_callbacks:
-            d.addCallback(cb)
-        d.addCallback(lambda _: self.db.model.upgrade())
-        d.addErrback(self.gotError)
-        d.addCallback(lambda _: self.db.pool.do(self.verify_thd))
-        d.addCallback(lambda _: self.assertModelMatches())
-        return d
+            yield cb
+        try:
+            yield self.db.model.upgrade()
+        except Exception as e:
+            self.gotError(e)
+
+        yield self.db.pool.do(self.verify_thd)
+        yield self.assertModelMatches()
 
 
 class UpgradeTestEmpty(UpgradeTestMixin, unittest.TestCase):
 
     use_real_db = True
 
+    @defer.inlineCallbacks
     def test_emptydb_modelmatches(self):
         os_encoding = locale.getpreferredencoding()
         try:
@@ -221,14 +224,13 @@ class UpgradeTestEmpty(UpgradeTestMixin, unittest.TestCase):
             raise unittest.SkipTest("Cannot encode weird unicode "
                 "on this platform with {}".format(os_encoding)) from e
 
-        d = self.db.model.upgrade()
-        d.addCallback(lambda r: self.assertModelMatches())
-        return d
+        yield self.db.model.upgrade()
+        yield self.assertModelMatches()
 
 
-class UpgradeTestV090b4(UpgradeTestMixin, unittest.TestCase):
+class UpgradeTestV2_10_5(UpgradeTestMixin, unittest.TestCase):
 
-    source_tarball = "v090b4.tgz"
+    source_tarball = "v2.10.5.tgz"
 
     def test_upgrade(self):
         return self.do_test_upgrade()
@@ -237,7 +239,7 @@ class UpgradeTestV090b4(UpgradeTestMixin, unittest.TestCase):
         pass
 
     @defer.inlineCallbacks
-    def test_gotError(self):
+    def test_got_invalid_sqlite_file(self):
         def upgrade():
             return defer.fail(sqlite3.DatabaseError('file is encrypted or is not a database'))
         self.db.model.upgrade = upgrade
@@ -245,7 +247,7 @@ class UpgradeTestV090b4(UpgradeTestMixin, unittest.TestCase):
             yield self.do_test_upgrade()
 
     @defer.inlineCallbacks
-    def test_gotError2(self):
+    def test_got_invalid_sqlite_file2(self):
         def upgrade():
             return defer.fail(DatabaseError('file is encrypted or is not a database', None, None))
         self.db.model.upgrade = upgrade
@@ -253,15 +255,33 @@ class UpgradeTestV090b4(UpgradeTestMixin, unittest.TestCase):
             yield self.do_test_upgrade()
 
 
+class UpgradeTestV090b4(UpgradeTestMixin, unittest.TestCase):
+
+    source_tarball = "v090b4.tgz"
+
+    def gotError(self, e):
+        self.flushLoggedErrors(UpgradeFromBefore3p0Error)
+
+    def test_upgrade(self):
+        return self.do_test_upgrade()
+
+    def verify_thd(self, conn):
+        r = conn.execute("select version from migrate_version limit 1")
+        version = r.scalar()
+        self.assertEqual(version, 44)
+
+    def assertModelMatches(self):
+        pass
+
+
 class UpgradeTestV087p1(UpgradeTestMixin, unittest.TestCase):
 
     source_tarball = "v087p1.tgz"
 
     def gotError(self, e):
-        self.flushLoggedErrors(EightUpgradeError)
+        self.flushLoggedErrors(UpgradeFromBefore0p9Error)
 
     def verify_thd(self, conn):
-        "partially verify the contents of the db - run in a thread"
         r = conn.execute("select version from migrate_version limit 1")
         version = r.scalar()
         self.assertEqual(version, 22)
