@@ -13,6 +13,7 @@
 #
 # Copyright Buildbot Team Members
 
+import copy
 import datetime
 import json
 import types
@@ -20,7 +21,6 @@ import types
 from twisted.internet import defer
 from twisted.internet import error
 from twisted.internet import reactor
-from twisted.internet import utils
 from twisted.python import failure
 from twisted.trial import unittest
 
@@ -30,6 +30,8 @@ from buildbot.test.fake import httpclientservice as fakehttpclientservice
 from buildbot.test.fake.change import Change
 from buildbot.test.util import changesource
 from buildbot.test.util.misc import TestReactorMixin
+from buildbot.test.util.runprocess import ExpectMaster
+from buildbot.test.util.runprocess import MasterRunProcessMixin
 
 
 class TestGerritHelpers(unittest.TestCase):
@@ -86,122 +88,339 @@ class TestGerritHelpers(unittest.TestCase):
                          }, "gerrit"))
 
 
-class TestGerritChangeSource(changesource.ChangeSourceMixin,
+class TestGerritChangeSource(MasterRunProcessMixin, changesource.ChangeSourceMixin,
                              TestReactorMixin,
                              unittest.TestCase):
 
     def setUp(self):
         self.setUpTestReactor()
+        self.setup_master_run_process()
         return self.setUpChangeSource()
 
     def tearDown(self):
         return self.tearDownChangeSource()
 
+    @defer.inlineCallbacks
     def newChangeSource(self, host, user, *args, **kwargs):
         s = gerritchangesource.GerritChangeSource(
             host, user, *args, **kwargs)
-        self.attachChangeSource(s)
+        yield self.attachChangeSource(s)
         s.configureService()
         return s
 
+    def assert_changes(self, expected_changes, ignore_keys):
+        self.assertEqual(len(self.master.data.updates.changesAdded), len(expected_changes))
+        for i, expected_change in enumerate(expected_changes):
+            change = self.master.data.updates.changesAdded[i]
+            for key in ignore_keys:
+                del change[key]
+            self.assertEqual(change, expected_change)
+
     # tests
 
+    @defer.inlineCallbacks
     def test_describe(self):
-        s = self.newChangeSource('somehost', 'someuser')
+        s = yield self.newChangeSource('somehost', 'someuser')
         self.assertSubstring("GerritChangeSource", s.describe())
 
+    @defer.inlineCallbacks
     def test_name(self):
-        s = self.newChangeSource('somehost', 'someuser')
+        s = yield self.newChangeSource('somehost', 'someuser')
         self.assertEqual("GerritChangeSource:someuser@somehost:29418", s.name)
 
-        s = self.newChangeSource('somehost', 'someuser', name="MyName")
+        s = yield self.newChangeSource('somehost', 'someuser', name="MyName")
         self.assertEqual("MyName", s.name)
 
     # TODO: test the backoff algorithm
 
+    patchset_created_event = {
+        "uploader": {
+            'name': 'uploader uploader',
+            'email': 'uploader@example.com',
+            'username': 'uploader'
+        },
+        "patchSet": {
+            "number": 1,
+            "revision": "29b73c3eb1aeaa9e6c7da520a940d60810e883db",
+            "parents": ["7e563631188dcadf32aad0d8647c818834921a1e"],
+            "ref": "refs/changes/21/4321/1",
+            "uploader": {
+                'name': 'uploader uploader',
+                'email': 'uploader@example.com',
+                'username': 'uploader'
+            },
+            "createdOn": 1627214047,
+            "author": {
+                'name': 'author author',
+                'email': 'author@example.com',
+                'username': 'author'
+            },
+            "kind": "REWORK",
+            "sizeInsertions": 1,
+            "sizeDeletions": 0
+        },
+        "change": {
+            "project": "test",
+            "branch": "master",
+            "id": "I21234123412341234123412341234",
+            "number": 4321,
+            "subject": "change subject",
+            "owner": {
+                'name': 'owner owner',
+                'email': 'owner@example.com',
+                'username': 'owner'
+            },
+            "url": "http://example.com/c/test/+/4321",
+            "commitMessage": "test1\n\nChange-Id: I21234123412341234123412341234\n",
+            "createdOn": 1627214047,
+            "status": "NEW"
+        },
+        "project": "test",
+        "refName": "refs/heads/master",
+        "changeKey": {"id": "I21234123412341234123412341234"},
+        "type": "patchset-created",
+        "eventCreatedOn": 1627214048
+    }
+
     # this variable is reused in test_steps_source_repo
     # to ensure correct integration between change source and repo step
-    expected_change = {'category': 'patchset-created',
-                       'files': ['unknown'],
-                       'repository': 'ssh://someuser@somehost:29418/pr',
-                       'author': 'Dustin <dustin@mozilla.com>',
-                       'committer': None,
-                       'comments': 'fix 1234',
-                       'project': 'pr',
-                       'branch': 'br/4321',
-                       'revlink': 'http://buildbot.net',
-                       'codebase': None,
-                       'revision': 'abcdef',
-                       'src': None,
-                       'when_timestamp': None,
-                       'properties': {'event.change.owner.email': 'dustin@mozilla.com',
-                                      'event.change.subject': 'fix 1234',
-                                      'event.change.project': 'pr',
-                                      'event.change.owner.name': 'Dustin',
-                                      'event.change.number': '4321',
-                                      'event.change.url': 'http://buildbot.net',
-                                      'event.change.branch': 'br',
-                                      'event.type': 'patchset-created',
-                                      'event.patchSet.revision': 'abcdef',
-                                      'event.patchSet.number': '12',
-                                      'event.source': 'GerritChangeSource'}}
+    expected_change_patchset_created = {
+        'category': 'patchset-created',
+        'files': ['unknown'],
+        'repository': 'ssh://someuser@somehost:29418/test',
+        'author': 'owner owner <owner@example.com>',
+        'committer': None,
+        'comments': 'change subject',
+        'project': 'test',
+        'branch': 'refs/changes/21/4321/1',
+        'revision': '29b73c3eb1aeaa9e6c7da520a940d60810e883db',
+        'codebase': None,
+        'revlink': 'http://example.com/c/test/+/4321',
+        'src': None,
+        'when_timestamp': None,
+    }
 
     @defer.inlineCallbacks
     def test_lineReceived_patchset_created(self):
-        s = self.newChangeSource('somehost', 'someuser')
-        yield s.lineReceived(json.dumps(dict(
-            type="patchset-created",
-            change=dict(
-                branch="br",
-                project="pr",
-                number="4321",
-                owner=dict(name="Dustin", email="dustin@mozilla.com"),
-                url="http://buildbot.net",
-                subject="fix 1234"
-            ),
-            patchSet=dict(revision="abcdef", number="12")
-        )))
+        s = yield self.newChangeSource('somehost', 'someuser')
+        yield s.lineReceived(json.dumps(self.patchset_created_event))
 
+        self.assert_changes([self.expected_change_patchset_created], ignore_keys=['properties'])
+
+    @defer.inlineCallbacks
+    def test_lineReceived_patchset_created_props(self):
+        s = yield self.newChangeSource('somehost', 'someuser')
+        yield s.lineReceived(json.dumps(self.patchset_created_event))
+
+        change = copy.deepcopy(self.expected_change_patchset_created)
+        change['properties'] = {
+            'event.change.branch': 'master',
+            'event.change.commitMessage': 'test1\n\nChange-Id: I21234123412341234123412341234\n',
+            'event.change.createdOn': 1627214047,
+            'event.change.id': 'I21234123412341234123412341234',
+            'event.change.number': 4321,
+            'event.change.owner.email': 'owner@example.com',
+            'event.change.owner.name': 'owner owner',
+            'event.change.owner.username': 'owner',
+            'event.change.project': 'test',
+            'event.change.status': 'NEW',
+            'event.change.subject': 'change subject',
+            'event.change.url': 'http://example.com/c/test/+/4321',
+            'event.changeKey.id': 'I21234123412341234123412341234',
+            'event.patchSet.author.email': 'author@example.com',
+            'event.patchSet.author.name': 'author author',
+            'event.patchSet.author.username': 'author',
+            'event.patchSet.createdOn': 1627214047,
+            'event.patchSet.kind': 'REWORK',
+            'event.patchSet.number': 1,
+            'event.patchSet.parents': ['7e563631188dcadf32aad0d8647c818834921a1e'],
+            'event.patchSet.ref': 'refs/changes/21/4321/1',
+            'event.patchSet.revision': '29b73c3eb1aeaa9e6c7da520a940d60810e883db',
+            'event.patchSet.sizeDeletions': 0,
+            'event.patchSet.sizeInsertions': 1,
+            'event.patchSet.uploader.email': 'uploader@example.com',
+            'event.patchSet.uploader.name': 'uploader uploader',
+            'event.patchSet.uploader.username': 'uploader',
+            'event.project': 'test',
+            'event.refName': 'refs/heads/master',
+            'event.source': 'GerritChangeSource',
+            'event.type': 'patchset-created',
+            'event.uploader.email': 'uploader@example.com',
+            'event.uploader.name': 'uploader uploader',
+            'event.uploader.username': 'uploader',
+            'target_branch': 'master',
+        }
+        self.maxDiff = None
+        self.assert_changes([change], ignore_keys=[])
+
+    comment_added_event = {
+        "type": "comment-added",
+        "author": {
+            'name': 'author author',
+            'email': 'author@example.com',
+            'username': 'author'
+        },
+        "approvals": [{"type": "Code-Review", "description": "Code-Review", "value": "0"}],
+        "comment": "Patch Set 1:\n\ntest comment",
+        "patchSet": {
+            "number": 1,
+            "revision": "29b73c3eb1aeaa9e6c7da520a940d60810e883db",
+            "parents": ["7e563631188dcadf32aad0d8647c818834921a1e"],
+            "ref": "refs/changes/21/4321/1",
+            "uploader": {
+                'name': 'uploader uploader',
+                'email': 'uploader@example.com',
+                'username': 'uploader'
+            },
+            "createdOn": 1627214047,
+            "author": {
+                'name': 'author author',
+                'email': 'author@example.com',
+                'username': 'author'
+            },
+            "kind": "REWORK",
+            "sizeInsertions": 1,
+            "sizeDeletions": 0
+        },
+        "change": {
+            "project": "test",
+            "branch": "master",
+            "id": "I21234123412341234123412341234",
+            "number": 4321,
+            "subject": "change subject",
+            "owner": {
+                'name': 'owner owner',
+                'email': 'owner@example.com',
+                'username': 'owner'
+            },
+            "url": "http://example.com/c/test/+/4321",
+            "commitMessage": "test1\n\nChange-Id: I21234123412341234123412341234\n",
+            "createdOn": 1627214047,
+            "status": "NEW"
+        },
+        "project": "test",
+        "refName": "refs/heads/master",
+        "changeKey": {"id": "I21234123412341234123412341234"},
+        "eventCreatedOn": 1627214102
+    }
+
+    expected_change_comment_added = {
+        'category': 'comment-added',
+        'files': ['unknown'],
+        'repository': 'ssh://someuser@somehost:29418/test',
+        'author': 'owner owner <owner@example.com>',
+        'committer': None,
+        'comments': 'change subject',
+        'project': 'test',
+        'branch': 'refs/changes/21/4321/1',
+        'revlink': 'http://example.com/c/test/+/4321',
+        'codebase': None,
+        'revision': '29b73c3eb1aeaa9e6c7da520a940d60810e883db',
+        'src': None,
+        'when_timestamp': None,
+    }
+
+    @defer.inlineCallbacks
+    def test_lineReceived_comment_added(self):
+        s = yield self.newChangeSource('somehost', 'someuser', handled_events=["comment-added"])
+        yield s.lineReceived(json.dumps(self.comment_added_event))
+
+        self.assert_changes([self.expected_change_comment_added], ignore_keys=['properties'])
+
+    @defer.inlineCallbacks
+    def test_lineReceived_ref_updated(self):
+        s = yield self.newChangeSource('somehost', 'someuser')
+        yield s.lineReceived(json.dumps({
+            'type': 'ref-updated',
+            'submitter': {
+                'name': 'tester',
+                'email': 'tester@example.com',
+                'username': 'tester'
+            },
+            'refUpdate': {
+                'oldRev': '12341234',
+                'newRev': '56785678',
+                'refName': 'refs/heads/master',
+                'project': 'test'
+            },
+            'eventCreatedOn': 1614528683
+        }))
         self.assertEqual(len(self.master.data.updates.changesAdded), 1)
         c = self.master.data.updates.changesAdded[0]
-        for k, v in c.items():
-            self.assertEqual(self.expected_change[k], v)
+        self.assertEqual(c, {
+            'files': ['unknown'],
+            'comments': 'Gerrit: commit(s) pushed.',
+            'author': 'tester <tester@example.com>',
+            'committer': None,
+            'revision': '56785678',
+            'when_timestamp': None,
+            'branch': 'refs/heads/master',
+            'category': 'ref-updated',
+            'revlink': '',
+            'properties': {
+                'event.type': 'ref-updated',
+                'event.submitter.name': 'tester',
+                'event.submitter.email':
+                    'tester@example.com',
+                    'event.submitter.username': 'tester',
+                    'event.refUpdate.oldRev': '12341234',
+                    'event.refUpdate.newRev': '56785678',
+                    'event.refUpdate.refName': 'refs/heads/master',
+                    'event.refUpdate.project': 'test',
+                    'event.source': 'GerritChangeSource'
+                },
+            'repository': 'ssh://someuser@somehost:29418/test',
+            'codebase': None,
+            'project': 'test',
+            'src': None
+        })
+
+    @defer.inlineCallbacks
+    def test_lineReceived_ref_updated_for_change(self):
+        s = yield self.newChangeSource('somehost', 'someuser')
+        yield s.lineReceived(json.dumps({
+            'type': 'ref-updated',
+            'submitter': {
+                'name': 'tester',
+                'email': 'tester@example.com',
+                'username': 'tester'
+            },
+            'refUpdate': {
+                'oldRev': '00000000',
+                'newRev': '56785678',
+                'refName': 'refs/changes/12/432112/1',
+                'project': 'test'
+            },
+            'eventCreatedOn': 1614528683
+        }))
+        self.assertEqual(len(self.master.data.updates.changesAdded), 0)
 
     @defer.inlineCallbacks
     def test_duplicate_events_ignored(self):
-        s = self.newChangeSource('somehost', 'someuser')
-        yield s.lineReceived(json.dumps(dict(
-            type="patchset-created",
-            change=dict(
-                branch="br",
-                project="pr",
-                number="4321",
-                owner=dict(name="Dustin", email="dustin@mozilla.com"),
-                url="http://buildbot.net",
-                subject="fix 1234"
-            ),
-            patchSet=dict(revision="abcdef", number="12")
-        )))
+        s = yield self.newChangeSource('somehost', 'someuser')
+        yield s.lineReceived(json.dumps(self.patchset_created_event))
         self.assertEqual(len(self.master.data.updates.changesAdded), 1)
 
-        yield s.lineReceived(json.dumps(dict(
-            type="patchset-created",
-            change=dict(
-                branch="br",
-                # Note that this time "project" is a dictionary
-                project=dict(name="pr"),
-                number="4321",
-                owner=dict(name="Dustin", email="dustin@mozilla.com"),
-                url="http://buildbot.net",
-                subject="fix 1234"
-            ),
-            patchSet=dict(revision="abcdef", number="12")
-        )))
+        patchset_created_event = copy.deepcopy(self.patchset_created_event)
+        patchset_created_event['change']['project'] = {'name': 'test'}
+
+        yield s.lineReceived(json.dumps(patchset_created_event))
         self.assertEqual(len(self.master.data.updates.changesAdded), 1)
 
+    @defer.inlineCallbacks
+    def test_duplicate_non_source_events_not_ignored(self):
+        s = yield self.newChangeSource('somehost', 'someuser',
+                                       handled_events=['patchset-created', 'ref-updated',
+                                                       'change-merged', 'comment-added'])
+        yield s.lineReceived(json.dumps(self.comment_added_event))
+        self.assertEqual(len(self.master.data.updates.changesAdded), 1)
+
+        yield s.lineReceived(json.dumps(self.comment_added_event))
+        self.assertEqual(len(self.master.data.updates.changesAdded), 2)
+
     @defer.inlineCallbacks
     def test_malformed_events_ignored(self):
-        s = self.newChangeSource('somehost', 'someuser')
+        s = yield self.newChangeSource('somehost', 'someuser')
         # "change" not in event
         yield s.lineReceived(json.dumps(dict(
             type="patchset-created",
@@ -238,8 +457,8 @@ class TestGerritChangeSource(changesource.ChangeSourceMixin,
 
     @defer.inlineCallbacks
     def test_handled_events_filter_true(self):
-        s = self.newChangeSource(
-            'somehost', 'some_choosy_user', handled_events=["change-merged"])
+        s = yield self.newChangeSource('somehost', 'some_choosy_user',
+                                       handled_events=["change-merged"])
         yield s.lineReceived(json.dumps(self.change_merged_event))
 
         self.assertEqual(len(self.master.data.updates.changesAdded), 1)
@@ -249,15 +468,14 @@ class TestGerritChangeSource(changesource.ChangeSourceMixin,
 
     @defer.inlineCallbacks
     def test_handled_events_filter_false(self):
-        s = self.newChangeSource('somehost', 'some_choosy_user')
+        s = yield self.newChangeSource('somehost', 'some_choosy_user')
         yield s.lineReceived(json.dumps(self.change_merged_event))
         self.assertEqual(len(self.master.data.updates.changesAdded), 0)
 
     @defer.inlineCallbacks
     def test_custom_handler(self):
-        s = self.newChangeSource(
-            'somehost', 'some_choosy_user',
-            handled_events=["change-merged"])
+        s = yield self.newChangeSource('somehost', 'some_choosy_user',
+                                       handled_events=["change-merged"])
 
         def custom_handler(self, properties, event):
             event['change']['project'] = "world"
@@ -270,11 +488,11 @@ class TestGerritChangeSource(changesource.ChangeSourceMixin,
         c = self.master.data.updates.changesAdded[0]
         self.assertEqual(c['project'], "world")
 
+    @defer.inlineCallbacks
     def test_startStreamProcess_bytes_output(self):
-        s = self.newChangeSource(
-            'somehost', 'some_choosy_user', debug=True)
+        s = yield self.newChangeSource('somehost', 'some_choosy_user', debug=True)
 
-        exp_argv = ['ssh', 'some_choosy_user@somehost', '-p', '29418']
+        exp_argv = ['ssh', '-o', 'BatchMode=yes', 'some_choosy_user@somehost', '-p', '29418']
         exp_argv += ['gerrit', 'stream-events']
 
         def spawnProcess(pp, cmd, argv, env):
@@ -322,40 +540,44 @@ class TestGerritChangeSource(changesource.ChangeSourceMixin,
 
     @defer.inlineCallbacks
     def test_getFiles(self):
-        s = self.newChangeSource('host', 'user', gerritport=2222)
+        s = yield self.newChangeSource('host', 'user', gerritport=2222)
         exp_argv = [
-            'ssh', 'user@host', '-p', '2222', 'gerrit', 'query', '1000',
-            '--format', 'JSON', '--files', '--patch-sets'
+            'ssh', '-o', 'BatchMode=yes', 'user@host', '-p', '2222',
+            'gerrit', 'query', '1000', '--format', 'JSON', '--files', '--patch-sets'
         ]
 
-        def getoutput_success(cmd, argv, env):
-            self.assertEqual([cmd, argv], [exp_argv[0], exp_argv[1:]])
-            return self.query_files_success
+        self.expect_commands(
+            ExpectMaster(exp_argv)
+            .stdout(self.query_files_success),
+            ExpectMaster(exp_argv)
+            .stdout(self.query_files_failure)
+        )
 
-        def getoutput_failure(cmd, argv, env):
-            return self.query_files_failure
-
-        self.patch(utils, 'getProcessOutput', getoutput_success)
         res = yield s.getFiles(1000, 13)
         self.assertEqual(set(res), {'/COMMIT_MSG', 'file1', 'file2'})
 
-        self.patch(utils, 'getProcessOutput', getoutput_failure)
         res = yield s.getFiles(1000, 13)
         self.assertEqual(res, ['unknown'])
 
+        self.assert_all_commands_ran()
+
     @defer.inlineCallbacks
     def test_getFilesFromEvent(self):
-        s = self.newChangeSource('host', 'user', get_files=True,
-                                 handled_events=["change-merged"])
+        self.expect_commands(
+            ExpectMaster(['ssh', '-o', 'BatchMode=yes', 'user@host', '-p', '29418', 'gerrit',
+                          'query', '4321', '--format', 'JSON', '--files', '--patch-sets'])
+            .stdout(self.query_files_success)
+        )
 
-        def getoutput(cmd, argv, env):
-            return self.query_files_success
-        self.patch(utils, 'getProcessOutput', getoutput)
+        s = yield self.newChangeSource('host', 'user', get_files=True,
+                                       handled_events=["change-merged"])
 
         yield s.lineReceived(json.dumps(self.change_merged_event))
         c = self.master.data.updates.changesAdded[0]
         self.assertEqual(set(c['files']), {'/COMMIT_MSG', 'file1', 'file2'})
 
+        self.assert_all_commands_ran()
+
 
 class TestGerritEventLogPoller(changesource.ChangeSourceMixin,
                                TestReactorMixin,
@@ -427,20 +649,24 @@ class TestGerritEventLogPoller(changesource.ChangeSourceMixin,
                           content_json=dict(
                               type="patchset-created",
                               change=dict(
-                                  branch="br",
-                                  project="pr",
+                                  branch="master",
+                                  project="test",
                                   number="4321",
-                                  owner=dict(name="Dustin",
-                                             email="dustin@mozilla.com"),
-                                  url="http://buildbot.net",
-                                  subject="fix 1234"
+                                  owner=dict(name="owner owner",
+                                             email="owner@example.com"),
+                                  url="http://example.com/c/test/+/4321",
+                                  subject="change subject"
                               ),
                               eventCreatedOn=self.EVENT_TIMESTAMP,
-                              patchSet=dict(revision="abcdef", number="12")))
+                              patchSet={
+                                  'revision': "29b73c3eb1aeaa9e6c7da520a940d60810e883db",
+                                  'number': "1",
+                                  'ref': 'refs/changes/21/4321/1'}
+                              ))
 
         self._http.expect(
             method='get',
-            ep='/changes/4321/revisions/12/files/',
+            ep='/changes/4321/revisions/1/files/',
             content=self.change_revision_resp,
         )
 
@@ -450,11 +676,9 @@ class TestGerritEventLogPoller(changesource.ChangeSourceMixin,
         self.assertEqual(len(self.master.data.updates.changesAdded), 1)
 
         c = self.master.data.updates.changesAdded[0]
-        expected_change = dict(TestGerritChangeSource.expected_change)
-        expected_change['properties'] = dict(expected_change['properties'])
-        expected_change['properties']['event.source'] = 'GerritEventLogPoller'
+        expected_change = dict(TestGerritChangeSource.expected_change_patchset_created)
         for k, v in c.items():
-            if k == 'files':
+            if k in ('files', 'properties'):
                 continue
             self.assertEqual(expected_change[k], v)
         self.master.db.state.assertState(
@@ -477,11 +701,15 @@ class TestGerritEventLogPoller(changesource.ChangeSourceMixin,
                                   subject="fix 1234"
                               ),
                               eventCreatedOn=self.EVENT_TIMESTAMP + 1,
-                              patchSet=dict(revision="abcdef", number="12")))
+                              patchSet={
+                                  'revision': "29b73c3eb1aeaa9e6c7da520a940d60810e883db",
+                                  'number': "1",
+                                  'ref': 'refs/changes/21/4321/1'}
+                              ))
 
         self._http.expect(
             method='get',
-            ep='/changes/4321/revisions/12/files/',
+            ep='/changes/4321/revisions/1/files/',
             content=self.change_revision_resp,
         )
 
@@ -513,18 +741,22 @@ class TestGerritEventLogPoller(changesource.ChangeSourceMixin,
 class TestGerritChangeFilter(unittest.TestCase):
 
     def test_basic(self):
+        props = {
+            'event.type': 'patchset-created',
+            'event.change.branch': 'master',
+        }
 
-        ch = Change(**TestGerritChangeSource.expected_change)
+        ch = Change(**TestGerritChangeSource.expected_change_patchset_created, properties=props)
         f = gerritchangesource.GerritChangeFilter(
-            branch=["br"], eventtype=["patchset-created"])
+            branch=["master"], eventtype=["patchset-created"])
         self.assertTrue(f.filter_change(ch))
         f = gerritchangesource.GerritChangeFilter(
-            branch="br2", eventtype=["patchset-created"])
+            branch="master2", eventtype=["patchset-created"])
         self.assertFalse(f.filter_change(ch))
         f = gerritchangesource.GerritChangeFilter(
-            branch="br", eventtype="ref-updated")
+            branch="master", eventtype="ref-updated")
         self.assertFalse(f.filter_change(ch))
         self.assertEqual(
             repr(f),
-            '<GerritChangeFilter on prop:event.change.branch == br and '
+            '<GerritChangeFilter on prop:event.change.branch == master and '
             'prop:event.type == ref-updated>')
