@@ -108,6 +108,7 @@ class TestDataConnector(TestReactorMixin, unittest.TestCase, Tests):
 
 
 class DataConnector(TestReactorMixin, unittest.TestCase):
+    maxDiff = None
 
     @defer.inlineCallbacks
     def setUp(self):
@@ -153,7 +154,7 @@ class DataConnector(TestReactorMixin, unittest.TestCase):
         self.assertIsInstance(match[0], TestEndpoint)
         match = self.data.matcher[('test', '10', 'p2')]
         self.assertIsInstance(match[0], TestEndpoint)
-        match = self.data.matcher[('test',)]
+        match = self.data.matcher[('tests',)]
         self.assertIsInstance(match[0], TestsEndpoint)
         self.assertEqual(match[1], dict())
         match = self.data.matcher[('test', 'foo')]
@@ -220,11 +221,12 @@ class DataConnector(TestReactorMixin, unittest.TestCase):
         ep.control.assert_called_once_with('foo!', {'arg': 2},
                                            {'fooid': 10})
 
+
 # classes discovered by test_scanModule, above
 
 
 class TestsEndpoint(base.Endpoint):
-    pathPatterns = "/test"
+    pathPatterns = "/tests"
     rootLinkName = 'tests'
 
 
@@ -246,12 +248,14 @@ class TestEndpoint(base.Endpoint):
 
 class TestResourceType(base.ResourceType):
     name = 'test'
+    plural = 'tests'
+
     endpoints = [TestsEndpoint, TestEndpoint, TestsEndpointSubclass]
-    keyFields = ('testid', )
+    keyField = 'testid'
 
     class EntityType(types.Entity):
         testid = types.Integer()
-    entityType = EntityType(name)
+    entityType = EntityType(name, 'Test')
 
     @base.updateMethod
     def testUpdate(self):
