@@ -181,6 +181,13 @@ class Tests(TestReactorMixin, unittest.TestCase):
             'type': 's',
         })
 
+    @defer.inlineCallbacks
+    def test_unyielded_finish(self):
+        _log = yield self.makeLog('s')
+        _log.finish()
+        with self.assertRaises(AssertionError):
+            yield _log.finish()
+
     @defer.inlineCallbacks
     def test_isFinished(self):
         _log = yield self.makeLog('s')
