@@ -164,7 +164,7 @@ class TestGerritStatusPush(TestReactorMixin, unittest.TestCase,
     @defer.inlineCallbacks
     def setupBuildResults(self, buildResults, finalResult):
         self.insertTestData(buildResults, finalResult)
-        res = yield utils.getDetailsForBuildset(self.master, 98, wantProperties=True)
+        res = yield utils.getDetailsForBuildset(self.master, 98, want_properties=True)
         builds = res['builds']
         buildset = res['buildset']
 
@@ -257,14 +257,14 @@ class TestGerritStatusPush(TestReactorMixin, unittest.TestCase,
         without_identity = yield self.setupGerritStatusPush(**kwargs)
 
         expected1 = [
-            'ssh', 'buildbot@example.com', '-p', '29418', 'gerrit', 'foo']
+            'ssh', '-o', 'BatchMode=yes', 'buildbot@example.com', '-p', '29418', 'gerrit', 'foo']
         self.assertEqual(expected1, without_identity._gerritCmd('foo'))
         yield without_identity.disownServiceParent()
         with_identity = yield self.setupGerritStatusPush(
             identity_file='/path/to/id_rsa', **kwargs)
         expected2 = [
-            'ssh', '-i', '/path/to/id_rsa', 'buildbot@example.com', '-p', '29418',
-            'gerrit', 'foo',
+            'ssh', '-o', 'BatchMode=yes', '-i', '/path/to/id_rsa', 'buildbot@example.com',
+            '-p', '29418', 'gerrit', 'foo',
         ]
         self.assertEqual(expected2, with_identity._gerritCmd('foo'))
 
@@ -455,15 +455,18 @@ class TestGerritStatusPush(TestReactorMixin, unittest.TestCase,
         yield gsp.sendCodeReview("project", "revision",
                                 {"message": "bla", "labels": {'Verified': 1}})
         spawnSkipFirstArg.assert_called_once_with(
-            'ssh', ['ssh', 'user@serv', '-p', '29418', 'gerrit', 'version'], env=None)
+            'ssh',
+            ['ssh', '-o', 'BatchMode=yes', 'user@serv', '-p', '29418', 'gerrit', 'version'],
+            env=None)
         gsp.processVersion(parse_version("2.6"), lambda: None)
         spawnSkipFirstArg = Mock()
         yield gsp.sendCodeReview("project", "revision",
                                 {"message": "bla", "labels": {'Verified': 1}})
         spawnSkipFirstArg.assert_called_once_with(
             'ssh',
-            ['ssh', 'user@serv', '-p', '29418', 'gerrit', 'review',
-             '--project project', "--message 'bla'", '--label Verified=1', 'revision'], env=None)
+            ['ssh', '-o', 'BatchMode=yes', 'user@serv', '-p', '29418', 'gerrit', 'review',
+             '--project project', "--message 'bla'", '--label Verified=1', 'revision'],
+            env=None)
 
         # <=2.5 uses other syntax
         gsp.processVersion(parse_version("2.4"), lambda: None)
@@ -472,8 +475,9 @@ class TestGerritStatusPush(TestReactorMixin, unittest.TestCase,
                                  {"message": "bla", "labels": {'Verified': 1}})
         spawnSkipFirstArg.assert_called_once_with(
             'ssh',
-            ['ssh', 'user@serv', '-p', '29418', 'gerrit', 'review', '--project project',
-             "--message 'bla'", '--verified 1', 'revision'], env=None)
+            ['ssh', '-o', 'BatchMode=yes', 'user@serv', '-p', '29418', 'gerrit', 'review',
+            '--project project', "--message 'bla'", '--verified 1', 'revision'],
+            env=None)
 
         # now test the notify argument, even though _gerrit_notify
         # is private, work around that
@@ -484,7 +488,7 @@ class TestGerritStatusPush(TestReactorMixin, unittest.TestCase,
                                  {'message': 'bla', 'labels': {'Verified': 1}})
         spawnSkipFirstArg.assert_called_once_with(
             'ssh',
-            ['ssh', 'user@serv', '-p', '29418', 'gerrit', 'review',
+            ['ssh', '-o', 'BatchMode=yes', 'user@serv', '-p', '29418', 'gerrit', 'review',
              '--project project', '--notify OWNER', "--message 'bla'", '--label Verified=1',
              'revision'],
             env=None)
@@ -496,8 +500,8 @@ class TestGerritStatusPush(TestReactorMixin, unittest.TestCase,
                                  {'message': 'bla', 'labels': {'Verified': 1}})
         spawnSkipFirstArg.assert_called_once_with(
             'ssh',
-            ['ssh', 'user@serv', '-p', '29418', 'gerrit', 'review', '--project project',
-            '--notify OWNER', "--message 'bla'", '--verified 1', 'revision'],
+            ['ssh', '-o', 'BatchMode=yes', 'user@serv', '-p', '29418', 'gerrit', 'review',
+            '--project project', '--notify OWNER', "--message 'bla'", '--verified 1', 'revision'],
             env=None)
 
         gsp.processVersion(parse_version("2.13"), lambda: None)
@@ -506,14 +510,14 @@ class TestGerritStatusPush(TestReactorMixin, unittest.TestCase,
                                  {"message": "bla", "labels": {'Verified': 1}})
         spawnSkipFirstArg.assert_called_once_with(
             'ssh',
-            ['ssh', 'user@serv', '-p', '29418', 'gerrit', 'review',
+            ['ssh', '-o', 'BatchMode=yes', 'user@serv', '-p', '29418', 'gerrit', 'review',
              '--project project', '--tag autogenerated:buildbot', '--notify OWNER',
              "--message 'bla'", '--label Verified=1', 'revision'], env=None)
 
     @defer.inlineCallbacks
     def test_callWithVersion_bytes_output(self):
         gsp = yield self.setupGerritStatusPushSimple()
-        exp_argv = ['ssh', 'user@serv', '-p', '29418', 'gerrit', 'version']
+        exp_argv = ['ssh', '-o', 'BatchMode=yes', 'user@serv', '-p', '29418', 'gerrit', 'version']
 
         def spawnProcess(pp, cmd, argv, env):
             self.assertEqual([cmd, argv], [exp_argv[0], exp_argv])
