@@ -37,7 +37,7 @@ from buildbot.test.util.misc import TestReactorMixin
 _COMSPEC_ENV = 'COMSPEC'
 
 
-class TestMasterShellCommandNewStyle(steps.BuildStepMixin, TestReactorMixin,
+class TestMasterShellCommand(steps.BuildStepMixin, TestReactorMixin,
                              unittest.TestCase):
 
     def setUp(self):
@@ -75,7 +75,7 @@ class TestMasterShellCommandNewStyle(steps.BuildStepMixin, TestReactorMixin,
 
     def test_real_cmd(self):
         cmd = [sys.executable, '-c', 'print("hello")']
-        self.setupStep(master.MasterShellCommandNewStyle(command=cmd))
+        self.setupStep(master.MasterShellCommand(command=cmd))
         if runtime.platformType == 'win32':
             self.expectLogfile('stdio', "hello\r\n")
         else:
@@ -85,7 +85,7 @@ class TestMasterShellCommandNewStyle(steps.BuildStepMixin, TestReactorMixin,
 
     def test_real_cmd_interrupted(self):
         cmd = [sys.executable, '-c', 'while True: pass']
-        self.setupStep(master.MasterShellCommandNewStyle(command=cmd))
+        self.setupStep(master.MasterShellCommand(command=cmd))
         self.expectLogfile('stdio', "")
         if runtime.platformType == 'win32':
             # windows doesn't have signals, so we don't get 'killed',
@@ -102,16 +102,16 @@ class TestMasterShellCommandNewStyle(steps.BuildStepMixin, TestReactorMixin,
     def test_real_cmd_fails(self):
         cmd = [sys.executable, '-c', 'import sys; sys.exit(1)']
         self.setupStep(
-            master.MasterShellCommandNewStyle(command=cmd))
+            master.MasterShellCommand(command=cmd))
         self.expectLogfile('stdio', "")
         self.expectOutcome(result=FAILURE, state_string="failed (1) (failure)")
         return self.runStep()
 
     def test_constr_args(self):
         self.setupStep(
-            master.MasterShellCommandNewStyle(description='x', descriptionDone='y',
-                                              env={'a': 'b'}, workdir='build', usePTY=True,
-                                              command='true'))
+            master.MasterShellCommand(description='x', descriptionDone='y',
+                                      env={'a': 'b'}, workdir='build', usePTY=True,
+                                      command='true'))
 
         if runtime.platformType == 'win32':
             exp_argv = [r'C:\WINDOWS\system32\cmd.exe', '/c', 'true']
@@ -132,7 +132,7 @@ class TestMasterShellCommandNewStyle(steps.BuildStepMixin, TestReactorMixin,
         cmd = [sys.executable, '-c', 'import os; print(os.environ["HELLO"])']
         os.environ['WORLD'] = 'hello'
         self.setupStep(
-            master.MasterShellCommandNewStyle(command=cmd, env={'HELLO': '${WORLD}'}))
+            master.MasterShellCommand(command=cmd, env={'HELLO': '${WORLD}'}))
         if runtime.platformType == 'win32':
             self.expectLogfile('stdio', "hello\r\n")
         else:
@@ -151,9 +151,8 @@ class TestMasterShellCommandNewStyle(steps.BuildStepMixin, TestReactorMixin,
         cmd = [sys.executable, '-c', 'import os; print(os.environ["HELLO"])']
         os.environ['WORLD'] = 'hello'
         os.environ['LIST'] = 'world'
-        self.setupStep(
-            master.MasterShellCommandNewStyle(command=cmd,
-                                              env={'HELLO': ['${WORLD}', '${LIST}']}))
+        self.setupStep(master.MasterShellCommand(command=cmd,
+                                                 env={'HELLO': ['${WORLD}', '${LIST}']}))
         if runtime.platformType == 'win32':
             self.expectLogfile('stdio', "hello;world\r\n")
         else:
@@ -173,9 +172,8 @@ class TestMasterShellCommandNewStyle(steps.BuildStepMixin, TestReactorMixin,
         cmd = [sys.executable, '-c', WithProperties(
             'import os; print("%s"); print(os.environ[\"BUILD\"])',
             'project')]
-        self.setupStep(
-            master.MasterShellCommandNewStyle(command=cmd,
-                                              env={'BUILD': WithProperties('%s', "project")}))
+        self.setupStep(master.MasterShellCommand(command=cmd,
+                                                 env={'BUILD': WithProperties('%s', "project")}))
         self.properties.setProperty("project", "BUILDBOT-TEST", "TEST")
         if runtime.platformType == 'win32':
             self.expectLogfile('stdio', "BUILDBOT-TEST\r\nBUILDBOT-TEST\r\n")
@@ -185,11 +183,10 @@ class TestMasterShellCommandNewStyle(steps.BuildStepMixin, TestReactorMixin,
         return self.runStep()
 
     def test_constr_args_descriptionSuffix(self):
-        self.setupStep(
-            master.MasterShellCommandNewStyle(description='x', descriptionDone='y',
-                                              descriptionSuffix='z',
-                                              env={'a': 'b'}, workdir='build', usePTY=True,
-                                              command='true'))
+        self.setupStep(master.MasterShellCommand(description='x', descriptionDone='y',
+                                                 descriptionSuffix='z',
+                                                 env={'a': 'b'}, workdir='build', usePTY=True,
+                                                 command='true'))
 
         if runtime.platformType == 'win32':
             exp_argv = [r'C:\WINDOWS\system32\cmd.exe', '/c', 'true']
