@@ -49,7 +49,7 @@ class TestShellCommandExecution(steps.BuildStepMixin,
         return self.tearDownBuildStep()
 
     def test_doStepIf_False(self):
-        self.setupStep(shell.ShellCommandNewStyle(command="echo hello", doStepIf=False))
+        self.setupStep(shell.ShellCommand(command="echo hello", doStepIf=False))
         self.expectOutcome(result=SKIPPED,
                            state_string="'echo hello' (skipped)")
         return self.runStep()
@@ -57,12 +57,12 @@ class TestShellCommandExecution(steps.BuildStepMixin,
     def test_constructor_args_validity(self):
         # this checks that an exception is raised for invalid arguments
         with self.assertRaisesConfigError(
-                "Invalid argument(s) passed to ShellCommandNewStyle: "):
-            shell.ShellCommandNewStyle(workdir='build', command="echo Hello World",
-                                       wrongArg1=1, wrongArg2='two')
+                "Invalid argument(s) passed to ShellCommand: "):
+            shell.ShellCommand(workdir='build', command="echo Hello World",
+                               wrongArg1=1, wrongArg2='two')
 
     def test_run_simple(self):
-        self.setupStep(shell.ShellCommandNewStyle(workdir='build', command="echo hello"))
+        self.setupStep(shell.ShellCommand(workdir='build', command="echo hello"))
         self.expectCommands(
             ExpectShell(workdir='build', command='echo hello')
             + 0
@@ -71,8 +71,8 @@ class TestShellCommandExecution(steps.BuildStepMixin,
         return self.runStep()
 
     def test_run_list(self):
-        self.setupStep(shell.ShellCommandNewStyle(workdir='build',
-                                                  command=['trial', '-b', '-B', 'buildbot.test']))
+        self.setupStep(shell.ShellCommand(workdir='build',
+                                          command=['trial', '-b', '-B', 'buildbot.test']))
         self.expectCommands(
             ExpectShell(workdir='build',
                         command=['trial', '-b', '-B', 'buildbot.test'])
@@ -83,7 +83,7 @@ class TestShellCommandExecution(steps.BuildStepMixin,
         return self.runStep()
 
     def test_run_nested_description(self):
-        self.setupStep(shell.ShellCommandNewStyle(
+        self.setupStep(shell.ShellCommand(
             workdir='build',
             command=properties.FlattenList(['trial', ['-b', '-B'], 'buildbot.test']),
             descriptionDone=properties.FlattenList(['test', ['done']]),
@@ -98,8 +98,8 @@ class TestShellCommandExecution(steps.BuildStepMixin,
         return self.runStep()
 
     def test_run_nested_command(self):
-        self.setupStep(shell.ShellCommandNewStyle(workdir='build',
-                                                  command=['trial', ['-b', '-B'], 'buildbot.test']))
+        self.setupStep(shell.ShellCommand(workdir='build',
+                                          command=['trial', ['-b', '-B'], 'buildbot.test']))
         self.expectCommands(
             ExpectShell(workdir='build',
                         command=['trial', '-b', '-B', 'buildbot.test'])
@@ -110,9 +110,8 @@ class TestShellCommandExecution(steps.BuildStepMixin,
         return self.runStep()
 
     def test_run_nested_deeply_command(self):
-        self.setupStep(shell.ShellCommandNewStyle(workdir='build',
-                                                  command=[['trial', ['-b', ['-B']]],
-                                                           'buildbot.test']))
+        self.setupStep(shell.ShellCommand(workdir='build',
+                                          command=[['trial', ['-b', ['-B']]], 'buildbot.test']))
         self.expectCommands(
             ExpectShell(workdir='build',
                         command=['trial', '-b', '-B', 'buildbot.test'])
@@ -123,8 +122,8 @@ class TestShellCommandExecution(steps.BuildStepMixin,
         return self.runStep()
 
     def test_run_nested_empty_command(self):
-        self.setupStep(shell.ShellCommandNewStyle(workdir='build',
-                                                  command=['trial', [], '-b', [], 'buildbot.test']))
+        self.setupStep(shell.ShellCommand(workdir='build',
+                                          command=['trial', [], '-b', [], 'buildbot.test']))
         self.expectCommands(
             ExpectShell(workdir='build',
                         command=['trial', '-b', 'buildbot.test'])
@@ -135,7 +134,7 @@ class TestShellCommandExecution(steps.BuildStepMixin,
         return self.runStep()
 
     def test_run_env(self):
-        self.setupStep(shell.ShellCommandNewStyle(workdir='build', command="echo hello"),
+        self.setupStep(shell.ShellCommand(workdir='build', command="echo hello"),
                        worker_env=dict(DEF='HERE'))
         self.expectCommands(
             ExpectShell(workdir='build', command='echo hello',
@@ -146,8 +145,8 @@ class TestShellCommandExecution(steps.BuildStepMixin,
         return self.runStep()
 
     def test_run_env_override(self):
-        self.setupStep(shell.ShellCommandNewStyle(workdir='build', env={'ABC': '123'},
-                                                  command="echo hello"),
+        self.setupStep(shell.ShellCommand(workdir='build', env={'ABC': '123'},
+                                          command="echo hello"),
                        worker_env=dict(ABC='XXX', DEF='HERE'))
         self.expectCommands(
             ExpectShell(workdir='build', command='echo hello',
@@ -158,8 +157,7 @@ class TestShellCommandExecution(steps.BuildStepMixin,
         return self.runStep()
 
     def test_run_usePTY(self):
-        self.setupStep(shell.ShellCommandNewStyle(workdir='build', command="echo hello",
-                                                  usePTY=False))
+        self.setupStep(shell.ShellCommand(workdir='build', command="echo hello", usePTY=False))
         self.expectCommands(
             ExpectShell(workdir='build', command='echo hello',
                         usePTY=False)
@@ -170,7 +168,7 @@ class TestShellCommandExecution(steps.BuildStepMixin,
 
     def test_run_usePTY_old_worker(self):
         self.setupStep(
-            shell.ShellCommandNewStyle(workdir='build', command="echo hello", usePTY=True),
+            shell.ShellCommand(workdir='build', command="echo hello", usePTY=True),
             worker_version=dict(shell='1.1'))
         self.expectCommands(
             ExpectShell(workdir='build', command='echo hello')
@@ -180,8 +178,8 @@ class TestShellCommandExecution(steps.BuildStepMixin,
         return self.runStep()
 
     def test_run_decodeRC(self, rc=1, results=WARNINGS, extra_text=" (warnings)"):
-        self.setupStep(shell.ShellCommandNewStyle(workdir='build', command="echo hello",
-                                                  decodeRC={1: WARNINGS}))
+        self.setupStep(shell.ShellCommand(workdir='build', command="echo hello",
+                                          decodeRC={1: WARNINGS}))
         self.expectCommands(
             ExpectShell(workdir='build', command='echo hello')
             + rc
@@ -230,7 +228,7 @@ class TreeSize(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command=['du', '-s', '-k', '.'])
-            + ExpectShell.log('stdio', stdio='abcdef\n')
+            + ExpectShell.log('stdio', stdout='abcdef\n')
             + 0
         )
         self.expectOutcome(result=WARNINGS,
@@ -262,11 +260,11 @@ class SetPropertyFromCommand(steps.BuildStepMixin, TestReactorMixin,
 
     def test_constructor_conflict(self):
         with self.assertRaises(config.ConfigErrors):
-            shell.SetPropertyFromCommandNewStyle(property='foo', extract_fn=lambda: None)
+            shell.SetPropertyFromCommand(property='foo', extract_fn=lambda: None)
 
     def test_run_property(self):
         self.setupStep(
-            shell.SetPropertyFromCommandNewStyle(property="res", command="cmd"))
+            shell.SetPropertyFromCommand(property="res", command="cmd"))
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command="cmd")
@@ -281,8 +279,8 @@ class SetPropertyFromCommand(steps.BuildStepMixin, TestReactorMixin,
 
     def test_renderable_workdir(self):
         self.setupStep(
-            shell.SetPropertyFromCommandNewStyle(property="res", command="cmd",
-                                                 workdir=properties.Interpolate('wkdir')))
+            shell.SetPropertyFromCommand(property="res", command="cmd",
+                                         workdir=properties.Interpolate('wkdir')))
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command="cmd")
@@ -296,8 +294,7 @@ class SetPropertyFromCommand(steps.BuildStepMixin, TestReactorMixin,
         return self.runStep()
 
     def test_run_property_no_strip(self):
-        self.setupStep(shell.SetPropertyFromCommandNewStyle(property="res", command="cmd",
-                                                            strip=False))
+        self.setupStep(shell.SetPropertyFromCommand(property="res", command="cmd", strip=False))
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command="cmd")
@@ -312,7 +309,7 @@ class SetPropertyFromCommand(steps.BuildStepMixin, TestReactorMixin,
 
     def test_run_failure(self):
         self.setupStep(
-            shell.SetPropertyFromCommandNewStyle(property="res", command="blarg"))
+            shell.SetPropertyFromCommand(property="res", command="blarg"))
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command="blarg")
@@ -330,7 +327,7 @@ class SetPropertyFromCommand(steps.BuildStepMixin, TestReactorMixin,
                 (rc, stdout, stderr), (0, 'startend\n', 'STARTEND\n'))
             return dict(a=1, b=2)
         self.setupStep(
-            shell.SetPropertyFromCommandNewStyle(extract_fn=extract_fn, command="cmd"))
+            shell.SetPropertyFromCommand(extract_fn=extract_fn, command="cmd"))
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command="cmd")
@@ -351,7 +348,7 @@ class SetPropertyFromCommand(steps.BuildStepMixin, TestReactorMixin,
             self.assertEqual((rc, stdout, stderr), (3, '', ''))
             return dict(a=1, b=2)
         self.setupStep(
-            shell.SetPropertyFromCommandNewStyle(extract_fn=extract_fn, command="cmd"))
+            shell.SetPropertyFromCommand(extract_fn=extract_fn, command="cmd"))
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command="cmd")
@@ -368,7 +365,7 @@ class SetPropertyFromCommand(steps.BuildStepMixin, TestReactorMixin,
             self.assertEqual((rc, stdout, stderr), (3, '', ''))
             return dict()
         self.setupStep(
-            shell.SetPropertyFromCommandNewStyle(extract_fn=extract_fn, command="cmd"))
+            shell.SetPropertyFromCommand(extract_fn=extract_fn, command="cmd"))
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command="cmd")
@@ -384,7 +381,7 @@ class SetPropertyFromCommand(steps.BuildStepMixin, TestReactorMixin,
         def extract_fn(rc, stdout, stderr):
             raise RuntimeError("oh noes")
         self.setupStep(
-            shell.SetPropertyFromCommandNewStyle(extract_fn=extract_fn, command="cmd"))
+            shell.SetPropertyFromCommand(extract_fn=extract_fn, command="cmd"))
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command="cmd")
@@ -399,20 +396,19 @@ class SetPropertyFromCommand(steps.BuildStepMixin, TestReactorMixin,
     def test_error_both_set(self):
         """
         If both ``extract_fn`` and ``property`` are defined,
-        ``SetPropertyFromCommandNewStyle`` reports a config error.
+        ``SetPropertyFromCommand`` reports a config error.
         """
         with self.assertRaises(config.ConfigErrors):
-            shell.SetPropertyFromCommandNewStyle(command=["echo", "value"],
-                                                 property="propname",
-                                                 extract_fn=lambda x: {"propname": "hello"})
+            shell.SetPropertyFromCommand(command=["echo", "value"], property="propname",
+                                         extract_fn=lambda x: {"propname": "hello"})
 
     def test_error_none_set(self):
         """
         If neither ``extract_fn`` and ``property`` are defined,
-        ``SetPropertyFromCommandNewStyle`` reports a config error.
+        ``SetPropertyFromCommand`` reports a config error.
         """
         with self.assertRaises(config.ConfigErrors):
-            shell.SetPropertyFromCommandNewStyle(command=["echo", "value"])
+            shell.SetPropertyFromCommand(command=["echo", "value"])
 
 
 class PerlModuleTest(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
@@ -552,11 +548,11 @@ class Configure(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
         return self.tearDownBuildStep()
 
     def test_class_attrs(self):
-        step = shell.ConfigureNewStyle()
+        step = shell.Configure()
         self.assertEqual(step.command, ['./configure'])
 
     def test_run(self):
-        self.setupStep(shell.ConfigureNewStyle())
+        self.setupStep(shell.Configure())
 
         self.expectCommands(
             ExpectShell(workdir='wkdir',
@@ -580,7 +576,7 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
         return self.tearDownBuildStep()
 
     def test_no_warnings(self):
-        self.setupStep(shell.WarningCountingShellCommandNewStyle(workdir='w', command=['make']))
+        self.setupStep(shell.WarningCountingShellCommand(workdir='w', command=['make']))
         self.expectCommands(
             ExpectShell(workdir='w',
                         command=["make"])
@@ -592,7 +588,7 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
         return self.runStep()
 
     def test_default_pattern(self):
-        self.setupStep(shell.WarningCountingShellCommandNewStyle(command=['make']))
+        self.setupStep(shell.WarningCountingShellCommand(command=['make']))
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command=["make"])
@@ -608,8 +604,8 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
         return self.runStep()
 
     def test_custom_pattern(self):
-        self.setupStep(shell.WarningCountingShellCommandNewStyle(command=['make'],
-                                                                 warningPattern=r"scary:.*"))
+        self.setupStep(shell.WarningCountingShellCommand(command=['make'],
+                                                         warningPattern=r"scary:.*"))
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command=["make"])
@@ -623,8 +619,7 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
         return self.runStep()
 
     def test_maxWarnCount(self):
-        self.setupStep(shell.WarningCountingShellCommandNewStyle(command=['make'],
-                                                                 maxWarnCount=9))
+        self.setupStep(shell.WarningCountingShellCommand(command=['make'], maxWarnCount=9))
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command=["make"])
@@ -636,7 +631,7 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
         return self.runStep()
 
     def test_fail_with_warnings(self):
-        self.setupStep(shell.WarningCountingShellCommandNewStyle(command=['make']))
+        self.setupStep(shell.WarningCountingShellCommand(command=['make']))
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command=["make"])
@@ -649,8 +644,8 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
         return self.runStep()
 
     def test_warn_with_decoderc(self):
-        self.setupStep(shell.WarningCountingShellCommandNewStyle(command=['make'],
-                                                                 decodeRC={3: WARNINGS}))
+        self.setupStep(shell.WarningCountingShellCommand(command=['make'],
+                                                         decodeRC={3: WARNINGS}))
         self.expectCommands(
             ExpectShell(workdir='wkdir',
                         command=["make"],
@@ -717,7 +712,7 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
         return self.runStep()
 
     def test_suppressions(self):
-        step = shell.WarningCountingShellCommandNewStyle(command=['make'], suppressionFile='supps')
+        step = shell.WarningCountingShellCommand(command=['make'], suppressionFile='supps')
         supps_file = textwrap.dedent("""\
             # example suppressions file
 
@@ -744,9 +739,9 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
     def test_suppressions_directories(self):
         def warningExtractor(step, line, match):
             return line.split(':', 2)
-        step = shell.WarningCountingShellCommandNewStyle(command=['make'],
-                                                         suppressionFile='supps',
-                                                         warningExtractor=warningExtractor)
+        step = shell.WarningCountingShellCommand(command=['make'],
+                                                 suppressionFile='supps',
+                                                 warningExtractor=warningExtractor)
         supps_file = textwrap.dedent("""\
             # these should be suppressed:
             amar-src/amar.c : XXX
@@ -777,11 +772,11 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
     def test_suppressions_directories_custom(self):
         def warningExtractor(step, line, match):
             return line.split(':', 2)
-        step = shell.WarningCountingShellCommandNewStyle(command=['make'],
-                                                         suppressionFile='supps',
-                                                         warningExtractor=warningExtractor,
-                                                         directoryEnterPattern="^IN: (.*)",
-                                                         directoryLeavePattern="^OUT:")
+        step = shell.WarningCountingShellCommand(command=['make'],
+                                                 suppressionFile='supps',
+                                                 warningExtractor=warningExtractor,
+                                                 directoryEnterPattern="^IN: (.*)",
+                                                 directoryLeavePattern="^OUT:")
         supps_file = "dir1/dir2/abc.c : .*"
         stdout = textwrap.dedent("""\
             IN: dir1
@@ -795,9 +790,9 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
     def test_suppressions_linenos(self):
         def warningExtractor(step, line, match):
             return line.split(':', 2)
-        step = shell.WarningCountingShellCommandNewStyle(command=['make'],
-                                                         suppressionFile='supps',
-                                                         warningExtractor=warningExtractor)
+        step = shell.WarningCountingShellCommand(command=['make'],
+                                                 suppressionFile='supps',
+                                                 warningExtractor=warningExtractor)
         supps_file = "abc.c:.*:100-199\ndef.c:.*:22"
         stdout = textwrap.dedent("""\
             abc.c:99: warning: seen 1
@@ -816,9 +811,9 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
     def test_suppressions_warningExtractor_exc(self):
         def warningExtractor(step, line, match):
             raise RuntimeError("oh noes")
-        step = shell.WarningCountingShellCommandNewStyle(command=['make'],
-                                                         suppressionFile='supps',
-                                                         warningExtractor=warningExtractor)
+        step = shell.WarningCountingShellCommand(command=['make'],
+                                                 suppressionFile='supps',
+                                                 warningExtractor=warningExtractor)
         # need at least one supp to trigger warningExtractor
         supps_file = 'x:y'
         stdout = "abc.c:99: warning: seen 1"
@@ -828,7 +823,7 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
 
     def test_suppressions_addSuppression(self):
         # call addSuppression "manually" from a subclass
-        class MyWCSC(shell.WarningCountingShellCommandNewStyle):
+        class MyWCSC(shell.WarningCountingShellCommand):
 
             def run(self):
                 self.addSuppression([('.*', '.*unseen.*', None, None)])
@@ -858,9 +853,9 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
                    ("abc.c", ".*", 100, 199),
                    ("def.c", ".*", 22, 22),
                 )
-        step = shell.WarningCountingShellCommandNewStyle(command=['make'],
-                                                         suppressionList=supps,
-                                                         warningExtractor=warningExtractor)
+        step = shell.WarningCountingShellCommand(command=['make'],
+                                                 suppressionList=supps,
+                                                 warningExtractor=warningExtractor)
         stdout = textwrap.dedent("""\
             abc.c:99: warning: seen 1
             abc.c:150: warning: unseen
@@ -883,7 +878,7 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
                    ("def.c", ".*", 22, 22),
         )
 
-        step = shell.WarningCountingShellCommandNewStyle(
+        step = shell.WarningCountingShellCommand(
             command=['make'],
             suppressionList=properties.Property("suppressionsList"),
             warningExtractor=warningExtractor)
@@ -902,8 +897,8 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
                                          exp_warning_log, props={"suppressionsList": supps})
 
     def test_warnExtractFromRegexpGroups(self):
-        step = shell.WarningCountingShellCommandNewStyle(command=['make'])
-        we = shell.WarningCountingShellCommandNewStyle.warnExtractFromRegexpGroups
+        step = shell.WarningCountingShellCommand(command=['make'])
+        we = shell.WarningCountingShellCommand.warnExtractFromRegexpGroups
         line, pat, exp_file, exp_lineNo, exp_text = \
             ('foo:123:text', '(.*):(.*):(.*)', 'foo', 123, 'text')
         self.assertEqual(we(step, line, re.match(pat, line)),
@@ -912,9 +907,8 @@ class WarningCountingShellCommand(steps.BuildStepMixin,
     def test_missing_command_error(self):
         # this checks that an exception is raised for invalid arguments
         with self.assertRaisesConfigError(
-                "WarningCountingShellCommandNewStyle's `command' argument is not "
-                "specified"):
-            shell.WarningCountingShellCommandNewStyle()
+                "WarningCountingShellCommand's 'command' argument is not specified"):
+            shell.WarningCountingShellCommand()
 
 
 class Compile(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
@@ -929,7 +923,7 @@ class Compile(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
     def test_class_args(self):
         # since this step is just a pre-configured WarningCountingShellCommand,
         # there' not much to test!
-        step = self.setupStep(shell.CompileNewStyle())
+        step = self.setupStep(shell.Compile())
         self.assertEqual(step.name, "compile")
         self.assertTrue(step.haltOnFailure)
         self.assertTrue(step.flunkOnFailure)
