@@ -26,7 +26,7 @@ from twisted.trial import unittest
 from buildbot import pbmanager
 
 
-class FakeMaster(object):
+class FakeMaster:
     initLock = defer.DeferredLock()
 
     def addService(self, svc):
@@ -39,9 +39,10 @@ class FakeMaster(object):
 
 class TestPBManager(unittest.TestCase):
 
+    @defer.inlineCallbacks
     def setUp(self):
         self.pbm = pbmanager.PBManager()
-        self.pbm.setServiceParent(FakeMaster())
+        yield self.pbm.setServiceParent(FakeMaster())
         self.pbm.startService()
         self.connections = []
 
@@ -55,8 +56,9 @@ class TestPBManager(unittest.TestCase):
         self.connections.append(username)
         return defer.succeed(persp)
 
+    @defer.inlineCallbacks
     def test_repr(self):
-        reg = self.pbm.register(
+        reg = yield self.pbm.register(
             'tcp:0:interface=127.0.0.1', "x", "y", self.perspectiveFactory)
         self.assertEqual(repr(self.pbm.dispatchers['tcp:0:interface=127.0.0.1']),
                          '<pbmanager.Dispatcher for x on tcp:0:interface=127.0.0.1>')
@@ -66,8 +68,7 @@ class TestPBManager(unittest.TestCase):
     @defer.inlineCallbacks
     def test_register_unregister(self):
         portstr = "tcp:0:interface=127.0.0.1"
-        reg = self.pbm.register(
-            portstr, "boris", "pass", self.perspectiveFactory)
+        reg = yield self.pbm.register(portstr, "boris", "pass", self.perspectiveFactory)
 
         # make sure things look right
         self.assertIn(portstr, self.pbm.dispatchers)
@@ -89,11 +90,35 @@ class TestPBManager(unittest.TestCase):
 
         yield reg.unregister()
 
+    @defer.inlineCallbacks
+    def test_register_no_user(self):
+        portstr = "tcp:0:interface=127.0.0.1"
+        reg = yield self.pbm.register(portstr, "boris", "pass", self.perspectiveFactory)
+
+        # make sure things look right
+        self.assertIn(portstr, self.pbm.dispatchers)
+        disp = self.pbm.dispatchers[portstr]
+        self.assertIn('boris', disp.users)
+
+        # we can't actually connect to it, as that requires finding the
+        # dynamically allocated port number which is buried out of reach;
+        # however, we can try the requestAvatar and requestAvatarId methods.
+
+        username = yield disp.requestAvatarId(credentials.UsernamePassword(b'boris', b'pass'))
+
+        self.assertEqual(username, b'boris')
+        with self.assertRaises(ValueError):
+            yield disp.requestAvatar(b'notboris', mock.Mock(), pb.IPerspective)
+
+        self.assertNotIn('boris', self.connections)
+
+        yield reg.unregister()
+
     @defer.inlineCallbacks
     def test_double_register_unregister(self):
         portstr = "tcp:0:interface=127.0.0.1"
-        reg1 = self.pbm.register(portstr, "boris", "pass", None)
-        reg2 = self.pbm.register(portstr, "ivona", "pass", None)
+        reg1 = yield self.pbm.register(portstr, "boris", "pass", None)
+        reg2 = yield self.pbm.register(portstr, "ivona", "pass", None)
 
         # make sure things look right
         self.assertEqual(len(self.pbm.dispatchers), 1)
@@ -116,8 +141,7 @@ class TestPBManager(unittest.TestCase):
     @defer.inlineCallbacks
     def test_requestAvatarId_noinitLock(self):
         portstr = "tcp:0:interface=127.0.0.1"
-        reg = self.pbm.register(
-            portstr, "boris", "pass", self.perspectiveFactory)
+        reg = yield self.pbm.register(portstr, "boris", "pass", self.perspectiveFactory)
 
         disp = self.pbm.dispatchers[portstr]
 
@@ -130,8 +154,7 @@ class TestPBManager(unittest.TestCase):
     @defer.inlineCallbacks
     def test_requestAvatarId_initLock(self):
         portstr = "tcp:0:interface=127.0.0.1"
-        reg = self.pbm.register(
-            portstr, "boris", "pass", self.perspectiveFactory)
+        reg = yield self.pbm.register(portstr, "boris", "pass", self.perspectiveFactory)
 
         disp = self.pbm.dispatchers[portstr]
 
