@@ -85,11 +85,11 @@ class VerifyDict(unittest.TestCase):
         os_encoding = locale.getpreferredencoding()
         try:
             '\N{SNOWMAN}'.encode(os_encoding)
-        except UnicodeEncodeError:
+        except UnicodeEncodeError as e:
             # Default encoding of Windows console is 'cp1252'
             # which cannot encode the snowman.
             raise(unittest.SkipTest("Cannot encode weird unicode "
-                "on this platform with {}".format(os_encoding)))
+                "on this platform with {}".format(os_encoding))) from e
 
         self.doValidationTest(validation.IdentifierValidator(50),
                               good=[
