@@ -13,18 +13,22 @@
 #
 # Copyright Buildbot Team Members
 
+from parameterized import parameterized
+
 import mock
 
 from twisted.internet import defer
 from twisted.trial import unittest
 
 from buildbot.test.fake import fakemaster
+from buildbot.test.util.misc import TestReactorMixin
 from buildbot.util import service
 from buildbot.wamp import connector
 
 
-class FakeConfig(object):
-    mq = dict(type='wamp', router_url="wss://foo", realm="bb")
+class FakeConfig:
+    def __init__(self, mq_dict):
+        self.mq = mq_dict
 
 
 class FakeService(service.AsyncMultiService):
@@ -34,7 +38,7 @@ class FakeService(service.AsyncMultiService):
 
     def __init__(self, url, realm, make, extra=None,
                  debug=False, debug_wamp=False, debug_app=False):
-        service.AsyncMultiService.__init__(self)
+        super().__init__()
         self.make = make
         self.extra = extra
 
@@ -51,15 +55,38 @@ class TestedWampConnector(connector.WampConnector):
     serviceClass = FakeService
 
 
-class WampConnector(unittest.TestCase):
+class WampConnector(TestReactorMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def setUp(self):
-        master = fakemaster.make_master()
+        self.setUpTestReactor()
+        master = fakemaster.make_master(self)
         self.connector = TestedWampConnector()
+
+        config = FakeConfig({'type': 'wamp', 'router_url': "wss://foo", 'realm': "bb"})
+
         yield self.connector.setServiceParent(master)
         yield master.startService()
-        yield self.connector.reconfigServiceWithBuildbotConfig(FakeConfig())
+        yield self.connector.reconfigServiceWithBuildbotConfig(config)
+
+    @defer.inlineCallbacks
+    def test_reconfig_same_config(self):
+        config = FakeConfig({'type': 'wamp', 'router_url': "wss://foo", 'realm': "bb"})
+        yield self.connector.reconfigServiceWithBuildbotConfig(config)
+
+    @parameterized.expand([
+        ('type', 'simple'),
+        ('router_url', 'wss://other-foo'),
+        ('realm', 'bb-other'),
+        ('wamp_debug_level', 'info'),
+    ])
+    @defer.inlineCallbacks
+    def test_reconfig_does_not_allow_config_change(self, attr_name, attr_value):
+        mq_dict = {'type': 'wamp', 'router_url': "wss://foo", 'realm': "bb"}
+        mq_dict[attr_name] = attr_value
+        with self.assertRaises(ValueError,
+                               msg="Cannot use different wamp settings when reconfiguring"):
+            yield self.connector.reconfigServiceWithBuildbotConfig(FakeConfig(mq_dict))
 
     @defer.inlineCallbacks
     def test_startup(self):
