@@ -18,9 +18,7 @@ import os
 
 from twisted.trial import unittest
 
-from buildbot.test.util.decorators import flaky
 from buildbot.test.util.warnings import assertNotProducesWarnings
-from buildbot.test.util.warnings import assertProducesWarnings
 from buildbot.warnings import DeprecatedApiWarning
 
 try:
@@ -28,9 +26,11 @@ try:
     assert mock_ec2
     import boto3
     assert boto3
+    from botocore.client import ClientError
 except ImportError:
     boto3 = None
     ec2 = None
+    ClientError = None
 
 
 if boto3 is not None:
@@ -92,6 +92,40 @@ class TestEC2LatentWorker(unittest.TestCase):
         c.terminate_instances(InstanceIds=[instance.id])
         return c, r
 
+    def _patch_moto_describe_spot_price_history(self, bs, instance_type, price):
+        def fake_describe_price(*args, **kwargs):
+            return {
+                'SpotPriceHistory': [{'InstanceType': instance_type, 'SpotPrice': price}]
+            }
+
+        self.patch(bs.ec2.meta.client, "describe_spot_price_history", fake_describe_price)
+
+    def _patch_moto_describe_spot_instance_requests(self, c, r, bs):
+        this_call = [0]
+
+        orig_describe_instance = bs.ec2.meta.client.describe_spot_instance_requests
+
+        def fake_describe_spot_instance_requests(*args, **kwargs):
+            curr_call = this_call[0]
+            this_call[0] += 1
+            if curr_call == 0:
+                raise ClientError({'Error': {'Code': 'InvalidSpotInstanceRequestID.NotFound'}},
+                                  'DescribeSpotInstanceRequests')
+            if curr_call == 1:
+                return orig_describe_instance(*args, **kwargs)
+
+            response = orig_describe_instance(*args, **kwargs)
+
+            instances = r.instances.filter(Filters=[{'Name': 'instance-state-name',
+                                                     'Values': ['running']}])
+
+            response['SpotInstanceRequests'][0]['Status']['Code'] = 'fulfilled'
+            response['SpotInstanceRequests'][0]['InstanceId'] = list(instances)[0].id
+            return response
+
+        self.patch(bs.ec2.meta.client, 'describe_spot_instance_requests',
+                   fake_describe_spot_instance_requests)
+
     @mock_ec2
     def test_constructor_minimal(self):
         c, r = self.botoSetup('latent_buildbot_slave')
@@ -209,64 +243,6 @@ class TestEC2LatentWorker(unittest.TestCase):
         self.assertIsNone(instances[0].tags)
         self.assertEqual(instances[0].id, bs.properties.getProperty('instance'))
 
-    @mock_ec2
-    def test_start_instance_volumes_deprecated(self):
-        c, r = self.botoSetup()
-        block_device_map_arg = {
-            "/dev/xvdb": {
-                "volume_type": "io1",
-                "iops": 10,
-                "size": 20,
-            },
-            "/dev/xvdc": {
-                "volume_type": "gp2",
-                "size": 30,
-                "delete_on_termination": False
-            }
-        }
-        block_device_map_res = [
-                {
-                    'DeviceName': "/dev/xvdb",
-                    'Ebs': {
-                        "VolumeType": "io1",
-                        "Iops": 10,
-                        "VolumeSize": 20,
-                        "DeleteOnTermination": True,
-                        }
-                    },
-                {
-                    'DeviceName': "/dev/xvdc",
-                    'Ebs': {
-                        "VolumeType": "gp2",
-                        "VolumeSize": 30,
-                        "DeleteOnTermination": False,
-                        }
-                    },
-                ]
-
-        amis = list(r.images.all())
-        with assertProducesWarnings(
-                DeprecatedApiWarning,
-                messages_patterns=[
-                    r"Use of dict value to 'block_device_map' of EC2LatentWorker "
-                    r"constructor is deprecated. Please use a list matching the AWS API"
-                ]):
-            bs = ec2.EC2LatentWorker('bot1', 'sekrit', 'm1.large',
-                                     identifier='publickey',
-                                     secret_identifier='privatekey',
-                                     keypair_name="latent_buildbot_worker",
-                                     security_name='latent_buildbot_worker',
-                                     ami=amis[0].id,
-                                     block_device_map=block_device_map_arg
-                                     )
-        # moto does not currently map volumes properly.  below ensures
-        # that my conversion code properly composes it, including
-        # delete_on_termination default.
-        self.assertEqual(sorted(block_device_map_res,
-                                key=lambda x: x['DeviceName']),
-                         sorted(bs.block_device_map,
-                                key=lambda x: x['DeviceName']))
-
     @mock_ec2
     def test_start_instance_volumes(self):
         c, r = self.botoSetup()
@@ -409,7 +385,11 @@ class TestEC2LatentWorker(unittest.TestCase):
                                  subnet_id=subnet.id,
                                  )
         bs._poll_resolution = 0
-        instance_id, _, _ = bs._start_instance()
+
+        self._patch_moto_describe_spot_price_history(bs, 'm1.large', price=1.0)
+        self._patch_moto_describe_spot_instance_requests(c, r, bs)
+
+        instance_id, _, _ = bs._request_spot_instance()
         instances = r.instances.filter(
             Filters=[{'Name': 'instance-state-name', 'Values': ['running']}])
         instances = list(instances)
@@ -419,7 +399,9 @@ class TestEC2LatentWorker(unittest.TestCase):
         self.assertEqual(instances[0].id, instance_id)
         self.assertEqual(instances[0].subnet_id, subnet.id)
         self.assertEqual(len(instances[0].security_groups), 1)
-        self.assertEqual(instances[0].security_groups[0]['GroupId'], sg.id)
+
+        # TODO: As of moto 2.0.2 GroupId is not handled in spot requests
+        # self.assertEqual(instances[0].security_groups[0]['GroupId'], sg.id)
 
     @mock_ec2
     def test_start_spot_instance(self):
@@ -436,7 +418,11 @@ class TestEC2LatentWorker(unittest.TestCase):
                                  product_description=product_description
                                  )
         bs._poll_resolution = 0
-        instance_id, _, _ = bs._start_instance()
+
+        self._patch_moto_describe_spot_price_history(bs, 'm1.large', price=1.0)
+        self._patch_moto_describe_spot_instance_requests(c, r, bs)
+
+        instance_id, _, _ = bs._request_spot_instance()
         instances = r.instances.filter(
             Filters=[{'Name': 'instance-state-name', 'Values': ['running']}])
         instances = list(instances)
@@ -462,7 +448,6 @@ class TestEC2LatentWorker(unittest.TestCase):
 
         self.assertEqual(image.id, ami.id)
 
-    @flaky(issueNumber=3936)
     @mock_ec2
     def test_get_image_owners(self):
         c, r = self.botoSetup('latent_buildbot_slave')
