@@ -23,6 +23,8 @@ from buildbot.changes.manager import ChangeManager
 from buildbot.test.fake import fakemaster
 from buildbot.test.fake.web import FakeRequest
 from buildbot.test.util.misc import TestReactorMixin
+from buildbot.test.util.warnings import assertProducesWarnings
+from buildbot.warnings import DeprecatedApiWarning
 from buildbot.www import change_hook
 
 
@@ -136,8 +138,10 @@ class TestPollingChangeHook(TestReactorMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def test_trigger_old_poller(self):
-        yield self.setUpRequest({b"poller": [b"example"]},
-                                poller_cls=self.OldstyleSubclass)
+        with assertProducesWarnings(DeprecatedApiWarning, num_warnings=2,
+                                    message_pattern="use ReconfigurablePollingChangeSource"):
+            yield self.setUpRequest({b"poller": [b"example"]},
+                                    poller_cls=self.OldstyleSubclass)
         self.assertEqual(self.request.written, b"no change found")
         self.assertEqual(self.changesrc.called, True)
         self.assertEqual(self.otherpoller.called, False)
