@@ -21,23 +21,25 @@ import mock
 from twisted.internet import defer
 from twisted.trial import unittest
 
+from buildbot.data.exceptions import InvalidQueryParameter
 from buildbot.test.fake import endpoint
 from buildbot.test.util import www
 from buildbot.test.util.misc import TestReactorMixin
 from buildbot.util import bytes2unicode
 from buildbot.util import unicode2bytes
 from buildbot.www import authz
+from buildbot.www import graphql
 from buildbot.www import rest
 from buildbot.www.rest import JSONRPC_CODES
-from buildbot.www.rest import BadRequest
 
 
 class RestRootResource(TestReactorMixin, www.WwwTestMixin, unittest.TestCase):
 
-    maxVersion = 2
+    maxVersion = 3
 
     def setUp(self):
         self.setUpTestReactor()
+        [graphql]  # used for import side effect
 
     @defer.inlineCallbacks
     def test_render(self):
@@ -434,9 +436,9 @@ class V2RootResource_REST(TestReactorMixin, www.WwwTestMixin,
 
     @defer.inlineCallbacks
     def test_api_collection_invalid_filter_value(self):
-        yield self.render_resource(self.rsrc, b'/test?id__lt=fifteen')
+        yield self.render_resource(self.rsrc, b'/test?testid__lt=fifteen')
         self.assertRequest(
-            contentJson=dict(error="invalid filter value for id__lt"),
+            contentJson=dict(error="invalid filter value for testid__lt"),
             contentType=b'text/plain; charset=utf-8',
             responseCode=400)
 
@@ -516,13 +518,13 @@ class V2RootResource_REST(TestReactorMixin, www.WwwTestMixin,
 
     @defer.inlineCallbacks
     def test_api_collection_order_on_unselected(self):
-        yield self.render_resource(self.rsrc, b'/test?field=id&order=info')
+        yield self.render_resource(self.rsrc, b'/test?field=testid&order=info')
         self.assertRestError(message="cannot order on un-selected fields",
                              responseCode=400)
 
     @defer.inlineCallbacks
     def test_api_collection_filter_on_unselected(self):
-        yield self.render_resource(self.rsrc, b'/test?field=id&info__gt=xx')
+        yield self.render_resource(self.rsrc, b'/test?field=testid&info__gt=xx')
         self.assertRestError(message="cannot filter on un-selected fields",
                              responseCode=400)
 
@@ -531,8 +533,9 @@ class V2RootResource_REST(TestReactorMixin, www.WwwTestMixin,
         yield self.render_resource(self.rsrc, b'/test?success=false&limit=2')
         # note that the limit/offset and total are *after* the filter
         self.assertRestCollection(typeName='tests',
-                                  items=sorted([v for v in endpoint.testData.values()
-                                                if not v['success']], key=lambda v: v['id'])[:2],
+                                  items=sorted(
+                                      [v for v in endpoint.testData.values()
+                                       if not v['success']], key=lambda v: v['testid'])[:2],
                                   total=3)
 
     @defer.inlineCallbacks
@@ -547,7 +550,7 @@ class V2RootResource_REST(TestReactorMixin, www.WwwTestMixin,
         yield self.render_resource(self.rsrc, b'/test/0')
         self.assertRequest(
             contentJson={'error': "not found while getting from endpoint for "
-                                  "/test/n:testid with arguments"
+                                  "/tests/n:testid,/test/n:testid with arguments"
                                   " ResultSpec(**{'filters': [], 'fields': None, "
                                   "'properties': [], "
                                   "'order': None, 'limit': None, 'offset': None}) "
@@ -588,7 +591,7 @@ class V2RootResource_REST(TestReactorMixin, www.WwwTestMixin,
         expected_props = [None, 'test2']
         self.make_request(b'/test')
         self.request.args = {b'property': expected_props}
-        with self.assertRaises(BadRequest):
+        with self.assertRaises(InvalidQueryParameter):
             self.rsrc.decodeResultSpec(self.request, endpoint.TestsEndpoint)
 
     def test_decode_result_spec_limit(self):
@@ -620,31 +623,31 @@ class V2RootResource_REST(TestReactorMixin, www.WwwTestMixin,
         self.assertEqual(spec.properties[0].values, expected_props)
 
     def test_decode_result_spec_not_a_collection_limit(self):
-        def expectRaiseBadRequest():
+        def expectRaiseInvalidQueryParameter():
             limit = 5
             self.make_request(b'/test')
             self.request.args = {b'limit': limit}
             self.rsrc.decodeResultSpec(self.request, endpoint.TestEndpoint)
-        with self.assertRaises(rest.BadRequest):
-            expectRaiseBadRequest()
+        with self.assertRaises(InvalidQueryParameter):
+            expectRaiseInvalidQueryParameter()
 
     def test_decode_result_spec_not_a_collection_order(self):
-        def expectRaiseBadRequest():
+        def expectRaiseInvalidQueryParameter():
             order = ('info',)
             self.make_request(b'/test')
             self.request.args = {b'order': order}
             self.rsrc.decodeResultSpec(self.request, endpoint.TestEndpoint)
-        with self.assertRaises(rest.BadRequest):
-            expectRaiseBadRequest()
+        with self.assertRaises(InvalidQueryParameter):
+            expectRaiseInvalidQueryParameter()
 
     def test_decode_result_spec_not_a_collection_offset(self):
-        def expectRaiseBadRequest():
+        def expectRaiseInvalidQueryParameter():
             offset = 0
             self.make_request(b'/test')
             self.request.args = {b'offset': offset}
             self.rsrc.decodeResultSpec(self.request, endpoint.TestEndpoint)
-        with self.assertRaises(rest.BadRequest):
-            expectRaiseBadRequest()
+        with self.assertRaises(InvalidQueryParameter):
+            expectRaiseInvalidQueryParameter()
 
     def test_decode_result_spec_not_a_collection_properties(self):
         expected_props = ['test1', 'test2']
