@@ -221,7 +221,6 @@ class BuildStepMixin:
             self.step._connectPendingLogObservers()
             return defer.succeed(_log)
         step.addLog = addLog
-        step.addLog_newStyle = addLog
 
         def addHTMLLog(name, html):
             _log = logfile.FakeLogFile(name)
@@ -232,6 +231,8 @@ class BuildStepMixin:
 
         def addCompleteLog(name, text):
             _log = logfile.FakeLogFile(name)
+            if name in self.step.logs:
+                raise Exception('Attempt to add log {} twice to the logs'.format(name))
             self.step.logs[name] = _log
             _log.addStdout(text)
             return defer.succeed(None)
@@ -257,6 +258,14 @@ class BuildStepMixin:
                                            duration_ns))
         step.addTestResult = add_test_result
 
+        self._got_build_data = {}
+
+        def set_build_data(name, value, source):
+            self._got_build_data[name] = (value, source)
+            return defer.succeed(None)
+
+        step.setBuildData = set_build_data
+
         # expectations
 
         self.exp_result = None
@@ -264,10 +273,12 @@ class BuildStepMixin:
         self.exp_properties = {}
         self.exp_missing_properties = []
         self.exp_logfiles = {}
+        self._exp_logfiles_stderr = {}
         self.exp_hidden = False
         self.exp_exception = None
         self._exp_test_result_sets = []
         self._exp_test_results = []
+        self._exp_build_data = {}
 
         # check that the step's name is not None
         self.assertNotEqual(step.name, None)
@@ -308,6 +319,12 @@ class BuildStepMixin:
         """
         self.exp_logfiles[logfile] = contents
 
+    def expect_log_file_stderr(self, logfile, contents):
+        self._exp_logfiles_stderr[logfile] = contents
+
+    def expect_build_data(self, name, value, source):
+        self._exp_build_data[name] = (value, source)
+
     def expectHidden(self, hidden):
         """
         Set whether the step is expected to be hidden.
@@ -379,24 +396,41 @@ class BuildStepMixin:
                     self.properties.getPropertySource(pn), ps,
                     "property {0!r} source has source {1!r}".format(
                         pn, self.properties.getPropertySource(pn)))
+
         for pn in self.exp_missing_properties:
             self.assertFalse(self.properties.hasProperty(pn), "unexpected property '{}'".format(pn))
+
         for l, exp in self.exp_logfiles.items():
             got = self.step.logs[l].stdout
-            if got != exp:
-                log.msg("Unexpected log output:\n" + got)
-                log.msg("Expected log output:\n" + exp)
-                raise AssertionError("Unexpected log output; see logs")
+            self._match_log(exp, got, 'stdout')
+
+        for l, exp in self._exp_logfiles_stderr.items():
+            got = self.step.logs[l].stderr
+            self._match_log(exp, got, 'stderr')
+
         if self.exp_exception:
             self.assertEqual(
                 len(self.flushLoggedErrors(self.exp_exception)), 1)
 
         self.assertEqual(self._exp_test_result_sets, self._got_test_result_sets)
         self.assertEqual(self._exp_test_results, self._got_test_results)
+        self.assertEqual(self._exp_build_data, self._got_build_data)
 
         # XXX TODO: hidden
         # self.step_status.setHidden.assert_called_once_with(self.exp_hidden)
 
+    def _match_log(self, exp, got, log_type):
+        if hasattr(exp, 'match'):
+            if exp.match(got) is None:
+                log.msg("Unexpected {} log output:\n{}".format(log_type, exp))
+                log.msg("Expected {} to match:\n{}".format(log_type, got))
+                raise AssertionError("Unexpected {} log output; see logs".format(log_type))
+        else:
+            if got != exp:
+                log.msg("Unexpected {} log output:\n{}".format(log_type, exp))
+                log.msg("Expected {} log output:\n{}".format(log_type, got))
+                raise AssertionError("Unexpected {} log output; see logs".format(log_type))
+
     # callbacks from the running step
 
     @defer.inlineCallbacks
