@@ -98,7 +98,8 @@ class IdentifierValidator(Validator):
     name = 'identifier'
     hasArgs = True
 
-    ident_re = re.compile('^[a-zA-Z\u00a0-\U0010ffff_-][a-zA-Z0-9\u00a0-\U0010ffff_-]*$', flags=re.UNICODE)
+    ident_re = re.compile('^[a-zA-Z\u00a0-\U0010ffff_-][a-zA-Z0-9\u00a0-\U0010ffff_-]*$',
+                          flags=re.UNICODE)
 
     def __init__(self, len):
         self.len = len
@@ -180,7 +181,7 @@ class SequenceValidator(Validator):
         self.elementValidator = elementValidator
 
     def validate(self, name, object):
-        if not isinstance(object, self.type):
+        if not isinstance(object, self.type):  # noqa pylint: disable=isinstance-second-argument-not-valid-type
             yield "{} ({!r}) is not a {}".format(name, object, self.name)
             return
 
@@ -486,6 +487,7 @@ message['changes'].add(None,
                                changeid=IntValidator(),
                                parent_changeids=ListValidator(IntValidator()),
                                author=StringValidator(),
+                               committer=StringValidator(),
                                files=ListValidator(StringValidator()),
                                comments=StringValidator(),
                                revision=NoneOk(StringValidator()),
@@ -505,6 +507,7 @@ message['changes'].add(None,
 dbdict['chdict'] = DictValidator(
     changeid=IntValidator(),
     author=StringValidator(),
+    committer=StringValidator(),
     files=ListValidator(StringValidator()),
     comments=StringValidator(),
     revision=NoneOk(StringValidator()),
@@ -582,6 +585,29 @@ dbdict['dbbuilddict'] = buildbase = DictValidator(
 dbdict['builddict'] = DictValidator(
     properties=NoneOk(SourcedPropertiesValidator()), **buildbase.keys)
 
+# build data
+
+_build_data_msgdict = DictValidator(
+    buildid=IntValidator(),
+    name=StringValidator(),
+    value=NoneOk(BinaryValidator()),
+    length=IntValidator(),
+    source=StringValidator(),
+)
+
+message['build_data'] = Selector()
+message['build_data'].add(None,
+                          MessageValidator(events=[],
+                                           messageValidator=_build_data_msgdict))
+
+dbdict['build_datadict'] = DictValidator(
+    buildid=IntValidator(),
+    name=StringValidator(),
+    value=NoneOk(BinaryValidator()),
+    length=IntValidator(),
+    source=StringValidator(),
+)
+
 # steps
 
 _step = dict(
@@ -642,6 +668,66 @@ dbdict['logdict'] = DictValidator(
     num_lines=IntValidator(),
     type=IdentifierValidator(1))
 
+# test results sets
+
+_test_result_set_msgdict = DictValidator(
+    builderid=IntValidator(),
+    buildid=IntValidator(),
+    stepid=IntValidator(),
+    description=NoneOk(StringValidator()),
+    category=StringValidator(),
+    value_unit=StringValidator(),
+    tests_passed=NoneOk(IntValidator()),
+    tests_failed=NoneOk(IntValidator()),
+    complete=BooleanValidator()
+)
+
+message['test_result_sets'] = Selector()
+message['test_result_sets'].add(None,
+                                MessageValidator(events=[b'new', b'completed'],
+                                                 messageValidator=_test_result_set_msgdict))
+
+dbdict['test_result_setdict'] = DictValidator(
+    id=IntValidator(),
+    builderid=IntValidator(),
+    buildid=IntValidator(),
+    stepid=IntValidator(),
+    description=NoneOk(StringValidator()),
+    category=StringValidator(),
+    value_unit=StringValidator(),
+    tests_passed=NoneOk(IntValidator()),
+    tests_failed=NoneOk(IntValidator()),
+    complete=BooleanValidator()
+)
+
+# test results
+
+_test_results_msgdict = DictValidator(
+    builderid=IntValidator(),
+    test_result_setid=IntValidator(),
+    test_name=NoneOk(StringValidator()),
+    test_code_path=NoneOk(StringValidator()),
+    line=NoneOk(IntValidator()),
+    duration_ns=NoneOk(IntValidator()),
+    value=StringValidator(),
+)
+
+message['test_results'] = Selector()
+message['test_results'].add(None,
+                            MessageValidator(events=[b'new'],
+                                             messageValidator=_test_results_msgdict))
+
+dbdict['test_resultdict'] = DictValidator(
+    id=IntValidator(),
+    builderid=IntValidator(),
+    test_result_setid=IntValidator(),
+    test_name=NoneOk(StringValidator()),
+    test_code_path=NoneOk(StringValidator()),
+    line=NoneOk(IntValidator()),
+    duration_ns=NoneOk(IntValidator()),
+    value=StringValidator(),
+)
+
 
 # external functions
 
