@@ -21,13 +21,13 @@ import time
 from twisted.internet import defer
 from twisted.internet import reactor
 from twisted.internet.error import ProcessExitedAlready
-from twisted.internet.protocol import ProcessProtocol
 from twisted.python.failure import Failure
 
 from buildbot import config
 from buildbot.util import asyncSleep
 from buildbot.util.httpclientservice import HTTPClientService
 from buildbot.util.logger import Logger
+from buildbot.util.protocol import LineProcessProtocol
 from buildbot.util.service import BuildbotService
 
 log = Logger()
@@ -92,13 +92,13 @@ class KubeHardcodedConfig(KubeConfigLoaderBase):
             basicAuth = yield self.renderSecrets(self.basicAuth)
             authstring = "{user}:{password}".format(**basicAuth).encode('utf-8')
             encoded = base64.b64encode(authstring)
-            return defer.returnValue("Basic {0}".format(encoded))
+            return "Basic {0}".format(encoded)
 
         if self.bearerToken is not None:
             bearerToken = yield self.renderSecrets(self.bearerToken)
-            return defer.returnValue("Bearer {0}".format(bearerToken))
+            return "Bearer {0}".format(bearerToken)
 
-        return defer.returnValue(None)
+        return None
 
     def getConfig(self):
         return self.config
@@ -113,23 +113,23 @@ class KubeCtlProxyConfigLoader(KubeConfigLoaderBase):
     """
     kube_ctl_proxy_cmd = ['kubectl', 'proxy']  # for tests override
 
-    class LocalPP(ProcessProtocol):
+    class LocalPP(LineProcessProtocol):
         def __init__(self):
+            super().__init__()
             self.got_output_deferred = defer.Deferred()
             self.terminated_deferred = defer.Deferred()
             self.first_line = b""
 
-        def outReceived(self, data):
+        def outLineReceived(self, line):
             if not self.got_output_deferred.called:
-                self.first_line += data
-                if b"\n" in self.first_line:
-                    self.got_output_deferred.callback(self.first_line.split(b"\n")[0])
+                self.got_output_deferred.callback(line)
 
-        def errReceived(self, data):
+        def errLineReceived(self, line):
             if not self.got_output_deferred.called:
-                self.got_output_deferred.errback(Failure(RuntimeError(data)))
+                self.got_output_deferred.errback(Failure(RuntimeError(line)))
 
-        def processEnded(self, status_object):
+        def processEnded(self, status):
+            super().processEnded(status)
             self.terminated_deferred.callback(None)
 
     def checkConfig(self, proxy_port=8001, namespace="default"):
@@ -232,7 +232,7 @@ class KubeClientService(HTTPClientService):
             if arg in config:
                 req_kwargs[arg] = config[arg]
 
-        return defer.returnValue((url, req_kwargs))
+        return (url, req_kwargs)
 
     @defer.inlineCallbacks
     def createPod(self, namespace, spec):
@@ -241,7 +241,7 @@ class KubeClientService(HTTPClientService):
         res_json = yield res.json()
         if res.code not in (200, 201, 202):
             raise KubeError(res_json)
-        defer.returnValue(res_json)
+        return res_json
 
     @defer.inlineCallbacks
     def deletePod(self, namespace, name, graceperiod=0):
@@ -251,7 +251,7 @@ class KubeClientService(HTTPClientService):
         res_json = yield res.json()
         if res.code != 200:
             raise KubeError(res_json)
-        defer.returnValue(res_json)
+        return res_json
 
     @defer.inlineCallbacks
     def waitForPodDeletion(self, namespace, name, timeout):
@@ -270,7 +270,7 @@ class KubeClientService(HTTPClientService):
             if res.code != 200:
                 raise KubeError(res_json)
             yield asyncSleep(1)
-        defer.returnValue(res_json)
+        return res_json
 
     @property
     def namespace(self):
