@@ -44,9 +44,10 @@ class NoSuchMaildir(Exception):
 
 class MaildirService(service.BuildbotService):
     pollinterval = 10  # only used if we don't have DNotify
+    name = 'MaildirService'
 
     def __init__(self, basedir=None):
-        service.AsyncMultiService.__init__(self)
+        super().__init__()
         if basedir:
             self.setBasedir(basedir)
         self.files = []
@@ -62,9 +63,10 @@ class MaildirService(service.BuildbotService):
         self.newdir = os.path.join(self.basedir, "new")
         self.curdir = os.path.join(self.basedir, "cur")
 
+    @defer.inlineCallbacks
     def startService(self):
         if not os.path.isdir(self.newdir) or not os.path.isdir(self.curdir):
-            raise NoSuchMaildir("invalid maildir '%s'" % self.basedir)
+            raise NoSuchMaildir("invalid maildir '{}'".format(self.basedir))
         try:
             if dnotify:
                 # we must hold an fd open on the directory, so we can get
@@ -80,9 +82,9 @@ class MaildirService(service.BuildbotService):
         if not self.dnotify:
             self.timerService = internet.TimerService(
                 self.pollinterval, self.poll)
-            self.timerService.setServiceParent(self)
+            yield self.timerService.setServiceParent(self)
         self.poll()
-        return service.AsyncMultiService.startService(self)
+        yield super().startService()
 
     def dnotify_callback(self):
         log.msg("dnotify noticed something, now polling")
@@ -105,7 +107,7 @@ class MaildirService(service.BuildbotService):
         if self.timerService is not None:
             self.timerService.disownServiceParent()
             self.timerService = None
-        return service.AsyncMultiService.stopService(self)
+        return super().stopService()
 
     @defer.inlineCallbacks
     def poll(self):
@@ -124,10 +126,9 @@ class MaildirService(service.BuildbotService):
                 try:
                     yield self.messageReceived(n)
                 except Exception:
-                    log.err(
-                        None, "while reading '%s' from maildir '%s':" % (n, self.basedir))
+                    log.err(None, "while reading '{}' from maildir '{}':".format(n, self.basedir))
         except Exception:
-            log.err(None, "while polling maildir '%s':" % (self.basedir,))
+            log.err(None, "while polling maildir '{}':".format(self.basedir))
 
     def moveToCurDir(self, filename):
         if runtime.platformType == "posix":
