@@ -53,6 +53,8 @@ class ReconfigurableServiceMixin:
 # to catch issues even on twisted < 16
 class AsyncService(service.Service):
 
+    # service.Service.setServiceParent does not wait for neither disownServiceParent nor addService
+    # to complete
     @defer.inlineCallbacks
     def setServiceParent(self, parent):
         if self.parent is not None:
@@ -61,6 +63,13 @@ class AsyncService(service.Service):
         self.parent = parent
         yield self.parent.addService(self)
 
+    # service.Service.disownServiceParent does not wait for removeService to complete before
+    # setting parent to None
+    @defer.inlineCallbacks
+    def disownServiceParent(self):
+        yield self.parent.removeService(self)
+        self.parent = None
+
     # We recurse over the parent services until we find a MasterService
     @property
     def master(self):
@@ -221,6 +230,9 @@ class BuildbotService(AsyncMultiService, config.ConfiguredMixin, util.Comparable
                                        **kwargs)
         return d
 
+    def canReconfigWithSibling(self, sibling):
+        return reflect.qual(self.__class__) == reflect.qual(sibling.__class__)
+
     def configureService(self):
         # reconfigServiceWithSibling with self, means first configuration
         return self.reconfigServiceWithSibling(self)
@@ -453,23 +465,17 @@ class BuildbotServiceManager(AsyncMultiService, config.ConfiguredMixin,
         # calculate new childs, by name, and removed childs
         removed_names, added_names = util.diffSets(old_set, new_set)
 
-        # find any childs for which the fully qualified class name has
-        # changed, and treat those as an add and remove
-        # While we're at it find any service that don't know how to reconfig,
-        # and, if they have changed, add them to both removed and added, so that we
+        # find any children for which the old instance is not
+        # able to do a reconfig with the new sibling
+        # and add them to both removed and added, so that we
         # run the new version
         for n in old_set & new_set:
             old = old_by_name[n]
             new = new_by_name[n]
-            # detect changed class name
-            if reflect.qual(old.__class__) != reflect.qual(new.__class__):
+            # check if we are able to reconfig service
+            if not old.canReconfigWithSibling(new):
                 removed_names.add(n)
                 added_names.add(n)
-            # compare using ComparableMixin if they don't support reconfig
-            elif not hasattr(old, 'reconfigServiceWithBuildbotConfig'):
-                if not util.ComparableMixin.isEquivalent(old, new):
-                    removed_names.add(n)
-                    added_names.add(n)
 
         if removed_names or added_names:
             log.msg("adding {} new {}, removing {}".format(len(added_names), self.config_attr,
