@@ -175,16 +175,27 @@ class AbstractLatentWorker(AbstractWorker):
         self.build_wait_timeout = build_wait_timeout
         return super().reconfigService(name, password, **kwargs)
 
+    def _generate_random_password(self):
+        return ''.join(random.choice(string.ascii_letters + string.digits) for _ in range(20))
+
     def getRandomPass(self):
         """
-        compute a random password
-        There is no point to configure a password for a LatentWorker, as it is created by the
-        master.
-        For supporting backend, a password can be generated by this API
+        Compute a random password. Latent workers are started by the master, so master can setup
+        the password too. Backends should prefer to use this API as it handles edge cases.
         """
-        return ''.join(
-            random.choice(string.ascii_letters + string.digits)
-            for _ in range(20))
+
+        # We should return an existing password if we're reconfiguring a substantiated worker.
+        # Otherwise the worker may be rejected if its password was changed during substantiation.
+        # To simplify, we only allow changing passwords for workers that aren't substantiated.
+        if self.state not in [States.NOT_SUBSTANTIATED, States.SHUT_DOWN]:
+            if self.password is not None:
+                return self.password
+
+            # pragma: no cover
+            log.err('{}: could not reuse password of substantiated worker (password == None)',
+                    repr(self))
+
+        return self._generate_random_password()
 
     @property
     def building(self):
