@@ -20,6 +20,7 @@ import json
 from twisted.python import log
 
 from buildbot.util import bytes2unicode
+from buildbot.util.pullrequest import PullRequestMixin
 
 GIT_BRANCH_REF = "refs/heads/{}"
 GIT_MERGE_REF = "refs/pull-requests/{}/merge"
@@ -28,16 +29,19 @@ GIT_TAG_REF = "refs/tags/{}"
 _HEADER_EVENT = b'X-Event-Key'
 
 
-class BitbucketCloudEventHandler(object):
+class BitbucketCloudEventHandler(PullRequestMixin):
+
+    property_basename = "bitbucket"
 
     def __init__(self, master, options=None):
-        if options is None:
-            options = {}
         self.master = master
         if not isinstance(options, dict):
             options = {}
         self.options = options
         self._codebase = self.options.get('codebase', None)
+        self.external_property_whitelist = self.options.get(
+            'bitbucket_property_whitelist', []
+        )
 
     def process(self, request):
         payload = self._get_payload(request)
@@ -70,7 +74,7 @@ class BitbucketCloudEventHandler(object):
 
     def handle_repo_push(self, payload):
         changes = []
-        project = payload['repository']['project']['name']
+        project = payload['repository'].get('project', {'name': 'none'})['name']
         repo_url = payload['repository']['links']['self']['href']
         web_url = payload['repository']['links']['html']['href']
 
@@ -94,7 +98,7 @@ class BitbucketCloudEventHandler(object):
                 'revlink': '{}/commits/{}'.format(web_url, commit_hash),
                 'repository': repo_url,
                 'author': '{} <{}>'.format(payload['actor']['display_name'],
-                                           payload['actor']['username']),
+                                           payload['actor']['nickname']),
                 'comments': 'Bitbucket Cloud commit {}'.format(commit_hash),
                 'branch': branch,
                 'project': project,
@@ -139,17 +143,22 @@ class BitbucketCloudEventHandler(object):
     def handle_pullrequest(self, payload, refname, category):
         pr_number = int(payload['pullrequest']['id'])
         repo_url = payload['repository']['links']['self']['href']
+        project = payload['repository'].get('project', {'name': 'none'})['name']
+        revlink = payload['pullrequest']['link']
         change = {
             'revision': payload['pullrequest']['fromRef']['commit']['hash'],
-            'revlink': payload['pullrequest']['link'],
+            'revlink': revlink,
             'repository': repo_url,
             'author': '{} <{}>'.format(payload['actor']['display_name'],
-                                       payload['actor']['username']),
+                                       payload['actor']['nickname']),
             'comments': 'Bitbucket Cloud Pull Request #{}'.format(pr_number),
             'branch': refname,
-            'project': payload['repository']['project']['name'],
+            'project': project,
             'category': category,
-            'properties': {'pullrequesturl': payload['pullrequest']['link']}
+            'properties': {
+                'pullrequesturl': revlink,
+                **self.extractProperties(payload['pullrequest']),
+            }
         }
 
         if callable(self._codebase):
