@@ -26,8 +26,6 @@
 
 from urllib.parse import urlparse
 
-import ldap3
-
 from twisted.internet import threads
 
 from buildbot.util import bytes2unicode
@@ -35,6 +33,12 @@ from buildbot.util import flatten
 from buildbot.www import auth
 from buildbot.www import avatar
 
+try:
+    import ldap3
+except ImportError:
+    import importlib
+    ldap3 = None
+
 
 class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
     name = 'ldap'
@@ -50,6 +54,9 @@ class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
                  avatarPattern=None,
                  avatarData=None,
                  accountExtraFields=None):
+        # Throw import error now that this is being used
+        if not ldap3:
+            importlib.import_module('ldap3')
         self.uri = uri
         self.bindUser = bindUser
         self.bindPw = bindPw
@@ -107,8 +114,7 @@ class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
                                   self.accountEmail, self.accountFullName] +
                               self.accountExtraFields)
             if len(res) != 1:
-                raise KeyError(
-                    "ldap search \"%s\" returned %d results" % (pattern, len(res)))
+                raise KeyError("ldap search \"{}\" returned {} results".format(pattern, len(res)))
             dn, ldap_infos = res[0]['dn'], res[0]['attributes']
 
             def getFirstLdapInfo(x):
@@ -127,7 +133,7 @@ class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
                 return infos
 
             # needs double quoting of backslashing
-            pattern = self.groupMemberPattern % dict(dn=dn)
+            pattern = self.groupMemberPattern % dict(dn=ldap3.utils.conv.escape_filter_chars(dn))
             res = self.search(c, self.groupBase, pattern,
                               attributes=[self.groupName])
             infos['groups'] = flatten([group_infos['attributes'][self.groupName]
@@ -139,20 +145,28 @@ class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
     def findAvatarMime(self, data):
         # http://en.wikipedia.org/wiki/List_of_file_signatures
         if data.startswith(b"\xff\xd8\xff"):
-            return ("image/jpeg", data)
+            return (b"image/jpeg", data)
         if data.startswith(b"\x89PNG"):
-            return ("image/png", data)
+            return (b"image/png", data)
         if data.startswith(b"GIF8"):
-            return ("image/gif", data)
+            return (b"image/gif", data)
         # ignore unknown image format
         return None
 
-    def getUserAvatar(self, user_email, size, defaultAvatarUrl):
-        user_email = bytes2unicode(user_email)
+    def getUserAvatar(self, email, username, size, defaultAvatarUrl):
+        if username:
+            username = bytes2unicode(username)
+        if email:
+            email = bytes2unicode(email)
 
         def thd():
             c = self.connectLdap()
-            pattern = self.avatarPattern % dict(email=user_email)
+            if username:
+                pattern = self.accountPattern % dict(username=username)
+            elif email:
+                pattern = self.avatarPattern % dict(email=email)
+            else:
+                return None
             res = self.search(c, self.accountBase, pattern,
                               attributes=[self.avatarData])
             if not res:
