@@ -40,11 +40,13 @@ from buildbot.www import auth
 from buildbot.www import avatar
 from buildbot.www import change_hook
 from buildbot.www import config as wwwconfig
+from buildbot.www import graphql
 from buildbot.www import rest
 from buildbot.www import sse
 from buildbot.www import ws
 
-# as per: http://security.stackexchange.com/questions/95972/what-are-requirements-for-hmac-secret-key
+# as per:
+# http://security.stackexchange.com/questions/95972/what-are-requirements-for-hmac-secret-key
 # we need 128 bit key for HS256
 SESSION_SECRET_LENGTH = 128
 SESSION_SECRET_ALGORITHM = "HS256"
@@ -64,6 +66,9 @@ class BuildbotSession(server.Session):
         """
         self.site = site
         assert self.site.session_secret is not None, "site.session_secret is not configured yet!"
+        # Cannot use super() here as it would call server.Session.__init__
+        # which we explicitly want to override. However, we still want to call
+        # server.Session parent class constructor
         components.Componentized.__init__(self)
         if token:
             self._fromToken(token)
@@ -78,10 +83,10 @@ class BuildbotSession(server.Session):
             decoded = jwt.decode(token, self.site.session_secret, algorithms=[
                                  SESSION_SECRET_ALGORITHM])
         except jwt.exceptions.ExpiredSignatureError as e:
-            raise KeyError(str(e))
+            raise KeyError(str(e)) from e
         except Exception as e:
             log.err(e, "while decoding JWT session")
-            raise KeyError(str(e))
+            raise KeyError(str(e)) from e
         # might raise KeyError: will be caught by caller, which makes the token invalid
         self.user_info = decoded['user_info']
 
@@ -138,7 +143,7 @@ class BuildbotSite(server.Site):
     """
 
     def __init__(self, root, logPath, rotateLength, maxRotatedFiles):
-        server.Site.__init__(self, root, logPath=logPath)
+        super().__init__(root, logPath=logPath)
         self.rotateLength = rotateLength
         self.maxRotatedFiles = maxRotatedFiles
         self.session_secret = None
@@ -148,6 +153,10 @@ class BuildbotSite(server.Site):
         return LogFile.fromFullPath(
             path, rotateLength=self.rotateLength, maxRotatedFiles=self.maxRotatedFiles)
 
+    def getResourceFor(self, request):
+        request.responseHeaders.removeHeader('Server')
+        return server.Site.getResourceFor(self, request)
+
     def setSessionSecret(self, secret):
         self.session_secret = secret
 
@@ -173,7 +182,7 @@ class WWWService(service.ReconfigurableServiceMixin, service.AsyncMultiService):
     name = 'www'
 
     def __init__(self):
-        service.AsyncMultiService.__init__(self)
+        super().__init__()
 
         self.port = None
         self.port_service = None
@@ -211,7 +220,7 @@ class WWWService(service.ReconfigurableServiceMixin, service.AsyncMultiService):
 
         if www['port'] != self.port:
             if self.port_service:
-                yield defer.maybeDeferred(self.port_service.disownServiceParent)
+                yield self.port_service.disownServiceParent()
                 self.port_service = None
 
             self.port = www['port']
@@ -244,8 +253,7 @@ class WWWService(service.ReconfigurableServiceMixin, service.AsyncMultiService):
         if not self.port_service:
             log.msg("No web server configured on this master")
 
-        yield service.ReconfigurableServiceMixin.reconfigServiceWithBuildbotConfig(self,
-                                                                                   new_config)
+        yield super().reconfigServiceWithBuildbotConfig(new_config)
 
     def getPortnum(self):
         # for tests, when the configured port is 0 and the kernel selects a
@@ -258,8 +266,7 @@ class WWWService(service.ReconfigurableServiceMixin, service.AsyncMultiService):
         for key, plugin in list(new_config.www.get('plugins', {}).items()):
             log.msg("initializing www plugin %r" % (key,))
             if key not in self.apps:
-                raise RuntimeError(
-                    "could not find plugin %s; is it installed?" % (key,))
+                raise RuntimeError("could not find plugin {}; is it installed?".format(key))
             app = self.apps.get(key)
             app.setMaster(self.master)
             app.setConfiguration(plugin)
@@ -291,6 +298,7 @@ class WWWService(service.ReconfigurableServiceMixin, service.AsyncMultiService):
 
         # /api
         root.putChild(b'api', rest.RestRootResource(self.master))
+        [graphql]  # import is made for side effects
 
         # /ws
         root.putChild(b'ws', ws.WsResource(self.master))
@@ -358,12 +366,13 @@ class WWWService(service.ReconfigurableServiceMixin, service.AsyncMultiService):
             # we encode that in hex for db storage convenience
             return bytes2unicode(hexlify(os.urandom(int(SESSION_SECRET_LENGTH / 8))))
 
-        session_secret = yield state.atomicCreateState(objectid, "session_secret", create_session_secret)
+        session_secret = yield state.atomicCreateState(objectid, "session_secret",
+                                                       create_session_secret)
         self.site.setSessionSecret(session_secret)
 
     def setupProtectedResource(self, resource_obj, checkers):
         @implementer(IRealm)
-        class SimpleRealm(object):
+        class SimpleRealm:
 
             """
             A realm which gives out L{ChangeHookResource} instances for authenticated
