@@ -150,8 +150,9 @@ setup_args = {
         'Topic :: Software Development :: Build Tools',
         'Topic :: Software Development :: Testing',
         'Programming Language :: Python :: 3',
-        'Programming Language :: Python :: 3.5',
-        'Programming Language :: Python :: 3.6'
+        'Programming Language :: Python :: 3.6',
+        'Programming Language :: Python :: 3.7',
+        'Programming Language :: Python :: 3.8',
     ],
 
     'packages': [
@@ -163,7 +164,7 @@ setup_args = {
         "buildbot.clients",
         "buildbot.data",
         "buildbot.db",
-        "buildbot.db.migrate.versions",
+        "buildbot.db.migrations.versions",
         "buildbot.db.types",
         "buildbot.machine",
         "buildbot.monkeypatches",
@@ -179,7 +180,6 @@ setup_args = {
         "buildbot.secrets.providers",
         "buildbot.statistics",
         "buildbot.statistics.storage_backends",
-        "buildbot.status",
         "buildbot.steps",
         "buildbot.steps.package",
         "buildbot.steps.package.deb",
@@ -203,10 +203,10 @@ setup_args = {
     ]),
     'data_files': [
         include("buildbot/reporters/templates", "*.txt"),
-        ("buildbot/db/migrate", [
-            "buildbot/db/migrate/migrate.cfg",
+        ("buildbot/db/migrations", [
+            "buildbot/db/migrations/alembic.ini",
         ]),
-        include("buildbot/db/migrate/versions", "*.py"),
+        include("buildbot/db/migrations/versions", "*.py"),
         ("buildbot/scripts", [
             "buildbot/scripts/sample.cfg",
             "buildbot/scripts/buildbot_tac.tmpl",
@@ -228,7 +228,6 @@ setup_args = {
                 'BzrLaunchpadEmailMaildirSource']),
             ('buildbot.changes.bitbucket', ['BitbucketPullrequestPoller']),
             ('buildbot.changes.github', ['GitHubPullrequestPoller']),
-            ('buildbot.changes.bonsaipoller', ['BonsaiPoller']),
             ('buildbot.changes.gerritchangesource', [
                 'GerritChangeSource', 'GerritEventLogPoller']),
             ('buildbot.changes.gitpoller', ['GitPoller']),
@@ -251,7 +250,10 @@ setup_args = {
         ('buildbot.secrets', [
             ('buildbot.secrets.providers.file', ['SecretInAFile']),
             ('buildbot.secrets.providers.passwordstore', ['SecretInPass']),
-            ('buildbot.secrets.providers.vault', ['HashiCorpVaultSecretProvider'])
+            ('buildbot.secrets.providers.vault', ['HashiCorpVaultSecretProvider']),
+            ('buildbot.secrets.providers.vault_hvac', [
+                'HashiCorpVaultKvSecretProvider', 'VaultAuthenticatorToken',
+                'VaultAuthenticatorApprole'])
         ]),
         ('buildbot.worker', [
             ('buildbot.worker.base', ['Worker']),
@@ -269,17 +271,13 @@ setup_args = {
             ('buildbot.process.buildstep', ['BuildStep']),
             ('buildbot.steps.cmake', ['CMake']),
             ('buildbot.steps.cppcheck', ['Cppcheck']),
+            ('buildbot.steps.gitdiffinfo', ['GitDiffInfo']),
             ('buildbot.steps.http', [
-                'HTTPStep', 'POST', 'GET', 'PUT', 'DELETE', 'HEAD',
-                'OPTIONS',
-                'HTTPStepNewStyle', 'POSTNewStyle', 'GETNewStyle', 'PUTNewStyle', 'DELETENewStyle',
-                'HEADNewStyle', 'OPTIONSNewStyle']),
+                'HTTPStep', 'POST', 'GET', 'PUT', 'DELETE', 'HEAD', 'OPTIONS']),
             ('buildbot.steps.master', [
-                'MasterShellCommand', 'MasterShellCommandNewStyle',
-                'SetProperty', 'SetProperties', 'LogRenderable', "Assert"]),
+                'MasterShellCommand', 'SetProperty', 'SetProperties', 'LogRenderable', "Assert"]),
             ('buildbot.steps.maxq', ['MaxQ']),
             ('buildbot.steps.mswin', ['Robocopy']),
-            ('buildbot.steps.mtrlogobserver', ['MTR']),
             ('buildbot.steps.package.deb.lintian', ['DebLintian']),
             ('buildbot.steps.package.deb.pbuilder', [
                 'DebPbuilder', 'DebCowbuilder', 'UbuPbuilder',
@@ -293,12 +291,8 @@ setup_args = {
             ('buildbot.steps.python_twisted', [
                 'HLint', 'Trial', 'RemovePYCs']),
             ('buildbot.steps.shell', [
-                'ShellCommand', 'ShellCommandNewStyle', 'TreeSize',
-                'SetPropertyFromCommand', 'SetPropertyFromCommandNewStyle',
-                'Configure', 'ConfigureNewStyle',
-                'WarningCountingShellCommand', 'WarningCountingShellCommandNewStyle',
-                'Compile', 'CompileNewStyle',
-                'Test', 'TestNewStyle', 'PerlModuleTest']),
+                'ShellCommand', 'TreeSize', 'SetPropertyFromCommand', 'Configure',
+                'WarningCountingShellCommand', 'Compile', 'Test', 'PerlModuleTest']),
             ('buildbot.steps.shellsequence', ['ShellSequence']),
             ('buildbot.steps.source.bzr', ['Bzr']),
             ('buildbot.steps.source.cvs', ['CVS']),
@@ -328,6 +322,15 @@ setup_args = {
                 'RemoveDirectory', 'MakeDirectory']),
         ]),
         ('buildbot.reporters', [
+            ('buildbot.reporters.generators.build', [
+                'BuildStatusGenerator',
+                'BuildStartEndStatusGenerator'
+            ]),
+            ('buildbot.reporters.generators.buildrequest', [
+                'BuildRequestGenerator'
+            ]),
+            ('buildbot.reporters.generators.buildset', ['BuildSetStatusGenerator']),
+            ('buildbot.reporters.generators.worker', ['WorkerMissingGenerator']),
             ('buildbot.reporters.mail', ['MailNotifier']),
             ('buildbot.reporters.pushjet', ['PushjetNotifier']),
             ('buildbot.reporters.pushover', ['PushoverNotifier']),
@@ -341,11 +344,9 @@ setup_args = {
             ('buildbot.reporters.gerrit', ['GerritStatusPush']),
             ('buildbot.reporters.gerrit_verify_status',
              ['GerritVerifyStatusPush']),
-            ('buildbot.reporters.hipchat', ['HipChatStatusPush']),
             ('buildbot.reporters.http', ['HttpStatusPush']),
             ('buildbot.reporters.github', ['GitHubStatusPush', 'GitHubCommentPush']),
             ('buildbot.reporters.gitlab', ['GitLabStatusPush']),
-            ('buildbot.reporters.stash', ['StashStatusPush']),
             ('buildbot.reporters.bitbucketserver', [
                 'BitbucketServerStatusPush',
                 'BitbucketServerCoreAPIStatusPush',
@@ -384,10 +385,12 @@ setup_args = {
             ('buildbot.process.properties', [
                 'FlattenList', 'Interpolate', 'Property', 'Transform',
                 'WithProperties', 'renderer', 'Secret']),
-            ('buildbot.process.properties', [
+            ('buildbot.process.users.manual', [
                 'CommandlineUserManager']),
             ('buildbot.revlinks', ['RevlinkMatch']),
             ('buildbot.reporters.utils', ['URLForBuild']),
+            ('buildbot.schedulers.canceller', ['OldBuildCanceller']),
+            ('buildbot.schedulers.canceller_buildset', ['FailingBuildsetCanceller']),
             ('buildbot.schedulers.forcesched', [
                 'AnyPropertyParameter', 'BooleanParameter',
                 'ChoiceStringParameter',
@@ -400,7 +403,6 @@ setup_args = {
             ('buildbot.process.results', [
                 'Results', 'SUCCESS', 'WARNINGS', 'FAILURE', 'SKIPPED',
                 'EXCEPTION', 'RETRY', 'CANCELLED']),
-            ('buildbot.steps.mtrlogobserver', ['EqConnectionPool']),
             ('buildbot.steps.source.repo', [
                 ('repo.DownloadsFromChangeSource',
                  'RepoDownloadsFromChangeSource'),
@@ -410,6 +412,7 @@ setup_args = {
             ('buildbot.util.kubeclientservice', [
                 'KubeHardcodedConfig', 'KubeCtlProxyConfigLoader', 'KubeInClusterConfigLoader'
             ]),
+            ('buildbot.util.ssfilter', ['SourceStampFilter']),
             ('buildbot.www.avatar', ['AvatarGravatar', 'AvatarGitHub']),
             ('buildbot.www.auth', [
                 'UserPasswordAuth', 'HTPasswdAuth', 'RemoteUserAuth', 'CustomAuth']),
@@ -442,8 +445,6 @@ setup_args = {
     ]), {
         'console_scripts': [
             'buildbot=buildbot.scripts.runner:run',
-            # this will also be shipped on non windows :-(
-            'buildbot_windows_service=buildbot.scripts.windows_service:HandleCommandLine',
         ]}
     )
 }
@@ -453,11 +454,14 @@ setup_args = {
 # see http://buildbot.net/trac/ticket/907
 if sys.platform == "win32":
     setup_args['zip_safe'] = False
+    setup_args['entry_points']['console_scripts'].append(
+        'buildbot_windows_service=buildbot.scripts.windows_service:HandleCommandLine'
+    )
 
-py_35 = sys.version_info[0] > 3 or (
-    sys.version_info[0] == 3 and sys.version_info[1] >= 5)
-if not py_35:
-    raise RuntimeError("Buildbot master requires at least Python-3.5")
+py_36 = sys.version_info[0] > 3 or (
+    sys.version_info[0] == 3 and sys.version_info[1] >= 6)
+if not py_36:
+    raise RuntimeError("Buildbot master requires at least Python-3.6")
 
 # pip<1.4 doesn't have the --pre flag, and will thus attempt to install alpha
 # and beta versions of Buildbot.  Prevent that from happening.
@@ -490,8 +494,8 @@ setup_args['install_requires'] = [
     'Jinja2 >= 2.1',
     # required for tests, but Twisted requires this anyway
     'zope.interface >= 4.1.1',
-    'sqlalchemy>=1.2.0',
-    'sqlalchemy-migrate>=0.13',
+    'sqlalchemy >= 1.3.0, < 1.5',
+    'alembic >= 1.6.0',
     'python-dateutil>=1.5',
     'txaio ' + txaio_ver,
     'autobahn ' + autobahn_ver,
@@ -499,6 +503,10 @@ setup_args['install_requires'] = [
     'pyyaml'
 ]
 
+# buildbot_windows_service needs pywin32
+if sys.platform == "win32":
+    setup_args['install_requires'].append('pywin32')
+
 # Unit test dependencies.
 test_deps = [
     # http client libraries
@@ -529,7 +537,7 @@ setup_args['extras_require'] = {
         # spellcheck introduced in version 1.4.0
         'pylint<1.7.0',
         'pyenchant',
-        'flake8~=2.6.0',
+        'flake8~=3.9.2',
     ] + test_deps,
     'bundle': [
         "buildbot-www=={0}".format(bundle_version),
@@ -551,7 +559,6 @@ setup_args['extras_require'] = {
         'docutils>=0.16.0',
         'sphinx>=3.2.0',
         'sphinx-rtd-theme>=0.5',
-        'sphinxcontrib-blockdiag',
         'sphinxcontrib-spelling',
         'sphinxcontrib-websupport',
         'pyenchant',
