@@ -3,6 +3,7 @@
 
 import { BasePage } from "./base";
 import { browser, by, element, ExpectedConditions as EC } from 'protractor';
+import { bbrowser } from '../utils';
 
 export class AboutPage extends BasePage {
     constructor(builder) {
@@ -11,10 +12,8 @@ export class AboutPage extends BasePage {
     }
 
     async goAbout() {
-        await browser.get('#/about');
-        await browser.wait(EC.urlContains('#/about'),
-                           10000,
-                           "URL does not contain #/about");
+        await bbrowser.get('#/about');
+        await bbrowser.wait(EC.urlContains('#/about'), "URL does not contain #/about");
     }
 
     async checkBuildbotTitle() {
