@@ -108,6 +108,8 @@ class CreateWorkerOptions(MakerBase):
          "Do not permit buildmaster rotate logs by itself"],
         ['use-tls', None,
          "Uses TLS to connect to master"],
+        ['delete-leftover-dirs', None,
+         'Delete folders that are not required by the master on connection'],
     ]
     optParameters = [
         ["keepalive", "k", 600,
@@ -128,7 +130,9 @@ class CreateWorkerOptions(MakerBase):
          "(None for unlimited)"],
         ["allow-shutdown", "a", None,
          "Allows the worker to initiate a graceful shutdown. One of "
-         "'signal' or 'file'"]
+         "'signal' or 'file'"],
+        ["proxy-connection-string", None, None,
+         "Address of HTTP proxy to tunnel through"]
     ]
 
     longdesc = textwrap.dedent("""
@@ -156,11 +160,25 @@ class CreateWorkerOptions(MakerBase):
         if master_arg[:5] == "http:":
             raise usage.UsageError("<master> is not a URL - do not use URL")
 
-        if ":" not in master_arg:
+        if master_arg.startswith("[") and "]" in master_arg:
+            # detect ipv6 address with format [2001:1:2:3:4::1]:4321
+            master, port_tmp = master_arg.split("]")
+            master = master[1:]
+            if ":" not in port_tmp:
+                port = 9989
+            else:
+                port = port_tmp.split(":")[1]
+
+        elif ":" not in master_arg:
             master = master_arg
             port = 9989
         else:
-            master, port = master_arg.split(":")
+            try:
+                master, port = master_arg.split(":")
+            except ValueError:
+                raise usage.UsageError(("invalid <master> argument '{}', "
+                                        "if it is an ipv6 address, it must be enclosed by []"
+                                        ).format(master_arg))
 
         if not master:
             raise usage.UsageError("invalid <master> argument '{}'".format(
