@@ -119,9 +119,9 @@ class TestMakeBaseDir(misc.StdoutAssertionsMixin, unittest.TestCase):
                    mock.Mock(side_effect=OSError(0, "dummy-error")))
 
         # check that correct exception was raised
-        self.assertRaisesRegex(create_worker.CreateWorkerError,
-                               "error creating directory dummy: dummy-error",
-                               create_worker._makeBaseDir, "dummy", False)
+        with self.assertRaisesRegex(create_worker.CreateWorkerError,
+                                "error creating directory dummy: dummy-error"):
+            create_worker._makeBaseDir("dummy", False)
 
 
 class TestMakeBuildbotTac(misc.StdoutAssertionsMixin,
@@ -153,10 +153,9 @@ class TestMakeBuildbotTac(misc.StdoutAssertionsMixin,
 
         # call _makeBuildbotTac() and check that correct exception is raised
         expected_message = "error reading {0}: dummy-msg".format(self.tac_file_path)
-        self.assertRaisesRegex(create_worker.CreateWorkerError,
-                               expected_message,
-                               create_worker._makeBuildbotTac,
-                               "bdir", "contents", False)
+        with self.assertRaisesRegex(create_worker.CreateWorkerError,
+                                    expected_message):
+            create_worker._makeBuildbotTac("bdir", "contents", False)
 
     def testTacReadError(self):
         """
@@ -168,10 +167,9 @@ class TestMakeBuildbotTac(misc.StdoutAssertionsMixin,
 
         # call _makeBuildbotTac() and check that correct exception is raised
         expected_message = "error reading {0}: dummy-msg".format(self.tac_file_path)
-        self.assertRaisesRegex(create_worker.CreateWorkerError,
-                               expected_message,
-                               create_worker._makeBuildbotTac,
-                               "bdir", "contents", False)
+        with self.assertRaisesRegex(create_worker.CreateWorkerError,
+                                    expected_message):
+            create_worker._makeBuildbotTac("bdir", "contents", False)
 
     def testTacWriteError(self):
         """
@@ -183,10 +181,9 @@ class TestMakeBuildbotTac(misc.StdoutAssertionsMixin,
 
         # call _makeBuildbotTac() and check that correct exception is raised
         expected_message = "could not write {0}: dummy-msg".format(self.tac_file_path)
-        self.assertRaisesRegex(create_worker.CreateWorkerError,
-                               expected_message,
-                               create_worker._makeBuildbotTac,
-                               "bdir", "contents", False)
+        with self.assertRaisesRegex(create_worker.CreateWorkerError,
+                                    expected_message):
+            create_worker._makeBuildbotTac("bdir", "contents", False)
 
     def checkTacFileCorrect(self, quiet):
         """
@@ -313,11 +310,10 @@ class TestMakeInfoFiles(misc.StdoutAssertionsMixin,
         self.patch(os, "mkdir", mock.Mock(side_effect=OSError(0, "err-msg")))
 
         # call _makeInfoFiles() and check that correct exception is raised
-        self.assertRaisesRegex(create_worker.CreateWorkerError,
-                               "error creating directory %s: err-msg" %
-                               _regexp_path("bdir", "info"),
-                               create_worker._makeInfoFiles,
-                               "bdir", quiet)
+        with self.assertRaisesRegex(create_worker.CreateWorkerError,
+                                    "error creating directory {}: err-msg".format(
+                                            _regexp_path("bdir", "info"))):
+            create_worker._makeInfoFiles("bdir", quiet)
 
         # check output to stdout
         if quiet:
@@ -362,19 +358,18 @@ class TestMakeInfoFiles(misc.StdoutAssertionsMixin,
             self.fail("unexpected error_type '{0}'".format(error_type))
 
         # call _makeInfoFiles() and check that correct exception is raised
-        self.assertRaisesRegex(create_worker.CreateWorkerError,
-                               "could not write {0}: info-err-msg".format(
-                               _regexp_path("bdir", "info", "admin")),
-                               create_worker._makeInfoFiles,
-                               "bdir", quiet)
+        with self.assertRaisesRegex(create_worker.CreateWorkerError,
+                                    "could not write {0}: info-err-msg".format(
+                                    _regexp_path("bdir", "info", "admin"))):
+            create_worker._makeInfoFiles("bdir", quiet)
 
         # check output to stdout
         if quiet:
             self.assertWasQuiet()
         else:
             self.assertStdoutEqual(
-                "Creating %s, you need to edit it appropriately.\n" %
-                os.path.join("info", "admin"))
+                "Creating {}, you need to edit it appropriately.\n".format(
+                        os.path.join("info", "admin")))
 
     def testOpenError(self):
         """
@@ -437,15 +432,15 @@ class TestMakeInfoFiles(misc.StdoutAssertionsMixin,
             self.assertWasQuiet()
         else:
             self.assertStdoutEqual(
-                "mkdir %s\n"
-                "Creating %s, you need to edit it appropriately.\n"
-                "Creating %s, you need to edit it appropriately.\n"
-                "Not creating %s - add it if you wish\n"
-                "Please edit the files in %s appropriately.\n" %
-                (info_path, os.path.join("info", "admin"),
-                 os.path.join("info", "host"),
-                 os.path.join("info", "access_uri"),
-                 info_path))
+                ("mkdir {}\n"
+                 "Creating {}, you need to edit it appropriately.\n"
+                 "Creating {}, you need to edit it appropriately.\n"
+                 "Not creating {} - add it if you wish\n"
+                 "Please edit the files in {} appropriately.\n").format(
+                info_path, os.path.join("info", "admin"),
+                os.path.join("info", "host"),
+                os.path.join("info", "access_uri"),
+                info_path))
 
     def testCreatedSuccessfully(self):
         """
@@ -484,6 +479,8 @@ class TestCreateWorker(misc.StdoutAssertionsMixin, unittest.TestCase):
         "no-logrotate": False,
         "relocatable": False,
         "quiet": False,
+        "use-tls": False,
+        "delete-leftover-dirs": False,
         # options
         "basedir": "bdir",
         "allow-shutdown": None,
@@ -494,6 +491,7 @@ class TestCreateWorker(misc.StdoutAssertionsMixin, unittest.TestCase):
         "maxdelay": 2,
         "numcpus": None,
         "maxretries": None,
+        "proxy-connection-string": None,
 
         # arguments
         "host": "masterhost",
@@ -580,6 +578,7 @@ class TestCreateWorker(misc.StdoutAssertionsMixin, unittest.TestCase):
         script and does typical for TAC file logic.
         """
 
+        # pylint: disable=import-outside-toplevel
         # import modules for mocking
         import twisted.application.service
         import twisted.python.logfile
@@ -625,6 +624,9 @@ class TestCreateWorker(misc.StdoutAssertionsMixin, unittest.TestCase):
             maxdelay=options["maxdelay"],
             allow_shutdown=options["allow-shutdown"],
             maxRetries=options["maxretries"],
+            useTls=options["use-tls"],
+            delete_leftover_dirs=options["delete-leftover-dirs"],
+            proxy_connection_string=options["proxy-connection-string"],
             )
 
         # check that Worker instance attached to application
@@ -730,6 +732,30 @@ class TestCreateWorker(misc.StdoutAssertionsMixin, unittest.TestCase):
         # check that correct info message was printed
         self.assertStdoutEqual("worker configured in bdir\n")
 
+    def testUseTLS(self):
+        """
+        test that when --use-tls options is used, correct connection_string
+        is generated
+        """
+        options = self.options.copy()
+        options["use-tls"] = True
+
+        # patch _make*() functions to do nothing
+        self.setUpMakeFunctions()
+
+        # call createWorker() and check that we get success exit code
+        self.assertEqual(create_worker.createWorker(options), 0,
+                         "unexpected exit code")
+
+        # check _make*() functions were called with correct arguments
+        expected_tac_contents = ("".join(create_worker.workerTACTemplate)) % options
+        self.assertMakeFunctionsCalls(self.options["basedir"],
+                                      expected_tac_contents,
+                                      self.options["quiet"])
+
+        # check that correct info message was printed
+        self.assertStdoutEqual("worker configured in bdir\n")
+
     def testWithOpts(self):
         """
         test calling createWorker() with --relocatable and --allow-shutdown
@@ -780,3 +806,26 @@ class TestCreateWorker(misc.StdoutAssertionsMixin, unittest.TestCase):
 
         # there should be no output on stdout
         self.assertWasQuiet()
+
+    def testDeleteLeftoverDirs(self):
+        """
+        test calling createWorker() with --delete-leftover-dirs flag
+        """
+        options = self.options.copy()
+        options["delete-leftover-dirs"] = True
+
+        # patch _make*() functions to do nothing
+        self.setUpMakeFunctions()
+
+        # call createWorker() and check that we get success exit code
+        self.assertEqual(create_worker.createWorker(options), 0,
+                         "unexpected exit code")
+
+        # check _make*() functions were called with correct arguments
+        expected_tac_contents = ("".join(create_worker.workerTACTemplate)) % options
+        self.assertMakeFunctionsCalls(self.options["basedir"],
+                                      expected_tac_contents,
+                                      self.options["quiet"])
+
+        # check that correct info message was printed
+        self.assertStdoutEqual("worker configured in bdir\n")
