@@ -33,11 +33,31 @@ try:
     import setuptools
     from setuptools import setup
     from setuptools.command.sdist import sdist
+    from distutils.command.install_data import install_data
 except ImportError:
     setuptools = None
     from distutils.command.sdist import sdist
     from distutils.core import setup
 
+BUILDING_WHEEL = bool("bdist_wheel" in sys.argv)
+
+
+class our_install_data(install_data):
+
+    def finalize_options(self):
+        self.set_undefined_options('install',
+                                   ('install_lib', 'install_dir'),
+                                   )
+        install_data.finalize_options(self)
+
+    def run(self):
+        install_data.run(self)
+        # ensure there's a buildbot_worker/VERSION file
+        fn = os.path.join(self.install_dir, 'buildbot_worker', 'VERSION')
+        with open(fn, 'w') as f:
+            f.write(version)
+        self.outfiles.append(fn)
+
 
 class our_sdist(sdist):
 
@@ -81,6 +101,8 @@ setup_args = {
         'Programming Language :: Python :: 3.4',
         'Programming Language :: Python :: 3.5',
         'Programming Language :: Python :: 3.6',
+        'Programming Language :: Python :: 3.7',
+        'Programming Language :: Python :: 3.8',
     ],
 
     'packages': [
@@ -90,24 +112,27 @@ setup_args = {
         "buildbot_worker.commands",
         "buildbot_worker.scripts",
         "buildbot_worker.monkeypatches",
+    ] + ([] if BUILDING_WHEEL else [  # skip tests for wheels (save 40% of the archive)
         "buildbot_worker.test",
         "buildbot_worker.test.fake",
         "buildbot_worker.test.unit",
         "buildbot_worker.test.util",
-    ],
+    ]),
+    # mention data_files, even if empty, so install_data is called and
+    # VERSION gets copied
+    'data_files': [("buildbot_worker", [])],
     'package_data': {
         '': [
             'VERSION',
         ]
     },
     'cmdclass': {
+        'install_data': our_install_data,
         'sdist': our_sdist
     },
     'entry_points': {
         'console_scripts': [
             'buildbot-worker=buildbot_worker.scripts.runner:run',
-            # this will also be shipped on non windows :-(
-            'buildbot_worker_windows_service=buildbot_worker.scripts.windows_service:HandleCommandLine',  # noqa pylint: disable=line-too-long
         ]}
 }
 
@@ -116,6 +141,9 @@ setup_args = {
 # see http://buildbot.net/trac/ticket/907
 if sys.platform == "win32":
     setup_args['zip_safe'] = False
+    setup_args['entry_points']['console_scripts'].append(
+        'buildbot_worker_windows_service=buildbot_worker.scripts.windows_service:HandleCommandLine',  # noqa pylint: disable=line-too-long
+    )
 
 twisted_ver = ">= 17.9.0"
 
@@ -125,6 +153,10 @@ if setuptools is not None:
         'future',
     ]
 
+    # buildbot_worker_windows_service needs pywin32
+    if sys.platform == "win32":
+        setup_args['install_requires'].append('pywin32')
+
     # Unit test hard dependencies.
     test_deps = [
         'mock',
@@ -138,7 +170,7 @@ if setuptools is not None:
             # spellcheck introduced in version 1.4.0
             'pylint>=1.4.0',
             'pyenchant',
-            'flake8~=2.6.0',
+            'flake8~=3.9.0',
         ] + test_deps,
     }
 
