@@ -6,15 +6,20 @@
 class Route {
     constructor($urlRouterProvider, glMenuServiceProvider, config) {
         let apptitle;
-        $urlRouterProvider.otherwise('/');
+        $urlRouterProvider.otherwise(config.default_page || '/');
         // the app title needs to be < 18 chars else the UI looks bad
         // we try to find best option
+
+        // Note that we warn about too long title in master/buildbot/config.py.
+        // Adjust that code if the maximum length changes.
+        let max_title_len = 18;
+
         if (config.title != null) {
             apptitle = `Buildbot: ${config.title}`;
-            if (apptitle.length > 18) {
+            if (apptitle.length > max_title_len) {
                 apptitle = config.title;
             }
-            if (apptitle.length > 18) {
+            if (apptitle.length > max_title_len) {
                 apptitle = "Buildbot";
             }
         } else {
@@ -27,4 +32,7 @@ class Route {
 
 
 angular.module('app')
-.config(['$urlRouterProvider', 'glMenuServiceProvider', 'config', Route]);
+.config(['$urlRouterProvider', 'glMenuServiceProvider', 'config', Route])
+.config(['$locationProvider', function($locationProvider) {
+    $locationProvider.hashPrefix('');
+}]);
